@@ -30,7 +30,7 @@
 
 #include <utility>
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 
 #include <agrum/core/hashTable.h>
 
@@ -39,11 +39,12 @@
 
 namespace gum {
 
-  template <typename GUM_SCALAR>
+  template < typename GUM_SCALAR >
   class BayesNetFactory;
 
   /**
-   * @class BayesNet BayesNet.h <agrum/BN/BayesNet.h>
+   * @class BayesNet
+   * @headerfile BayesNet.h <agrum/BN/BayesNet.h>
    * @brief Class representing a Bayesian Network.
    * @ingroup bn_group
    *
@@ -71,12 +72,25 @@ namespace gum {
    * You can print a BayesNet using
    * gum::operator<<(std::ostream&, const BayesNet<GUM_SCALAR>&).
    */
-  template <typename GUM_SCALAR>
-  class BayesNet : public IBayesNet<GUM_SCALAR> {
-
-    friend class BayesNetFactory<GUM_SCALAR>;
+  template < typename GUM_SCALAR >
+  class BayesNet : public IBayesNet< GUM_SCALAR > {
+    friend class BayesNetFactory< GUM_SCALAR >;
 
     public:
+    /**
+     * Create a bn with a dotlike syntax : 'a->b->c;b->d;'. The domain size maybe
+     * specified using 'a[10]' or using 'a{yes|maybe|no}'. Note that if the dotlike
+     * string contains such a
+     * specification  for an already defined variable, the first specification will
+     * be used.
+     *
+     * @param dotlike the string containing the specification
+     * @param domainSize the default domain size for variables
+     * @return the resulting bayesian network
+     */
+    static BayesNet< GUM_SCALAR > fastPrototype(const std::string& dotlike,
+                                                Size               domainSize = 2);
+
     // ===========================================================================
     /// @name Constructors and Destructor
     // ===========================================================================
@@ -92,17 +106,17 @@ namespace gum {
      *
      * @param name The BayesNet's name.
      */
-    BayesNet( std::string name );
+    explicit BayesNet(std::string name);
 
     /**
      * @brief Destructor.
      */
-    ~BayesNet();
+    ~BayesNet() final;
 
     /**
      * @brief Copy constructor.
      */
-    BayesNet( const BayesNet<GUM_SCALAR>& source );
+    BayesNet(const BayesNet< GUM_SCALAR >& source);
 
     /// @}
     // ===========================================================================
@@ -116,7 +130,7 @@ namespace gum {
      * @param source The copied BayesNet.
      * @return The copy of source.
      */
-    BayesNet<GUM_SCALAR>& operator=( const BayesNet<GUM_SCALAR>& source );
+    BayesNet< GUM_SCALAR >& operator=(const BayesNet< GUM_SCALAR >& source);
 
     /// @}
     // ===========================================================================
@@ -131,13 +145,13 @@ namespace gum {
      * @return The variable's CPT.
      * @throw NotFound If no variable's id matches varId.
      */
-    virtual const Potential<GUM_SCALAR>& cpt( NodeId varId ) const;
+    const Potential< GUM_SCALAR >& cpt(NodeId varId) const final;
 
     /**
      * @brief Returns the CPT of a variable.
      */
-    const Potential<GUM_SCALAR>& cpt( const std::string& name ) const {
-      return cpt( idFromName( name ) );
+    const Potential< GUM_SCALAR >& cpt(const std::string& name) const {
+      return cpt(idFromName(name));
     };
 
     /**
@@ -145,7 +159,7 @@ namespace gum {
      *
      * @return Returns a constant reference to the gum::VariableNodeMap.
      */
-    virtual const VariableNodeMap& variableNodeMap() const;
+    const VariableNodeMap& variableNodeMap() const final;
 
     /**
      * @brief Add a variable to the gum::BayesNet.
@@ -157,15 +171,15 @@ namespace gum {
      * The variable's gum::Potential implementation will be a
      * gum::MultiDimArray.
      *
-     * @param variable The variable added by copy.
+     * @param var The variable added by copy.
      * @return Returns the variable's id in the gum::BayesNet.
      * @throws DuplicateLabel Raised if variable.name() is already used in this
      *                        gum::BayesNet.
      */
-    NodeId add( const DiscreteVariable& variable );
+    NodeId add(const DiscreteVariable& var);
 
     /**
-    * @brief Shortcut for add(gum::LabelizedVariable(name,name,nbrmod))
+     * @brief Shortcut for add(gum::LabelizedVariable(name,name,nbrmod))
      *
      * Add a gum::LabelizedVariable to the gum::BayesNet
      *
@@ -175,7 +189,7 @@ namespace gum {
      *                        gum::BayesNet.
      * @throws NotAllowed if nbrmod<2
      */
-    NodeId add( const std::string& name, unsigned int nbrmod );
+    NodeId add(const std::string& name, unsigned int nbrmod);
 
     /**
      * @brief Add a variable to the gum::BayesNet.
@@ -185,15 +199,15 @@ namespace gum {
      *
      * The variable is added by copy to the gum::BayesNet.
      *
-     * @param variable The variable added by copy.
+     * @param var The variable added by copy.
      * @param aContent The gum::MultiDimImplementation to use for this
-     *                 varable's gum::Potential implementation.
+     *                 variable's gum::Potential implementation.
      * @return Returns the variable's id in the gum::BayesNet.
      * @throws DuplicateLabel Raised if variable.name() is already used in this
      *                        gum::BayesNet.
      */
-    NodeId add( const DiscreteVariable&             variable,
-                MultiDimImplementation<GUM_SCALAR>* aContent );
+    NodeId add(const DiscreteVariable&               var,
+               MultiDimImplementation< GUM_SCALAR >* aContent);
 
     /**
      * @brief Add a variable to the gum::BayesNet.
@@ -205,14 +219,14 @@ namespace gum {
      * The variable's gum::Potential implementation will be a
      * gum::MultiDimArray.
      *
-     * @param variable The variable added by copy.
+     * @param var The variable added by copy.
      * @param id The variable's forced gum::NodeId in the gum::BayesNet.
      * @return Returns the variable's id in the gum::BayesNet.
      * @throws DuplicateElement Raised id is already used.
      * @throws DuplicateLabel Raised if variable.name() is already used in this
      *                        gum::BayesNet.
      */
-    NodeId add( const DiscreteVariable& variable, NodeId id );
+    NodeId add(const DiscreteVariable& var, NodeId id);
 
     /**
      * @brief Add a variable to the gum::BayesNet.
@@ -220,18 +234,18 @@ namespace gum {
      * Add a gum::DiscreteVariable, it's associated gum::NodeId and it's
      * gum::Potential.
      *
-     * @param variable The variable added by copy.
+     * @param var The variable added by copy.
      * @param aContent The gum::MultiDimImplementation to use for this
-     *                 varable's gum::Potential implementation.
+     *                 variable's gum::Potential implementation.
      * @param id The variable's forced gum::NodeId in the gum::BayesNet.
      * @return Returns the variable's id in the gum::BayesNet.
      * @throws DuplicateElement Raised id is already used.
      * @throws DuplicateLabel Raised if variable.name() is already used in this
      *                        gum::BayesNet.
      */
-    NodeId add( const DiscreteVariable&             variable,
-                MultiDimImplementation<GUM_SCALAR>* aContent,
-                NodeId                              id );
+    NodeId add(const DiscreteVariable&               var,
+               MultiDimImplementation< GUM_SCALAR >* aContent,
+               NodeId                                id);
 
     /**
      * @brief Remove a variable from the gum::BayesNet.
@@ -241,14 +255,14 @@ namespace gum {
      *
      * If no variable matches the given id, then nothing is done.
      *
-     * @param id The variable's id to remove.
+     * @param varId The variable's id to remove.
      */
-    void erase( NodeId id );
+    void erase(NodeId varId);
 
     /**
      * @brief Removes a variable from the gum::BayesNet.
      */
-    void erase( const std::string& name ) { erase( idFromName( name ) ); };
+    void erase(const std::string& name) { erase(idFromName(name)); };
 
     /**
      * @brief Remove a variable from the gum::BayesNet.
@@ -260,7 +274,7 @@ namespace gum {
      *
      * @param var A reference on the variable to remove.
      */
-    void erase( const DiscreteVariable& var );
+    void erase(const DiscreteVariable& var);
 
     /**
      * @brief Returns a gum::DiscreteVariable given its gum::NodeId in the
@@ -272,14 +286,14 @@ namespace gum {
      * @throw NotFound Raised if id does not match a a variable in the
      *                 gum::BayesNet.
      */
-    const DiscreteVariable& variable( NodeId id ) const;
+    const DiscreteVariable& variable(NodeId id) const final;
 
     /**
      * @brief Returns a gum::DiscreteVariable given its gum::NodeId in the
      *        gum::BayesNet.
      */
-    const DiscreteVariable& variable( const std::string& name ) const {
-      return variable( idFromName( name ) );
+    const DiscreteVariable& variable(const std::string& name) const {
+      return variable(idFromName(name));
     };
 
     /**
@@ -291,14 +305,36 @@ namespace gum {
      *                        gum::BayesNet.
      * @throws NotFound Raised if no variable matches id.
      */
-    void changeVariableName( NodeId id, const std::string& new_name );
+    void changeVariableName(NodeId id, const std::string& new_name);
 
     /**
      * @brief Changes a variable's name.
      */
-    void changeVariableName( const std::string& name,
-                             const std::string& new_name ) {
-      changeVariableName( idFromName( name ), new_name );
+    void changeVariableName(const std::string& name, const std::string& new_name) {
+      changeVariableName(idFromName(name), new_name);
+    }
+
+    /**
+     * @brief Changes a variable's label in the gum::BayesNet.
+     *
+     * This will change the gum::LabelizedVariable names in the gum::BayesNet.
+     *
+     * @throws DuplicateLabel Raised if new_label is already used in this
+     *                        gum::LabelizedVariable.
+     * @throws NotFound Raised if no variable matches id or if the variable is not
+     * a LabelizedVariable
+     */
+    void changeVariableLabel(NodeId             id,
+                             const std::string& old_label,
+                             const std::string& new_label);
+
+    /**
+     * @brief Changes a variable's name.
+     */
+    void changeVariableLabel(const std::string& name,
+                             const std::string& old_label,
+                             const std::string& new_label) {
+      changeVariableLabel(idFromName(name), old_label, new_label);
     }
 
     /**
@@ -309,7 +345,7 @@ namespace gum {
      *         gum::BayesNet.
      * @throw NotFound If var is not in the gum::BayesNet.
      */
-    NodeId nodeId( const DiscreteVariable& var ) const;
+    NodeId nodeId(const DiscreteVariable& var) const final;
 
     /**
      * @brief Returns a variable's id given its name in the gum::BayesNet.
@@ -319,7 +355,7 @@ namespace gum {
      * @throw NotFound Raised if name does not match a variable in the
      * gum::BayesNet.
      */
-    NodeId idFromName( const std::string& name ) const;
+    NodeId idFromName(const std::string& name) const final;
 
     /**
      * @brief Returns a variable given its name in the gum::BayesNet.
@@ -330,7 +366,7 @@ namespace gum {
      * @throw NotFound Raised if name does not match a variable in the
      * gum::BayesNet.
      */
-    const DiscreteVariable& variableFromName( const std::string& name ) const;
+    const DiscreteVariable& variableFromName(const std::string& name) const final;
     /// @}
 
     // ===========================================================================
@@ -345,13 +381,13 @@ namespace gum {
      * @param tail as NodeId
      * @throw InvalidEdge If arc.tail and/or arc.head are not in the BN.
      */
-    void addArc( NodeId tail, NodeId head );
+    void addArc(NodeId tail, NodeId head);
 
     /**
      * Add an arc in the BN, and update arc.head's CPT.
      */
-    void addArc( const std::string& tail, const std::string& head ) {
-      addArc( idFromName( tail ), idFromName( head ) );
+    void addArc(const std::string& tail, const std::string& head) {
+      addArc(idFromName(tail), idFromName(head));
     }
 
     /**
@@ -360,7 +396,7 @@ namespace gum {
      * If (tail, head) doesn't exist, the nothing happens.
      * @param arc The arc removed.
      */
-    void eraseArc( const Arc& arc );
+    void eraseArc(const Arc& arc);
 
     /**
      * Removes an arc in the BN, and update head's CTP.
@@ -369,13 +405,13 @@ namespace gum {
      * @param head and
      * @param tail as NodeId
      */
-    void eraseArc( NodeId tail, NodeId head );
+    void eraseArc(NodeId tail, NodeId head);
 
     /**
      * Removes an arc in the BN, and update head's CTP.
      */
-    void eraseArc( const std::string& tail, const std::string& head ) {
-      eraseArc( idFromName( tail ), idFromName( head ) );
+    void eraseArc(const std::string& tail, const std::string& head) {
+      eraseArc(idFromName(tail), idFromName(head));
     }
 
     /**
@@ -406,11 +442,11 @@ namespace gum {
      * @throws InvalidArc exception if the arc does not exist or if its reversal
      * would induce a directed cycle. */
     /// @{
-    void reverseArc( NodeId tail, NodeId head );
-    void reverseArc( const std::string& tail, const std::string& head ) {
-      reverseArc( idFromName( tail ), idFromName( head ) );
+    void reverseArc(NodeId tail, NodeId head);
+    void reverseArc(const std::string& tail, const std::string& head) {
+      reverseArc(idFromName(tail), idFromName(head));
     }
-    void reverseArc( const Arc& arc );
+    void reverseArc(const Arc& arc);
     /// @}
 
     /// @}
@@ -429,19 +465,17 @@ namespace gum {
      * the gum::BayesNet::addNoisyOR as an alias for
      *gum::BayesNet::addNoisyORCompound
      *
-     * @param variable The variable added by copy.
-     * @param externalWeight see ref
+     * @param var The variable added by copy.
+     * @param external_weight see ref
      *gum::MultiDimNoisyORNet,gum::MultiDimNoisyORCompound
      * @return the id of the added variable.
      * @{
      */
 
-    NodeId addNoisyOR( const DiscreteVariable& variable,
-                       GUM_SCALAR              externalWeight );
-    NodeId addNoisyORNet( const DiscreteVariable& variable,
-                          GUM_SCALAR              externalWeight );
-    NodeId addNoisyORCompound( const DiscreteVariable& variable,
-                               GUM_SCALAR              externalWeight );
+    NodeId addNoisyOR(const DiscreteVariable& var, GUM_SCALAR external_weight);
+    NodeId addNoisyORNet(const DiscreteVariable& var, GUM_SCALAR external_weight);
+    NodeId addNoisyORCompound(const DiscreteVariable& var,
+                              GUM_SCALAR              external_weight);
     /** @} */
 
     /**
@@ -449,8 +483,8 @@ namespace gum {
      * it seems that the 'classical' noisyOR is the Compound noisyOR, we keep
      * the addNoisyOR as an alias for addNoisyORCompound.
      *
-     * @param variable The variable added by copy.
-     * @param externalWeight see gum::MultiDimNoisyORNet,
+     * @param var The variable added by copy.
+     * @param external_weight see gum::MultiDimNoisyORNet,
      *gum::MultiDimNoisyORCompound
      * @param id The chosen id
      * @warning give an id should be reserved for rare and specific situations
@@ -460,65 +494,63 @@ namespace gum {
      *
      * @{
      */
-    NodeId addNoisyOR( const DiscreteVariable& variable,
-                       GUM_SCALAR              externalWeight,
-                       NodeId                  id );
-    NodeId addNoisyORNet( const DiscreteVariable& variable,
-                          GUM_SCALAR              externalWeight,
-                          NodeId                  id );
-    NodeId addNoisyORCompound( const DiscreteVariable& variable,
-                               GUM_SCALAR              externalWeight,
-                               NodeId                  id );
+    NodeId addNoisyOR(const DiscreteVariable& var,
+                      GUM_SCALAR              external_weight,
+                      NodeId                  id);
+    NodeId addNoisyORNet(const DiscreteVariable& var,
+                         GUM_SCALAR              external_weight,
+                         NodeId                  id);
+    NodeId addNoisyORCompound(const DiscreteVariable& var,
+                              GUM_SCALAR              external_weight,
+                              NodeId                  id);
     /** @} */
 
     /**
      * Add a variable, its associate node and a noisyAND implementation.
      *
-     * @param variable The variable added by copy
-     * @param externalWeight see gum::MultiDimNoisyAND
+     * @param var The variable added by copy
+     * @param external_weight see gum::MultiDimNoisyAND
      * @param id proposed gum::nodeId for the variable
      * @warning give an id should be reserved for rare and specific situations
      *!!!
      * @return the id of the added variable.
      */
-    NodeId addNoisyAND( const DiscreteVariable& variable,
-                        GUM_SCALAR              externalWeight,
-                        NodeId                  id );
+    NodeId addNoisyAND(const DiscreteVariable& var,
+                       GUM_SCALAR              external_weight,
+                       NodeId                  id);
 
     /**
      * Add a variable, its associate node and a noisyAND implementation. The id
      *of the new variable is automatically generated.
      *
-     * @param variable The variable added by copy.
-     * @param externalWeight see gum::MultiDimNoisyAND
+     * @param var The variable added by copy.
+     * @param external_weight see gum::MultiDimNoisyAND
      * @return the id of the added variable.
      */
-    NodeId addNoisyAND( const DiscreteVariable& variable,
-                        GUM_SCALAR              externalWeight );
+    NodeId addNoisyAND(const DiscreteVariable& var, GUM_SCALAR external_weight);
 
     /**
      * Add a variable, its associate node and a Logit implementation.
      *
-     * @param variable The variable added by copy
-     * @param externalWeight see gum::MultiDimLogit
+     * @param var The variable added by copy
+     * @param external_weight see gum::MultiDimLogit
      * @param id proposed gum::nodeId for the variable
      * @warning give an id should be reserved for rare and specific situations
      *!!!
      * @return the id of the added variable.
      */
-    NodeId addLogit( const DiscreteVariable& variable,
-                     GUM_SCALAR              externalWeight,
-                     NodeId                  id );
+    NodeId
+      addLogit(const DiscreteVariable& var, GUM_SCALAR external_weight, NodeId id);
 
     /**
      * Add a variable, its associate node and a Logit implementation. The id of
      *the new variable is automatically generated.
      *
-     * @param variable The variable added by copy.
-     * @param externalWeight see gum::MultiDimLogit
+     * @param var The variable added by copy.
+     * @param external_weight see gum::MultiDimLogit
      * @return the id of the added variable.
      */
-    NodeId addLogit( const DiscreteVariable& variable, GUM_SCALAR externalWeight );
+    NodeId addLogit(const DiscreteVariable& var, GUM_SCALAR external_weight);
 
     /**
      * Add a variable, it's associate node and an OR implementation. The id of
@@ -527,11 +559,11 @@ namespace gum {
      * @warning OR is implemented as a gum::aggregator::Or which means that if
      *parents are not boolean, all value>1 is True
      *
-     * @param variable The variable added by copy.
+     * @param var The variable added by copy.
      * @return the id of the added variable.
      * @throws SizeError if variable.domainSize()>2
      */
-    NodeId addOR( const DiscreteVariable& variable );
+    NodeId addOR(const DiscreteVariable& var);
 
     /**
      * Add a variable, it's associate node and an AND implementation. The id of
@@ -540,23 +572,23 @@ namespace gum {
      * @warning AND is implemented as a gum::aggregator::And which means that if
      *parents are not boolean, all value>1 is True
      *
-     * @param variable The variable added by copy.
+     * @param var The variable added by copy.
      * @return the id of the added variable.
      * @throws SizeError if variable.domainSize()>2
      */
-    NodeId addAND( const DiscreteVariable& variable );
+    NodeId addAND(const DiscreteVariable& var);
 
     /**
      * Others aggregators
      * @{
      */
-    NodeId addAMPLITUDE( const DiscreteVariable& variable );
-    NodeId addCOUNT( const DiscreteVariable& variable, Idx Value = 1 );
-    NodeId addEXISTS( const DiscreteVariable& variable, Idx Value = 1 );
-    NodeId addFORALL( const DiscreteVariable& variable, Idx Value = 1 );
-    NodeId addMAX( const DiscreteVariable& variable );
-    NodeId addMEDIAN( const DiscreteVariable& variable );
-    NodeId addMIN( const DiscreteVariable& variable );
+    NodeId addAMPLITUDE(const DiscreteVariable& var);
+    NodeId addCOUNT(const DiscreteVariable& var, Idx value = 1);
+    NodeId addEXISTS(const DiscreteVariable& var, Idx value = 1);
+    NodeId addFORALL(const DiscreteVariable& var, Idx value = 1);
+    NodeId addMAX(const DiscreteVariable& var);
+    NodeId addMEDIAN(const DiscreteVariable& var);
+    NodeId addMIN(const DiscreteVariable& var);
     /**
      * @}
      */
@@ -569,63 +601,74 @@ namespace gum {
      * @throw InvalidArc If arc.tail and/or arc.head are not in the BN.
      * @throw InvalidArc If variable in arc.head is not a NoisyOR variable.
      */
-    void addWeightedArc( NodeId tail, NodeId head, GUM_SCALAR causalWeight );
+    void addWeightedArc(NodeId tail, NodeId head, GUM_SCALAR causalWeight);
 
+    /**
+     * Add an arc in the BN, and update arc.head's CPT.
+     *
+     * @param head and
+     * @param tail as std::string
+     * @param causalWeight see gum::MultiDimICIModel
+     * @param NotFound if no node with sun names is found
+     * @throw InvalidArc If arc.tail and/or arc.head are not in the BN.
+     * @throw InvalidArc If variable in arc.head is not a NoisyOR variable.
+     */
+    void addWeightedArc(const std::string& tail,
+                        const std::string& head,
+                        GUM_SCALAR         causalWeight) {
+      addWeightedArc(idFromName(tail), idFromName(head), causalWeight);
+    };
     /// @}
 
     /// randomly generates CPTs for a given structure
     void generateCPTs() const;
 
     /// randomly generate CPT for a given node in a given structure
-    void generateCPT( NodeId node ) const;
-    void generateCPT( const std::string& name ) const {
-      generateCPT( idFromName( name ) );
+    void generateCPT(NodeId node) const;
+    void generateCPT(const std::string& name) const {
+      generateCPT(idFromName(name));
     };
 
     /// change the CPT associated to nodeId to newPot
     /// delete the old CPT associated to nodeId.
     /// @throw NotAllowed if newPot has not the same signature as
     /// __probaMap[NodeId]
-    void changePotential( NodeId id, Potential<GUM_SCALAR>* newPot );
-    void changePotential( const std::string&     name,
-                          Potential<GUM_SCALAR>* newPot ) {
-      changePotential( idFromName( name ), newPot );
-    }
+    void changePotential(NodeId id, Potential< GUM_SCALAR >* newPot);
+    void changePotential(const std::string& name, Potential< GUM_SCALAR >* newPot);
 
     private:
     /// clear all potentials
     void __clearPotentials();
 
     /// copy of potentials from a BN to another, using names of vars as ref.
-    void __copyPotentials( const BayesNet<GUM_SCALAR>& bn );
+    void __copyPotentials(const BayesNet< GUM_SCALAR >& source);
 
     /// the map between variable and id
     VariableNodeMap __varMap;
 
     /// Mapping between the variable's id and their CPT.
-    NodeProperty<Potential<GUM_SCALAR>*> __probaMap;
+    NodeProperty< Potential< GUM_SCALAR >* > __probaMap;
     // HashTable<NodeId, Potential<GUM_SCALAR>* > __probaMap;
 
     /// change the CPT associated to nodeId to newPot
     /// delete the old CPT associated to nodeId.
     /// @warning no verification of dimensions are performer
     /// @see changePotential
-    void _unsafeChangePotential( NodeId id, Potential<GUM_SCALAR>* newPot );
+    void _unsafeChangePotential(NodeId id, Potential< GUM_SCALAR >* newPot);
 
     public:
-    using IBayesNet<GUM_SCALAR>::dag;
-    using IBayesNet<GUM_SCALAR>::size;
-    using IBayesNet<GUM_SCALAR>::nodes;
-    using IBayesNet<GUM_SCALAR>::log10DomainSize;
+    using IBayesNet< GUM_SCALAR >::dag;
+    using IBayesNet< GUM_SCALAR >::size;
+    using IBayesNet< GUM_SCALAR >::nodes;
+    using IBayesNet< GUM_SCALAR >::log10DomainSize;
   };
 
   /// Prints map's DAG in output using the Graphviz-dot format.
-  template <typename GUM_SCALAR>
-  std::ostream& operator<<( std::ostream&               output,
-                            const BayesNet<GUM_SCALAR>& map );
+  template < typename GUM_SCALAR >
+  std::ostream& operator<<(std::ostream& output, const BayesNet< GUM_SCALAR >& bn);
 
-  extern template class BayesNet<float>;
-  extern template class BayesNet<double>;
+  extern template class BayesNet< float >;
+  extern template class BayesNet< double >;
 
 } /* namespace gum */
 
