@@ -27,7 +27,7 @@
 #ifndef GUM_BAYES_NET_FRAGMENT_H
 #define GUM_BAYES_NET_FRAGMENT_H
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 
 #include <agrum/BN/IBayesNet.h>
 #include <agrum/graphs/parts/listeners/diGraphListener.h>
@@ -36,7 +36,8 @@
 
 namespace gum {
   /**
-   * @class BayesNetFragment BayesNetFragment.h <agrum/BN/BayesNetFragment.h>
+   * @class BayesNetFragment
+   * @headerfile BayesNetFragment.h <agrum/BN/BayesNetFragment.h>
    * @brief Portion of a BN identified by the list of nodes and a BayesNet.
    * @ingroup bn_group
    *
@@ -65,25 +66,26 @@ namespace gum {
    * installed nodes, either all the parents are installed or a local CPT is
    * defined.
    */
-  template <typename GUM_SCALAR>
-  class BayesNetFragment : public IBayesNet<GUM_SCALAR>,
-                           public gum::DiGraphListener {
+  template < typename GUM_SCALAR >
+  class BayesNetFragment
+      : public IBayesNet< GUM_SCALAR >
+      , public gum::DiGraphListener {
     private:
     /// The referred BayesNet
-    const IBayesNet<GUM_SCALAR>& __bn;
+    const IBayesNet< GUM_SCALAR >& __bn;
 
     /// Mapping between the variable's id and their CPT specific to this
     /// Fragment.
-    NodeProperty<const Potential<GUM_SCALAR>*> __localCPTs;
+    NodeProperty< const Potential< GUM_SCALAR >* > __localCPTs;
 
     public:
     /// @name Constructors / Destructors
     /// @{
     BayesNetFragment() = delete;
-    BayesNetFragment( const BayesNetFragment<GUM_SCALAR>& fragment ) = delete;
-    BayesNetFragment( BayesNetFragment<GUM_SCALAR>&& fragment ) = delete;
+    BayesNetFragment(const BayesNetFragment< GUM_SCALAR >& fragment) = delete;
+    BayesNetFragment(BayesNetFragment< GUM_SCALAR >&& fragment) = delete;
 
-    BayesNetFragment( const IBayesNet<GUM_SCALAR>& bn );
+    explicit BayesNetFragment(const IBayesNet< GUM_SCALAR >& bn);
 
     virtual ~BayesNetFragment();
     /// @}
@@ -94,63 +96,63 @@ namespace gum {
     /// the action to take when a new node is inserted into the graph
     /** @param src the object that sent the signal
      * @param id the id of the new node inserted into the graph */
-    virtual void whenNodeAdded( const void* src, NodeId id ) noexcept override;
+    virtual void whenNodeAdded(const void* src, NodeId id) noexcept override;
 
     /// the action to take when a node has just been removed from the graph
     /** @param src the object that sent the signal
      * @param id the id of the node has just been removed from the graph */
-    virtual void whenNodeDeleted( const void* src, NodeId id ) noexcept override;
+    virtual void whenNodeDeleted(const void* src, NodeId id) noexcept override;
 
     /// the action to take when a new arc is inserted into the graph
     /** @param src the object that sent the signal
      * @param from the id of tail of the new arc inserted into the graph
      * @param to the id of head of the new arc inserted into the graph */
     virtual void
-    whenArcAdded( const void* src, NodeId from, NodeId to ) noexcept override;
+      whenArcAdded(const void* src, NodeId from, NodeId to) noexcept override;
 
     /// the action to take when an arc has just been removed from the graph
     /** @param src the object that sent the signal
      * @param from the id of tail of the arc removed from the graph
      * @param to the id of head of the arc removed from the graph */
     virtual void
-    whenArcDeleted( const void* src, NodeId from, NodeId to ) noexcept override;
+      whenArcDeleted(const void* src, NodeId from, NodeId to) noexcept override;
     /// @}
 
     /// @name IBayesNet interface
     /// @{
 
     /**
-    * Returns the CPT of a variable.
-    *
-    * @throw NotFound If no variable's id matches varId.
-    */
-    virtual const Potential<GUM_SCALAR>& cpt( NodeId varId ) const override;
+     * Returns the CPT of a variable.
+     *
+     * @throw NotFound If no variable's id matches varId.
+     */
+    virtual const Potential< GUM_SCALAR >& cpt(NodeId varId) const override;
 
     /**
-    * Returns a constant reference to the VariableNodeMap of this BN
-    */
+     * Returns a constant reference to the VariableNodeMap of this BN
+     */
     virtual const VariableNodeMap& variableNodeMap() const override;
 
     /**
-    * Returns a constant reference over a variabe given it's node id.
-    *
-    * @throw NotFound If no variable's id matches varId.
-    */
-    virtual const DiscreteVariable& variable( NodeId id ) const override;
+     * Returns a constant reference over a variabe given it's node id.
+     *
+     * @throw NotFound If no variable's id matches varId.
+     */
+    virtual const DiscreteVariable& variable(NodeId id) const override;
 
     /**
-    * Return id node from discrete var pointer.
-    *
-    * @throw NotFound If no variable matches var.
-    */
-    virtual NodeId nodeId( const DiscreteVariable& var ) const override;
+     * Return id node from discrete var pointer.
+     *
+     * @throw NotFound If no variable matches var.
+     */
+    virtual NodeId nodeId(const DiscreteVariable& var) const override;
 
     /**
      * Getter by name
      *
      * @throw NotFound if no such name exists in the graph.
      */
-    virtual NodeId idFromName( const std::string& name ) const override;
+    virtual NodeId idFromName(const std::string& name) const override;
 
     /**
      * Getter by name
@@ -158,13 +160,13 @@ namespace gum {
      * @throw NotFound if no such name exists in the graph.
      */
     virtual const DiscreteVariable&
-    variableFromName( const std::string& name ) const override;
+      variableFromName(const std::string& name) const override;
 
     /**
      * creates a dot representing the whole referred BN hilighting the fragment.
      * @return Returns a dot representation of this fragment
      */
-    virtual std::string toDot( void ) const override;
+    virtual std::string toDot() const override;
 
     /// @}
 
@@ -174,7 +176,7 @@ namespace gum {
     /**
      * check if a certain NodeId exists in the fragment
      */
-    bool isInstalledNode( NodeId id ) const noexcept;
+    bool isInstalledNode(NodeId id) const noexcept;
 
     /**
      * install a node referenced by its nodeId
@@ -182,7 +184,7 @@ namespace gum {
      * @throw NotFound if the node does not exist in the referred BN
      * @warning nothing happens if the node is already installed
      */
-    void installNode( NodeId id );
+    void installNode(NodeId id);
 
     /**
      * install a node and all its ascendants
@@ -190,14 +192,14 @@ namespace gum {
      * @throw NotFound if the node does not exist in the referred BN
      * @warning nothing happens if the node is already installed
      */
-    void installAscendants( NodeId id );
+    void installAscendants(NodeId id);
 
     /**
      * uninstall a node referenced by its nodeId
      *
      * @warning nothing happens if the node is not installed
      */
-    void uninstallNode( NodeId id ) noexcept;
+    void uninstallNode(NodeId id) noexcept;
 
     /**
      * install a local marginal for a node into the fragment.
@@ -209,7 +211,7 @@ namespace gum {
      *variable
      *(or is not a marginal)
      **/
-    void installMarginal( NodeId id, const Potential<GUM_SCALAR>* pot );
+    void installMarginal(NodeId id, const Potential< GUM_SCALAR >* pot);
 
     /**
      * install a local cpt for a node into the fragment.
@@ -225,7 +227,7 @@ namespace gum {
      *or if
      * a variable in the CPT is not a parent in the referred bn.
      **/
-    void installCPT( NodeId id, const Potential<GUM_SCALAR>* pot );
+    void installCPT(NodeId id, const Potential< GUM_SCALAR >* pot);
 
     /**
      * uninstall a local CPT.
@@ -234,7 +236,7 @@ namespace gum {
      *is
      *not installed.
      */
-    void uninstallCPT( NodeId id ) noexcept;
+    void uninstallCPT(NodeId id) noexcept;
 
     /**
      * returns true if the nodeId's (local or not) cpt is consistent with its
@@ -242,7 +244,7 @@ namespace gum {
      * in the fragment
      * @throw NotFound if the id is not in the fragment
      */
-    bool checkConsistency( NodeId id ) const;
+    bool checkConsistency(NodeId id) const;
 
     /**
      * returns true if all nodes in the fragment are consistent
@@ -251,33 +253,33 @@ namespace gum {
 
     /// @}
 
-    using IBayesNet<GUM_SCALAR>::nodes;
-    using IBayesNet<GUM_SCALAR>::dag;
+    using IBayesNet< GUM_SCALAR >::nodes;
+    using IBayesNet< GUM_SCALAR >::dag;
 
     protected:
     // remove an arc
-    void _uninstallArc( NodeId from, NodeId to ) noexcept;
+    void _uninstallArc(NodeId from, NodeId to) noexcept;
 
     // add an arc
-    void _installArc( NodeId from, NodeId to ) noexcept;
+    void _installArc(NodeId from, NodeId to) noexcept;
 
     // install a CPT, create or delete arcs. Checks are made in public methods
     // In particular, it is assumed that all the variables in the pot are in the
     // fragment
-    void _installCPT( NodeId id, const Potential<GUM_SCALAR>* pot ) noexcept;
+    void _installCPT(NodeId id, const Potential< GUM_SCALAR >* pot) noexcept;
 
     /**
      * uninstall a local CPT. Does nothing if no local CPT for this nodeId
      * No check. No change in the topology. Checks are made in public methods.
      */
-    void _uninstallCPT( NodeId id ) noexcept;
+    void _uninstallCPT(NodeId id) noexcept;
   };
 
-  extern template class BayesNetFragment<float>;
-  extern template class BayesNetFragment<double>;
+  extern template class BayesNetFragment< float >;
+  extern template class BayesNetFragment< double >;
 
-}  // namespace gum
+}   // namespace gum
 
 #include <agrum/BN/BayesNetFragment_tpl.h>
 
-#endif  // GUM_BAYES_NET_FRAGMENT_H
+#endif   // GUM_BAYES_NET_FRAGMENT_H
