@@ -29,7 +29,7 @@
 
 #include <utility>
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 
 #include <agrum/core/hashTable.h>
 
@@ -38,11 +38,12 @@
 
 namespace gum {
 
-  template <typename GUM_SCALAR>
+  template < typename GUM_SCALAR >
   class BayesNetFactory;
 
   /**
-   * @class IBayesNet IBayesNet.h <agrum/BN/IBayesNet.h>
+   * @class IBayesNet
+   * @headerfile IBayesNet.h <agrum/BN/IBayesNet.h>
    * @brief Class representing the minimal interface for Bayesian Network.
    * @ingroup bn_group
    *
@@ -54,9 +55,8 @@ namespace gum {
    *instance) may use this
    * class when a simple BN is needed.
    */
-  template <typename GUM_SCALAR>
+  template < typename GUM_SCALAR >
   class IBayesNet : public DAGmodel {
-
     public:
     // ===========================================================================
     /// @name Constructors / Destructors
@@ -67,7 +67,7 @@ namespace gum {
      * Default constructor.
      */
     IBayesNet();
-    IBayesNet( std::string name );
+    explicit IBayesNet(std::string name);
 
     /**
      * Destructor.
@@ -77,12 +77,12 @@ namespace gum {
     /**
      * Copy constructor.
      */
-    IBayesNet( const IBayesNet<GUM_SCALAR>& source );
+    IBayesNet(const IBayesNet< GUM_SCALAR >& source);
 
     /**
      * Copy operator.
      */
-    IBayesNet<GUM_SCALAR>& operator=( const IBayesNet<GUM_SCALAR>& source );
+    IBayesNet< GUM_SCALAR >& operator=(const IBayesNet< GUM_SCALAR >& source);
 
     /// @}
     // ===========================================================================
@@ -91,37 +91,37 @@ namespace gum {
     /// @{
 
     /**
-    * Returns the CPT of a variable.
-    *
-    * @throw NotFound If no variable's id matches varId.
-    */
-    virtual const Potential<GUM_SCALAR>& cpt( NodeId varId ) const = 0;
+     * Returns the CPT of a variable.
+     *
+     * @throw NotFound If no variable's id matches varId.
+     */
+    virtual const Potential< GUM_SCALAR >& cpt(NodeId varId) const = 0;
 
     /**
-    * Returns a constant reference to the VariableNodeMap of thisBN
-    */
+     * Returns a constant reference to the VariableNodeMap of thisBN
+     */
     virtual const VariableNodeMap& variableNodeMap() const = 0;
 
     /**
-    * Returns a constant reference over a variable given it's node id.
-    *
-    * @throw NotFound If no variable's id matches varId.
-    */
-    virtual const DiscreteVariable& variable( NodeId id ) const = 0;
+     * Returns a constant reference over a variable given it's node id.
+     *
+     * @throw NotFound If no variable's id matches varId.
+     */
+    virtual const DiscreteVariable& variable(NodeId id) const = 0;
 
     /**
-    * Return id node from discrete var pointer.
-    *
-    * @throw NotFound If no variable matches var.
-    */
-    virtual NodeId nodeId( const DiscreteVariable& var ) const = 0;
+     * Return id node from discrete var pointer.
+     *
+     * @throw NotFound If no variable matches var.
+     */
+    virtual NodeId nodeId(const DiscreteVariable& var) const = 0;
 
     /**
      * Getter by name
      *
      * @throw NotFound if no such name exists in the graph.
      */
-    virtual NodeId idFromName( const std::string& name ) const = 0;
+    virtual NodeId idFromName(const std::string& name) const = 0;
 
     /**
      * Getter by name
@@ -129,7 +129,7 @@ namespace gum {
      * @throw NotFound if no such name exists in the graph.
      */
     virtual const DiscreteVariable&
-    variableFromName( const std::string& name ) const = 0;
+      variableFromName(const std::string& name) const = 0;
     /// @}
 
     // ===========================================================================
@@ -141,13 +141,13 @@ namespace gum {
     /// instantiation of the vars)
     /// @warning a variable not present in the instantiation is assumed to be
     /// instantiated to 0.
-    GUM_SCALAR jointProbability( const Instantiation& i ) const;
+    GUM_SCALAR jointProbability(const Instantiation& i) const;
 
     /// Compute a parameter of the log joint probability for the BN (given an
     /// instantiation of the vars)
     /// @warning a variable not present in the instantiation is assumed to be
     /// instantiated to 0.
-    GUM_SCALAR log2JointProbability( const Instantiation& i ) const;
+    GUM_SCALAR log2JointProbability(const Instantiation& i) const;
 
     ///
     /// @}
@@ -159,10 +159,10 @@ namespace gum {
      *
      * @return true if the src and this are equal.
      */
-    bool operator==( const IBayesNet<GUM_SCALAR>& src ) const;
+    bool operator==(const IBayesNet< GUM_SCALAR >& from) const;
 
     /// @return Returns false if the src and this are equal.
-    bool operator!=( const IBayesNet<GUM_SCALAR>& src ) const;
+    bool operator!=(const IBayesNet< GUM_SCALAR >& from) const;
 
     /**
      * Returns the dimension (the number of free parameters) in this bayes net.
@@ -207,47 +207,48 @@ namespace gum {
     GUM_SCALAR maxNonOneParam() const;
 
     /// @return Returns a dot representation of this IBayesNet.
-    virtual std::string toDot( void ) const;
+    virtual std::string toDot() const;
 
     /// @return Returns a string representation of this IBayesNet.
-    std::string toString( void ) const;
+    std::string toString() const;
 
     /***
      * @return the minimal subset of soids that conditions the target
      *
      * i.e. P(target| soids)=P(target|@return)
      */
-    NodeSet minimalCondSet( NodeId target, const NodeSet& soids ) const;
+    NodeSet minimalCondSet(NodeId target, const NodeSet& soids) const;
+
 
     /***
      * @return the minimal subset of soids that conditions the targets
      *
      * i.e. P(targets| soids)=P(targets|@return)
      */
-    NodeSet minimalCondSet( const NodeSet& target, const NodeSet& soids ) const;
+    NodeSet minimalCondSet(const NodeSet& targets, const NodeSet& soids) const;
 
     private:
-    void __minimalCondSetVisitUp( NodeId         node,
-                                  const NodeSet& soids,
-                                  NodeSet&       minimal,
-                                  NodeSet&       alreadyVisitedUp,
-                                  NodeSet&       alreadyVisitedDn ) const;
-    void __minimalCondSetVisitDn( NodeId         node,
-                                  const NodeSet& soids,
-                                  NodeSet&       minimal,
-                                  NodeSet&       alreadyVisitedUp,
-                                  NodeSet&       alreadyVisitedDn ) const;
+    void __minimalCondSetVisitUp(NodeId         node,
+                                 const NodeSet& soids,
+                                 NodeSet&       minimal,
+                                 NodeSet&       alreadyVisitedUp,
+                                 NodeSet&       alreadyVisitedDn) const;
+    void __minimalCondSetVisitDn(NodeId         node,
+                                 const NodeSet& soids,
+                                 NodeSet&       minimal,
+                                 NodeSet&       alreadyVisitedUp,
+                                 NodeSet&       alreadyVisitedDn) const;
   };
 
 
-  extern template class IBayesNet<float>;
-  extern template class IBayesNet<double>;
+  extern template class IBayesNet< float >;
+  extern template class IBayesNet< double >;
 
 
   /// Prints map's DAG in output using the Graphviz-dot format.
-  template <typename GUM_SCALAR>
-  std::ostream& operator<<( std::ostream&                output,
-                            const IBayesNet<GUM_SCALAR>& map );
+  template < typename GUM_SCALAR >
+  std::ostream& operator<<(std::ostream&                  output,
+                           const IBayesNet< GUM_SCALAR >& bn);
 
 } /* namespace gum */
 
