@@ -26,18 +26,19 @@
 #ifndef GUM_I_CPT_GENERATOR_H
 #define GUM_I_CPT_GENERATOR_H
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 #include <agrum/multidim/potential.h>
 
 namespace gum {
-  /** @class ICPTGenerator ICPTGenerator.h <agrum/BN/generator/ICPTGenerator.h>
+  /** @class ICPTGenerator
+   * @headerfile ICPTGenerator.h <agrum/BN/generator/ICPTGenerator.h>
    * @brief Abstract class for generating Conditional Probability Tables.
    * @ingroup bn_generator
    *
    * This abstract class is an implementation of the strategy pattern to
    * help changing CPT generation policies for the BayesNetGenerator class.
    */
-  template <typename GUM_SCALAR>
+  template < typename GUM_SCALAR >
   class ICPTGenerator {
     public:
     // ############################################################################
@@ -64,15 +65,15 @@ namespace gum {
      * @param varId The variable id of the CPT owner.
      * @param cpt A reference on the CPT to fill.
      */
-    virtual void generateCPT( const Idx&                   varId,
-                              const Potential<GUM_SCALAR>& cpt ) = 0;
+    virtual void generateCPT(const Idx&                     varId,
+                             const Potential< GUM_SCALAR >& cpt) = 0;
     /// @}
   };
 
-  extern template class ICPTGenerator<float>;
-  extern template class ICPTGenerator<double>;
+  extern template class ICPTGenerator< float >;
+  extern template class ICPTGenerator< double >;
 
 } /* namespace gum */
 
-#include <agrum/BN/generator/ICPTGenerator.tcc>
+#include <agrum/BN/generator/ICPTGenerator_tpl.h>
 #endif /* GUM_I_CPT_GENERATOR_H */
