@@ -27,7 +27,7 @@
 #ifndef GUM_MC_BAYES_NET_GENERATOR
 #define GUM_MC_BAYES_NET_GENERATOR
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 
 #include <fstream>
 #include <iostream>
@@ -37,9 +37,9 @@
 #include <sstream>
 
 #ifdef HAVE_DIRENT_H
-#include <dirent.h>
+#  include <dirent.h>
 #else
-#include <agrum/core/mvsc/dirent.h>
+#  include <agrum/core/mvsc/dirent.h>
 #endif
 
 #include <agrum/BN/BayesNet.h>
@@ -151,11 +151,12 @@ namespace gum {
   }
    \enddot
    */
-  template <typename GUM_SCALAR,
-            template <typename> class ICPTGenerator = SimpleCPTGenerator,
-            template <typename> class ICPTDisturber = SimpleCPTDisturber>
-  class MCBayesNetGenerator : public IBayesNetGenerator<GUM_SCALAR, ICPTGenerator>,
-                              public ICPTDisturber<GUM_SCALAR> {
+  template < typename GUM_SCALAR,
+             template < typename > class ICPTGenerator = SimpleCPTGenerator,
+             template < typename > class ICPTDisturber = SimpleCPTDisturber >
+  class MCBayesNetGenerator
+      : public IBayesNetGenerator< GUM_SCALAR, ICPTGenerator >
+      , public ICPTDisturber< GUM_SCALAR > {
     public:
     // ############################################################################
     /// @name Constructors / Destructor
@@ -178,37 +179,37 @@ namespace gum {
      * probability_p_q
      * "use of p and q" )
      */
-    MCBayesNetGenerator( Size nbrNodes,
-                         Size maxArcs,
-                         Idx  maxModality = 2,
-                         Size iteration = 5000,
-                         Idx  p = 30,
-                         Idx  q = 40 );
+    MCBayesNetGenerator(Size nbrNodes,
+                        Size maxArcs,
+                        Idx  maxModality = 2,
+                        Size iteration = 5000,
+                        Idx  p = 30,
+                        Idx  q = 40);
 
     /**
-    * Constructor.
-    * Use by default the SimpleCPTGenerator for generating the BNs CPT
-    * and the SimpleCPTDisturber to tweak the CPT when the dimension of the
-    * table
-    * changes.
-    * @param bayesNet the IBayesNet used as reference to fill the parameters
-    * nbrNodes, maxArcs and maxModality
-    * @param iteration The number of iterations wanted to repeat the algorithm
-    * @param p probability for the change of the state (see \ref probability_p_q
-    * )
-    * @param q probability for the change of the state (see \ref probability_p_q
-    * )
-    */
-    MCBayesNetGenerator( BayesNet<GUM_SCALAR> bayesNet,
-                         Size                 iteration = 5000,
-                         Idx                  p = 30,
-                         Idx                  q = 40 );
+     * Constructor.
+     * Use by default the SimpleCPTGenerator for generating the BNs CPT
+     * and the SimpleCPTDisturber to tweak the CPT when the dimension of the
+     * table
+     * changes.
+     * @param bayesNet the IBayesNet used as reference to fill the parameters
+     * nbrNodes, maxArcs and maxModality
+     * @param iteration The number of iterations wanted to repeat the algorithm
+     * @param p probability for the change of the state (see \ref probability_p_q
+     * )
+     * @param q probability for the change of the state (see \ref probability_p_q
+     * )
+     */
+    explicit MCBayesNetGenerator(BayesNet< GUM_SCALAR > bayesNet,
+                                 Size                   iteration = 5000,
+                                 Idx                    p = 30,
+                                 Idx                    q = 40);
 
     /**
-    * Destructor.
-    */
+     * Destructor.
+     */
 
-    ~MCBayesNetGenerator();
+    ~MCBayesNetGenerator() override;
 
     /// @}
 
@@ -221,20 +222,20 @@ namespace gum {
      * @param bayesNet empty IBayesNet to generate.
      * @return null but modify inputed Bayesian Network
      */
-    void generateBN( BayesNet<GUM_SCALAR>& bayesNet );
+    void generateBN(BayesNet< GUM_SCALAR >& bayesNet) override;
 
     /**
-    * Change randomly the topology of a specific bayesian networks.
-    * @param bayesNetinit IBayesNet to be modify
-    * @param iteration The number of iterations wanted to repeat the algorithm
-    * @return null but modify inputed Bayesian Network
-    * @throws OperationNotAllow if the initial state of the IBayesNet is not
-    * respecting the wanted conditions
-    * if iteration = 0, it is assumed that the number of iteration wanted is the
-    * same
-    * as the one specified in the constructor
-    */
-    void disturbBN( BayesNet<GUM_SCALAR>& bayesNetinit, Size iteration = 0 );
+     * Change randomly the topology of a specific bayesian networks.
+     * @param bayesNetinit IBayesNet to be modify
+     * @param iteration The number of iterations wanted to repeat the algorithm
+     * @return null but modify inputed Bayesian Network
+     * @throws OperationNotAllow if the initial state of the IBayesNet is not
+     * respecting the wanted conditions
+     * if iteration = 0, it is assumed that the number of iteration wanted is the
+     * same
+     * as the one specified in the constructor
+     */
+    void disturbBN(BayesNet< GUM_SCALAR >& bayesNetinit, Size iteration = 0);
 
     ///@}
 
@@ -251,40 +252,40 @@ namespace gum {
      */
     Size iteration() const;
     /**
-    * Return a constant reference to the probabilité p imposed on the Markov
-    * Chain
-    * BayesNetGenerator.
-    */
+     * Return a constant reference to the probabilité p imposed on the Markov
+     * Chain
+     * BayesNetGenerator.
+     */
     Idx p() const;
     /**
-    * Return a constant reference to the probabilité imposed on the Markov Chain
-    * BayesNetGenerator.
-    */
+     * Return a constant reference to the probabilité imposed on the Markov Chain
+     * BayesNetGenerator.
+     */
     Idx q() const;
 
     ///@name Setters
 
     /**
-    * Modifies the value of the number of iterations impose on the
-    * BayesNetGenerator
-    */
-    void setIteration( Size iteration );
+     * Modifies the value of the number of iterations impose on the
+     * BayesNetGenerator
+     */
+    void setIteration(Size iteration);
     /**
-    * Modifies the value of the probability p imposed on the BayesNetGenerator
-    */
-    void setP( Idx p );
+     * Modifies the value of the probability p imposed on the BayesNetGenerator
+     */
+    void setP(Idx p);
     /**
-    * Modifies the value of the probability q imposed on the BayesNetGenerator
-    */
-    void setQ( Idx q );
+     * Modifies the value of the probability q imposed on the BayesNetGenerator
+     */
+    void setQ(Idx q);
 
     /// @}
     protected:
-    Size                 _iteration;
-    Idx                  _p, _q;
-    bool                 _disturbing;
-    BayesNet<GUM_SCALAR> _bayesNettemp;
-    HashTable<NodeId, Potential<GUM_SCALAR>*> _hashMarginal;
+    Size                                          _iteration;
+    Idx                                           _p, _q;
+    bool                                          _disturbing;
+    BayesNet< GUM_SCALAR >                        _bayesNettemp;
+    HashTable< NodeId, Potential< GUM_SCALAR >* > _hashMarginal;
 
     /**
      * The function that verify if graph is a polytree.
@@ -293,45 +294,45 @@ namespace gum {
     /**
      * The function that verify if node i and j are connected.
      **/
-    bool __connect( const NodeId i, const NodeId j );
+    bool __connect(NodeId i, NodeId j);
     /**
      * The function that verify if there is a oriented path from node i to node
      *j.
      **/
-    bool __directedPath( const NodeId i, const NodeId j );
+    bool __directedPath(NodeId tail, NodeId head);
     /**
      * The function that will insert an arc between node i to node j, but only
      *if
      *there isn't any cycle created.
      **/
-    void __insertArc( NodeId i, NodeId j );
+    void __insertArc(NodeId i, NodeId j);
     /**
      * The function that will remove the arc between node i and node j. If the
      *boolean parameter mustbeconnex is true, the function will assert that the
      *graph
      *remain connected and will restore the arc otherwise.
      **/
-    void __eraseArc( NodeId i, NodeId j, bool mustbeconnex = true );
+    void __eraseArc(NodeId i, NodeId j, bool mustbeconnex = true);
 
     /**
-    * In the case that the graph is a polytree, the function will, according to
-    *the
-    *probability p and q, choose which change of state must occure( AorR or AR
-    *or
-    *jump) then will assert that the imposed constraint are respected and if
-    *not,
-    *will return to the previous topology.
-    **/
+     * In the case that the graph is a polytree, the function will, according to
+     *the
+     *probability p and q, choose which change of state must occure( AorR or AR
+     *or
+     *jump) then will assert that the imposed constraint are respected and if
+     *not,
+     *will return to the previous topology.
+     **/
 
     void __PMMx_poly();
     /**
-    * In the case that the graph is a multiconnected graph, the function will,
-    *according to the probability p and q, choose which change of state must
-    *occure(
-    *AorR or jump) then will assert that the imposed constraint are respected
-    *and if
-    *not, will return to the previous topology.
-    **/
+     * In the case that the graph is a multiconnected graph, the function will,
+     *according to the probability p and q, choose which change of state must
+     *occure(
+     *AorR or jump) then will assert that the imposed constraint are respected
+     *and if
+     *not, will return to the previous topology.
+     **/
     void __PMMx_multi();
     /**
      * In the case that the graph is a polytree, the function will add a ramdom
@@ -357,9 +358,9 @@ namespace gum {
      **/
     void __AorR();
     /**
-    * The function will remove and add a random arc changing the topology of the
-    *graph but asserting its connectivity.
-    **/
+     * The function will remove and add a random arc changing the topology of the
+     *graph but asserting its connectivity.
+     **/
     void __AR();
     /**
      * The boolean function that will assert the respect of the constraint.
@@ -379,36 +380,36 @@ namespace gum {
      *listed in excluded.
      **/
 
-    bool __connect( const NodeId i, const NodeId j, NodeSet& excluded );
+    bool __connect(NodeId i, NodeId j, NodeSet& excluded);
 
     /**
      * The internal function used by the previous __directedPath. It asserts the
      *existence of an oriented path between node i and node j avoiding passing
      *through nodes listed in excluded.
      **/
-    bool __directedPath( const NodeId tail, const NodeId head, NodeSet& excluded );
+    bool __directedPath(NodeId tail, NodeId head, NodeSet& excluded);
 
     /**
      * The function that randomly choose two nodes of the graph.
      **/
 
-    void __chooseNodes( NodeId& i, NodeId& j );
+    void __chooseNodes(NodeId& i, NodeId& j);
 
     /**
      * The function that randomly choose two neighbours nodes of the graph.
      **/
-    void __chooseCloseNodes( NodeId& i, NodeId& j );
+    void __chooseCloseNodes(NodeId& i, NodeId& j);
 
     /**
      * The function that randomly change the simple tree into a polytree.
      **/
 
-    void __transformPoly( Idx nbiter );
+    void __transformPoly(Idx nbiter);
 
     /**
      * The function that randomly generate a simple tree.
      **/
-    void __createTree( Size BNSize );
+    void __createTree(Size BNSize);
 
     /**
      * The internal function used by __createTree that randomly generate a
@@ -416,14 +417,14 @@ namespace gum {
      *tree.
      * n : id number for node label
      **/
-    NodeId __createPartTree( Size BNSize, Idx& n );
+    NodeId __createPartTree(Size BNSize, Idx& n);
   };
 
 
-  extern template class MCBayesNetGenerator<float>;
-  extern template class MCBayesNetGenerator<double>;
+  extern template class MCBayesNetGenerator< float >;
+  extern template class MCBayesNetGenerator< double >;
 
 } /*namespace gum*/
 
-#include <agrum/BN/generator/MCBayesNetGenerator.tcc>
-#endif  // MCBAYESNETGENERATOR
+#include <agrum/BN/generator/MCBayesNetGenerator_tpl.h>
+#endif   // MCBAYESNETGENERATOR
