@@ -18,7 +18,7 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 /** @file
- * @brief Class for generating bayesian netwroks.
+ * @brief Class for generating bayesian networks.
  *
  * @author Christophe GONZALES and Pierre-Henri WUILLEMIN and Ariele-Paolo
  *MAESANO
@@ -33,7 +33,7 @@
 #include <vector>
 
 #include <agrum/BN/generator/IBayesNetGenerator.h>
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 
 namespace gum {
 
@@ -51,10 +51,10 @@ namespace gum {
    *density of the Bayesian Network to be too high
    * resulting in the failure of most of the inference Methods.
    */
-  template <typename GUM_SCALAR,
-            template <typename> class ICPTGenerator = SimpleCPTGenerator>
+  template < typename GUM_SCALAR,
+             template < typename > class ICPTGenerator = SimpleCPTGenerator >
   class SimpleBayesNetGenerator
-      : public IBayesNetGenerator<GUM_SCALAR, ICPTGenerator> {
+      : public IBayesNetGenerator< GUM_SCALAR, ICPTGenerator > {
     public:
     // ############################################################################
     /// @name Constructors / Destructor
@@ -62,18 +62,18 @@ namespace gum {
     /// @{
 
     /**
-    * Constructor.
-    * Use by default the SimpleCPTGenerator for generating the BNs CPT.
-    * @param nbrNodes The number of nodes imposed on the generator.
-    * @param maxArcs The number of maximum arcs imposed on the generator.
-    * @param maxModality Each DRV has from 2 to maxModality modalities
-    */
-    SimpleBayesNetGenerator( Size nbrNodes, Size maxArcs, Size maxModality = 2 );
+     * Constructor.
+     * Use by default the SimpleCPTGenerator for generating the BNs CPT.
+     * @param nbrNodes The number of nodes imposed on the generator.
+     * @param maxArcs The number of maximum arcs imposed on the generator.
+     * @param maxModality Each DRV has from 2 to maxModality modalities
+     */
+    SimpleBayesNetGenerator(Size nbrNodes, Size maxArcs, Size maxModality = 2);
 
     /**
      * Destructor.
      */
-    ~SimpleBayesNetGenerator();
+    ~SimpleBayesNetGenerator() override;
     /// @}
 
     // ############################################################################
@@ -81,22 +81,22 @@ namespace gum {
     // ############################################################################
     /// @{
     /**
-    * function that generates a bayesian networks.
+     * function that generates a bayesian networks.
      * @param bayesNet Bayesian Network to be completed after initialisation
      * @return null but modify inputed Bayesian Network
      */
-    void generateBN( BayesNet<GUM_SCALAR>& bayesNet );
+    void generateBN(BayesNet< GUM_SCALAR >& bayesNet) override;
 
     /// @}
   }; /* class SimpleBayesNetGenerator */
 
 
-  extern template class SimpleBayesNetGenerator<float>;
-  extern template class SimpleBayesNetGenerator<double>;
+  extern template class SimpleBayesNetGenerator< float >;
+  extern template class SimpleBayesNetGenerator< double >;
 
 
 } /* namespace gum */
 
-#include <agrum/BN/generator/simpleBayesNetGenerator.tcc>
+#include <agrum/BN/generator/simpleBayesNetGenerator_tpl.h>
 
 #endif /* GUM_SIMPLE_BAYES_NET_GENERATOR_H */
