@@ -30,30 +30,30 @@
 #include <cmath>
 #include <utility>
 
-#include <agrum/BN/inference/barrenNodesFinder.h>
-#include <agrum/BN/inference/evidenceInference.h>
-#include <agrum/BN/inference/jointTargetedInference.h>
-#include <agrum/BN/inference/relevantPotentialsFinderType.h>
-#include <agrum/config.h>
-#include <agrum/graphs/triangulations/defaultTriangulation.h>
+#include <agrum/BN/algorithms/barrenNodesFinder.h>
+#include <agrum/BN/inference/tools/evidenceInference.h>
+#include <agrum/BN/inference/tools/jointTargetedInference.h>
+#include <agrum/BN/inference/tools/relevantPotentialsFinderType.h>
+#include <agrum/agrum.h>
+#include <agrum/graphs/algorithms/triangulations/defaultTriangulation.h>
 
 namespace gum {
 
 
   // the function used to combine two tables
-  template <typename GUM_SCALAR>
-  INLINE static Potential<GUM_SCALAR>*
-  LPNewmultiPotential( const Potential<GUM_SCALAR>& t1,
-                       const Potential<GUM_SCALAR>& t2 ) {
-    return new Potential<GUM_SCALAR>( t1 * t2 );
+  template < typename GUM_SCALAR >
+  INLINE static Potential< GUM_SCALAR >*
+    LPNewmultiPotential(const Potential< GUM_SCALAR >& t1,
+                        const Potential< GUM_SCALAR >& t2) {
+    return new Potential< GUM_SCALAR >(t1 * t2);
   }
 
   // the function used to combine two tables
-  template <typename GUM_SCALAR>
-  INLINE static Potential<GUM_SCALAR>*
-  LPNewprojPotential( const Potential<GUM_SCALAR>&        t1,
-                      const Set<const DiscreteVariable*>& del_vars ) {
-    return new Potential<GUM_SCALAR>( t1.margSumOut( del_vars ) );
+  template < typename GUM_SCALAR >
+  INLINE static Potential< GUM_SCALAR >*
+    LPNewprojPotential(const Potential< GUM_SCALAR >&        t1,
+                       const Set< const DiscreteVariable* >& del_vars) {
+    return new Potential< GUM_SCALAR >(t1.margSumOut(del_vars));
   }
 
 
@@ -64,9 +64,10 @@ namespace gum {
    * propagation for inference in Bayesian Networks
    * @ingroup bn_inference
    */
-  template <typename GUM_SCALAR>
-  class LazyPropagation : public JointTargetedInference<GUM_SCALAR>,
-                          public EvidenceInference<GUM_SCALAR> {
+  template < typename GUM_SCALAR >
+  class LazyPropagation
+      : public JointTargetedInference< GUM_SCALAR >
+      , public EvidenceInference< GUM_SCALAR > {
     public:
     // ############################################################################
     /// @name Constructors / Destructors
@@ -74,14 +75,22 @@ namespace gum {
     /// @{
 
     /// default constructor
-    LazyPropagation( const IBayesNet<GUM_SCALAR>* BN,
-                     RelevantPotentialsFinderType =
-                         RelevantPotentialsFinderType::DSEP_BAYESBALL_POTENTIALS,
-                     FindBarrenNodesType = FindBarrenNodesType::FIND_BARREN_NODES,
-                     bool use_binary_join_tree = true );
+    explicit LazyPropagation(
+      const IBayesNet< GUM_SCALAR >* BN,
+      RelevantPotentialsFinderType =
+        RelevantPotentialsFinderType::DSEP_BAYESBALL_POTENTIALS,
+      FindBarrenNodesType = FindBarrenNodesType::FIND_BARREN_NODES,
+      bool use_binary_join_tree = true);
+
+    /// avoid copy constructors
+    LazyPropagation(const LazyPropagation< GUM_SCALAR >&) = delete;
+
+    /// avoid copy operators
+    LazyPropagation< GUM_SCALAR >&
+      operator=(const LazyPropagation< GUM_SCALAR >&) = delete;
 
     /// destructor
-    virtual ~LazyPropagation();
+    ~LazyPropagation() final;
 
     /// @}
 
@@ -92,7 +101,7 @@ namespace gum {
     /// @{
 
     /// use a new triangulation algorithm
-    void setTriangulation( const Triangulation& new_triangulation );
+    void setTriangulation(const Triangulation& new_triangulation);
 
     /// sets how we determine the relevant potentials to combine
     /** When a clique sends a message to a separator, it first constitute the
@@ -103,7 +112,7 @@ namespace gum {
      * If RelevantPotentialsFinderType = DSEP_BAYESBALL_NODES, then only the
      * set of potentials d-connected to the variables of the separator are kept
      * for combination and projection. */
-    void setRelevantPotentialsFinderType( RelevantPotentialsFinderType type );
+    void setRelevantPotentialsFinderType(RelevantPotentialsFinderType type);
 
     /// sets how we determine barren nodes
     /** Barren nodes are unnecessary for probability inference, so they can
@@ -111,7 +120,7 @@ namespace gum {
      * speeds-up inference. However, there are some cases in which we do not
      * want to remove barren nodes, typically when we want to answer queries
      * such as Most Probable Explanations (MPE). */
-    void setFindBarrenNodesType( FindBarrenNodesType type );
+    void setFindBarrenNodesType(FindBarrenNodesType type);
 
 
     /// returns the current join tree used
@@ -127,20 +136,20 @@ namespace gum {
      **/
     const JunctionTree* junctionTree();
     /// returns the probability of evidence
-    GUM_SCALAR evidenceProbability();
+    GUM_SCALAR evidenceProbability() final;
 
     /// @}
 
 
     protected:
     /// fired after a new evidence is inserted
-    virtual void _onEvidenceAdded( const NodeId id, bool isHardEvidence );
+    void _onEvidenceAdded(NodeId id, bool isHardEvidence) final;
 
     /// fired before an evidence is removed
-    virtual void _onEvidenceErased( const NodeId id, bool isHardEvidence );
+    void _onEvidenceErased(NodeId id, bool isHardEvidence) final;
 
     /// fired before all the evidence are erased
-    virtual void _onAllEvidenceErased( bool contains_hard_evidence );
+    void _onAllEvidenceErased(bool has_hard_evidence) final;
 
     /** @brief fired after an evidence is changed, in particular when its status
      * (soft/hard) changes
@@ -149,61 +158,64 @@ namespace gum {
      * @param hasChangedSoftHard true if the evidence has changed from Soft to
      * Hard or from Hard to Soft
      */
-    virtual void _onEvidenceChanged( const NodeId id, bool hasChangedSoftHard );
+    void _onEvidenceChanged(NodeId id, bool hasChangedSoftHard) final;
 
     /// fired after a new single target is inserted
     /** @param id The target variable's id. */
-    virtual void _onMarginalTargetAdded( const NodeId id );
+    void _onMarginalTargetAdded(NodeId id) final;
 
     /// fired before a single target is removed
     /** @param id The target variable's id. */
-    virtual void _onMarginalTargetErased( const NodeId id );
+    void _onMarginalTargetErased(NodeId id) final;
 
     /// fired after a new joint target is inserted
     /** @param set The set of target variable's ids. */
-    virtual void _onJointTargetAdded( const NodeSet& set );
+    void _onJointTargetAdded(const NodeSet& set) final;
 
     /// fired before a joint target is removed
     /** @param set The set of target variable's ids. */
-    virtual void _onJointTargetErased( const NodeSet& set );
+    void _onJointTargetErased(const NodeSet& set) final;
 
     /// fired after all the nodes of the BN are added as single targets
-    virtual void _onAllMarginalTargetsAdded();
+    void _onAllMarginalTargetsAdded() final;
 
     /// fired before a all the single targets are removed
-    virtual void _onAllMarginalTargetsErased();
+    void _onAllMarginalTargetsErased() final;
 
     /// fired before a all the joint targets are removed
-    virtual void _onAllJointTargetsErased();
+    void _onAllJointTargetsErased() final;
 
     /// fired before a all single and joint_targets are removed
-    virtual void _onAllTargetsErased();
+    void _onAllTargetsErased() final;
+
+    /// fired when the stage is changed
+    void _onStateChanged() final{};
 
     /// prepares inference when the latter is in OutdatedBNStructure state
     /** Note that the values of evidence are not necessarily
      * known and can be changed between _updateOutdatedBNStructure and
      * _makeInference. */
-    virtual void _updateOutdatedBNStructure();
+    void _updateOutdatedBNStructure() final;
 
     /// prepares inference when the latter is in OutdatedBNPotentials state
     /** Note that the values of evidence are not necessarily
      * known and can be changed between _updateOutdatedBNPotentials and
      * _makeInference. */
-    virtual void _updateOutdatedBNPotentials();
+    void _updateOutdatedBNPotentials() final;
 
     /// called when the inference has to be performed effectively
     /** Once the inference is done, _fillPosterior can be called. */
-    virtual void _makeInference();
+    void _makeInference() final;
 
 
     /// returns the posterior of a given variable
     /** @param id The variable's id. */
-    virtual const Potential<GUM_SCALAR>& _posterior( const NodeId id );
+    const Potential< GUM_SCALAR >& _posterior(NodeId id) final;
 
     /// returns the posterior of a declared target set
     /** @param set The set of ids of the variables whose joint posterior is
      * looked for. */
-    virtual const Potential<GUM_SCALAR>& _jointPosterior( const NodeSet& set );
+    const Potential< GUM_SCALAR >& _jointPosterior(const NodeSet& set) final;
 
     /** @brief asks derived classes for the joint posterior of a set of
      * variables not declared as a joint target
@@ -212,21 +224,21 @@ namespace gum {
      * posterior is looked for.
      * @param declared_target the joint target declared by the user that contains
      * set */
-    virtual const Potential<GUM_SCALAR>&
-    _jointPosterior( const NodeSet& wanted_target,
-                     const NodeSet& declared_target );
+    const Potential< GUM_SCALAR >&
+      _jointPosterior(const NodeSet& wanted_target,
+                      const NodeSet& declared_target) final;
 
     /// returns a fresh potential equal to P(argument,evidence)
-    virtual Potential<GUM_SCALAR>* _unnormalizedJointPosterior( const NodeId id );
+    Potential< GUM_SCALAR >* _unnormalizedJointPosterior(NodeId id) final;
 
     /// returns a fresh potential equal to P(argument,evidence)
-    virtual Potential<GUM_SCALAR>*
-    _unnormalizedJointPosterior( const NodeSet& set );
+    Potential< GUM_SCALAR >* _unnormalizedJointPosterior(const NodeSet& set) final;
 
 
     private:
-    typedef Set<const Potential<GUM_SCALAR>*>             __PotentialSet;
-    typedef SetIteratorSafe<const Potential<GUM_SCALAR>*> __PotentialSetIterator;
+    typedef Set< const Potential< GUM_SCALAR >* > __PotentialSet;
+    typedef SetIteratorSafe< const Potential< GUM_SCALAR >* >
+      __PotentialSetIterator;
 
 
     /// the type of relevant potential finding algorithm to be used
@@ -234,22 +246,22 @@ namespace gum {
 
     /** @brief update a set of potentials: the remaining are those to be
      * combined to produce a message on a separator */
-    void ( LazyPropagation<GUM_SCALAR>::*__findRelevantPotentials )(
-        Set<const Potential<GUM_SCALAR>*>& pot_list,
-        Set<const DiscreteVariable*>&      kept_vars );
+    void (LazyPropagation< GUM_SCALAR >::*__findRelevantPotentials)(
+      Set< const Potential< GUM_SCALAR >* >& pot_list,
+      Set< const DiscreteVariable* >&        kept_vars);
 
     /// the type of barren nodes computation we wish
     FindBarrenNodesType __barren_nodes_type;
 
     /// the operator for performing the projections
-    Potential<GUM_SCALAR>* ( *__projection_op )(
-        const Potential<GUM_SCALAR>&,
-        const Set<const DiscreteVariable*>& ){LPNewprojPotential};
+    Potential< GUM_SCALAR >* (*__projection_op)(
+      const Potential< GUM_SCALAR >&,
+      const Set< const DiscreteVariable* >&){LPNewprojPotential};
 
     /// the operator for performing the combinations
-    Potential<GUM_SCALAR>* ( *__combination_op )( const Potential<GUM_SCALAR>&,
-                                                  const Potential<GUM_SCALAR>& ){
-        LPNewmultiPotential};
+    Potential< GUM_SCALAR >* (*__combination_op)(const Potential< GUM_SCALAR >&,
+                                                 const Potential< GUM_SCALAR >&){
+      LPNewmultiPotential};
 
     /// the triangulation class creating the junction tree used for inference
     Triangulation* __triangulation;
@@ -268,6 +280,7 @@ namespace gum {
 
     /// the join (or junction) tree used to answer the last inference query
     JoinTree* __JT{nullptr};
+
     /// the junction tree to answer the last inference query
     JunctionTree* __junctionTree{nullptr};
 
@@ -287,10 +300,10 @@ namespace gum {
     NodeSet __roots;
 
     /// for each node of __graph (~ in the Bayes net), associate an ID in the JT
-    HashTable<NodeId, NodeId> __node_to_clique;
+    HashTable< NodeId, NodeId > __node_to_clique;
 
     /// for each set target, assign a clique in the JT that contains it
-    HashTable<NodeSet, NodeId> __joint_target_to_clique;
+    HashTable< NodeSet, NodeId > __joint_target_to_clique;
 
     /// the list of all potentials stored in the cliques
     /** This structure contains a list for each clique in the join tree. If
@@ -298,12 +311,12 @@ namespace gum {
      * the entry for the clique does exist. Note that clique potentials
      * contain also soft evidence and the CPTs that were projected to
      * remove their variables that received hard evidence. */
-    NodeProperty<__PotentialSet> __clique_potentials;
+    NodeProperty< __PotentialSet > __clique_potentials;
 
     /// the list of all potentials stored in the separators after inferences
     /** This structure contains all the arcs of the join tree (edges in both
      * directions) whether the arc received any potential or not. */
-    ArcProperty<__PotentialSet> __separator_potentials;
+    ArcProperty< __PotentialSet > __separator_potentials;
 
     /// the set of potentials created for the last inference messages
     /** This structure contains only the arcs on which potentials have
@@ -311,28 +324,28 @@ namespace gum {
      * @warning Note that the CPTs that were projected due to hard
      * evidence do not belong to this structure, they are kept in
      * __hard_ev_projected_CPTs. */
-    ArcProperty<__PotentialSet> __created_potentials;
+    ArcProperty< __PotentialSet > __created_potentials;
 
     /// the set of single posteriors computed during the last inference
     /** the posteriors are owned by LazyPropagation. */
-    NodeProperty<const Potential<GUM_SCALAR>*> __target_posteriors;
+    NodeProperty< const Potential< GUM_SCALAR >* > __target_posteriors;
 
     /// the set of set target posteriors computed during the last inference
     /** the posteriors are owned by LazyPropagation. */
-    HashTable<NodeSet, const Potential<GUM_SCALAR>*> __joint_target_posteriors;
+    HashTable< NodeSet, const Potential< GUM_SCALAR >* > __joint_target_posteriors;
 
     /** @brief the constants resulting from the projections of CPTs defined
      * over only hard evidence nodes
      * @TODO remove this constant and insert the notion of a constant into
      * potentials/multidim arrays */
-    NodeProperty<GUM_SCALAR> __constants;
+    NodeProperty< GUM_SCALAR > __constants;
 
     /// indicates whether a message (from one clique to another) has been
     /// computed
     /** Here, all the messages, computed or not, are put into the property, only
      * the Boolean makes the difference between messages computed and those that
      * were not computed */
-    ArcProperty<bool> __messages_computed;
+    ArcProperty< bool > __messages_computed;
 
     /// the soft evidence stored in the cliques per their assigned node in the BN
     /** This variable is useful for method _updateOutdatedBNPotentials: it
@@ -341,14 +354,14 @@ namespace gum {
      * @warning These potentials are not owned by LazyPropagation, they are only
      * referenced by it. Only the cliques that contain evidence are
      * filled in this structure. */
-    NodeProperty<const Potential<GUM_SCALAR>*> __node_to_soft_evidence;
+    NodeProperty< const Potential< GUM_SCALAR >* > __node_to_soft_evidence;
 
     /// the CPTs that were projected due to hard evidence nodes
     /** For each node whose CPT is defined over some nodes that contain some
      * hard evidence, assigns a new projected CPT that does not contain
      * these nodes anymore.
      * @warning These potentials are owned by LayPropagation. */
-    NodeProperty<const Potential<GUM_SCALAR>*> __hard_ev_projected_CPTs;
+    NodeProperty< const Potential< GUM_SCALAR >* > __hard_ev_projected_CPTs;
 
     /// the hard evidence nodes which were projected in CPTs
     NodeSet __hard_ev_nodes;
@@ -358,10 +371,10 @@ namespace gum {
 
     /** @brief indicates which nodes of the BN have evidence that changed
      * since the last inference */
-    NodeProperty<EvidenceChangeType> __evidence_changes;
+    NodeProperty< EvidenceChangeType > __evidence_changes;
 
     /// for comparisons with 1 - epsilon
-    const GUM_SCALAR __1_minus_epsilon{GUM_SCALAR( 1.0 - 1e-6 )};
+    const GUM_SCALAR __1_minus_epsilon{GUM_SCALAR(1.0 - 1e-6)};
 
 
     /// check whether a new join tree is really needed for the next inference
@@ -370,17 +383,17 @@ namespace gum {
     /// create a new junction tree as well as its related data structures
     void __createNewJT();
     /// sets the operator for performing the projections
-    void __setProjectionFunction( Potential<GUM_SCALAR>* ( *proj )(
-        const Potential<GUM_SCALAR>&, const Set<const DiscreteVariable*>&));
+    void __setProjectionFunction(Potential< GUM_SCALAR >* (*proj)(
+      const Potential< GUM_SCALAR >&, const Set< const DiscreteVariable* >&));
 
     /// sets the operator for performing the combinations
-    void __setCombinationFunction( Potential<GUM_SCALAR>* ( *comb )(
-        const Potential<GUM_SCALAR>&, const Potential<GUM_SCALAR>&));
+    void __setCombinationFunction(Potential< GUM_SCALAR >* (*comb)(
+      const Potential< GUM_SCALAR >&, const Potential< GUM_SCALAR >&));
 
     /// invalidate all the messages sent from a given clique
-    void __diffuseMessageInvalidations( const NodeId from,
-                                        const NodeId to,
-                                        NodeSet&     cliques_invalidated );
+    void __diffuseMessageInvalidations(NodeId   from_id,
+                                       NodeId   to_id,
+                                       NodeSet& invalidated_cliques);
 
     /// invalidate all messages, posteriors and created potentials
     void __invalidateAllMessages();
@@ -392,59 +405,53 @@ namespace gum {
      * combined
      * to produce a message on a separator */
     void __findRelevantPotentialsWithdSeparation(
-        __PotentialSet& pot_list, Set<const DiscreteVariable*>& kept_vars );
+      __PotentialSet& pot_list, Set< const DiscreteVariable* >& kept_vars);
 
     /** @brief update a set of potentials: the remaining are those to be
      * combined
      * to produce a message on a separator */
     void __findRelevantPotentialsWithdSeparation2(
-        __PotentialSet& pot_list, Set<const DiscreteVariable*>& kept_vars );
+      __PotentialSet& pot_list, Set< const DiscreteVariable* >& kept_vars);
 
     /** @brief update a set of potentials: the remaining are those to be
      * combined
      * to produce a message on a separator */
     void __findRelevantPotentialsWithdSeparation3(
-        __PotentialSet& pot_list, Set<const DiscreteVariable*>& kept_vars );
+      __PotentialSet& pot_list, Set< const DiscreteVariable* >& kept_vars);
 
     /** @brief update a set of potentials: the remaining are those to be
      * combined
      * to produce a message on a separator */
-    void __findRelevantPotentialsGetAll( __PotentialSet&               pot_list,
-                                         Set<const DiscreteVariable*>& kept_vars );
+    void __findRelevantPotentialsGetAll(__PotentialSet&                 pot_list,
+                                        Set< const DiscreteVariable* >& kept_vars);
 
     /** @brief update a set of potentials: the remaining are those to be
      * combined
      * to produce a message on a separator */
-    void __findRelevantPotentialsXX( __PotentialSet&               pot_list,
-                                     Set<const DiscreteVariable*>& kept_vars );
+    void __findRelevantPotentialsXX(__PotentialSet&                 pot_list,
+                                    Set< const DiscreteVariable* >& kept_vars);
 
     // remove barren variables and return the newly created projected potentials
     __PotentialSet
-    __removeBarrenVariables( __PotentialSet&               pot_list,
-                             Set<const DiscreteVariable*>& del_vars );
+      __removeBarrenVariables(__PotentialSet&                 pot_list,
+                              Set< const DiscreteVariable* >& del_vars);
 
     /** @brief removes variables del_vars from a list of potentials and
      * returns the resulting list */
-    __PotentialSet __marginalizeOut( __PotentialSet                pot_list,
-                                     Set<const DiscreteVariable*>& del_vars,
-                                     Set<const DiscreteVariable*>& kept_vars );
+    __PotentialSet __marginalizeOut(__PotentialSet                  pot_list,
+                                    Set< const DiscreteVariable* >& del_vars,
+                                    Set< const DiscreteVariable* >& kept_vars);
 
     /// creates the message sent by clique from_id to clique to_id
-    void __produceMessage( const NodeId from_id, const NodeId to_id );
+    void __produceMessage(NodeId from_id, NodeId to_id);
 
     /// actually perform the collect phase
-    void __collectMessage( const NodeId id, const NodeId from );
-
-    /// avoid copy constructors
-    LazyPropagation( const LazyPropagation<GUM_SCALAR>& );
-
-    /// avoid copy operators
-    LazyPropagation<GUM_SCALAR>& operator=( const LazyPropagation<GUM_SCALAR>& );
+    void __collectMessage(NodeId id, NodeId from);
   };
 
 
-  extern template class LazyPropagation<float>;
-  extern template class LazyPropagation<double>;
+  extern template class LazyPropagation< float >;
+  extern template class LazyPropagation< double >;
 
 
 } /* namespace gum */
@@ -452,4 +459,3 @@ namespace gum {
 #include <agrum/BN/inference/lazyPropagation_tpl.h>
 
 #endif /* GUM_LAZY_PROPAGATION_H */
-// kate: indent-mode cstyle; indent-width 2; replace-tabs on; ;
