@@ -75,10 +75,10 @@ between 0 and 100
 #include <string>
 
 #include <agrum/BN/io/BNReader.h>
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 #include <agrum/core/signal/signaler.h>
 #include <agrum/core/signal/signaler2.h>
-#include <agrum/core/tinyxml/ticpp/ticpp.h>
+#include <agrum/external/tinyxml/ticpp/ticpp.h>
 #include <agrum/variables/labelizedVariable.h>
 
 namespace gum {
@@ -95,20 +95,20 @@ namespace gum {
    * for information about this format.
    *
    */
-  template <typename GUM_SCALAR>
-  class BIFXMLBNReader : BNReader<GUM_SCALAR> {
+  template < typename GUM_SCALAR >
+  class BIFXMLBNReader : BNReader< GUM_SCALAR > {
     public:
     /**
      * Constructor
      * A reader is created to reading a defined file.
      * Note that an BN as to be created before and given in parameter.
      */
-    BIFXMLBNReader( BayesNet<GUM_SCALAR>* bn, const std::string& filePath );
+    BIFXMLBNReader(BayesNet< GUM_SCALAR >* bn, const std::string& filePath);
 
     /**
      * Default destructor.
      */
-    ~BIFXMLBNReader();
+    ~BIFXMLBNReader() final;
 
     /**
      * Reads the bayes net from the file referenced by filePath  given at the
@@ -116,31 +116,31 @@ namespace gum {
      * @return Returns 0 if no error, 1 if any
      * @warning XMLBNReader can not give the number of errors.
      */
-    virtual Size proceed();
+    Size proceed() final;
 
     /**
      * Signaler used to indicates how many percent of the Xml files have been
      * parsed
      * yet
      */
-    typename gum::Signaler2<int, std::string> onProceed;
+    typename gum::Signaler2< int, std::string > onProceed;
 
     private:
     /**
      * Parsing xml element containing data on variables
      */
-    void __parsingVariables( ticpp::Element* parentNetwork );
+    void __parsingVariables(ticpp::Element* parentNetwork);
 
     /**
      * fill the diagram
      */
-    void __fillingBN( ticpp::Element* parentNetwork );
+    void __fillingBN(ticpp::Element* parentNetwork);
 
     /**
      * An handle to the bayes net in which will be load the content of the xml
      * filePath
      */
-    BayesNet<GUM_SCALAR>* __bn;
+    BayesNet< GUM_SCALAR >* __bn;
 
     /**
      * the path to the xml filePath
@@ -149,11 +149,11 @@ namespace gum {
   };
 
 
-  extern template class BIFXMLBNReader<float>;
-  extern template class BIFXMLBNReader<double>;
+  extern template class BIFXMLBNReader< float >;
+  extern template class BIFXMLBNReader< double >;
 
 } /* namespace gum */
 
 #include <agrum/BN/io/BIFXML/BIFXMLBNReader_tpl.h>
 
-#endif  // GUM_BIF_XML_BN_READER_H
+#endif   // GUM_BIF_XML_BN_READER_H
