@@ -31,7 +31,7 @@
 #define GUM_BN_READER_H
 
 #include <agrum/BN/BayesNet.h>
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 #include <iostream>
 #include <string>
 
@@ -40,14 +40,15 @@ namespace gum {
   /* ===                               READERS                            === */
   /* =========================================================================*/
   /**
-   * @class BNReader BNReader.h <agrum/BN/io/BNReader.h>
+   * @class BNReader
+   * @headerfile BNReader.h <agrum/BN/io/BNReader.h>
    * @ingroup bn_io
    * @brief Pure virtual class for reading a BN from a file.
    *
    * Every class used to read the content of a Bayesian Network from a stream,
    * or a file must be a subclass of BNReader.
    */
-  template <typename GUM_SCALAR>
+  template < typename GUM_SCALAR >
   class BNReader {
     public:
     /**
@@ -57,7 +58,7 @@ namespace gum {
      * Note that the BN has to be built outside the reader. There is no
      * delegation to create/destroy the BN from inside the reader.
      */
-    BNReader( BayesNet<GUM_SCALAR>* bn, const std::string& filename );
+    BNReader(BayesNet< GUM_SCALAR >* bn, const std::string& filename);
 
     /**
      * Default destructor.
@@ -73,11 +74,11 @@ namespace gum {
   };
 
 
-  extern template class BNReader<float>;
-  extern template class BNReader<double>;
+  extern template class BNReader< float >;
+  extern template class BNReader< double >;
 
 } /* namespace gum */
 
 #include <agrum/BN/io/BNReader_tpl.h>
 
-#endif  // GUM_BN_READER_H
+#endif   // GUM_BN_READER_H
