@@ -36,7 +36,7 @@
 #include <string>
 
 #include <agrum/BN/io/BNWriter.h>
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 
 namespace gum {
   /**
@@ -50,8 +50,8 @@ namespace gum {
    * cf. http://www.cs.huji.ac.il/project/PASCAL/fileFormat.php
    *
    */
-  template <typename GUM_SCALAR>
-  class UAIWriter : public BNWriter<GUM_SCALAR> {
+  template < typename GUM_SCALAR >
+  class UAIWriter : public BNWriter< GUM_SCALAR > {
     public:
     // ==========================================================================
     /// @name Constructor & destructor
@@ -66,7 +66,7 @@ namespace gum {
     /**
      * Destructor.
      */
-    virtual ~UAIWriter();
+    ~UAIWriter() final;
 
     /// @}
 
@@ -77,7 +77,7 @@ namespace gum {
      * @param bn The bayes net writen in the stream.
      * @throws IOError Raised if an I/O error occurs.
      */
-    virtual void write( std::ostream& output, const IBayesNet<GUM_SCALAR>& bn );
+    void write(std::ostream& output, const IBayesNet< GUM_SCALAR >& bn) final;
 
     /**
      * Writes an bayes net in the file referenced by filePath.
@@ -88,22 +88,23 @@ namespace gum {
      * @param bn The bayes net writen in the file.
      * @throw IOError Raised if an I/O error occurs.
      */
-    virtual void write( std::string filePath, const IBayesNet<GUM_SCALAR>& bn );
+    void write(const std::string&             filePath,
+               const IBayesNet< GUM_SCALAR >& bn) final;
 
     private:
     /**
      * Returns the header of the BIF file.
      */
-    std::string __preambule( const IBayesNet<GUM_SCALAR>& bn );
+    std::string __preambule(const IBayesNet< GUM_SCALAR >& bn);
 
-    std::string __cptBloc( const IBayesNet<GUM_SCALAR>& bn, NodeId node );
+    std::string __cptBloc(const IBayesNet< GUM_SCALAR >& bn, NodeId node);
   };
 
 
-  extern template class UAIWriter<float>;
-  extern template class UAIWriter<double>;
+  extern template class UAIWriter< float >;
+  extern template class UAIWriter< double >;
 
 } /* namespace gum */
 
 #include <agrum/BN/io/UAI/UAIWriter_tpl.h>
-#endif  // GUM_UAIWRITER_H
+#endif   // GUM_UAIWRITER_H
