@@ -37,12 +37,13 @@
 
 #include <agrum/BN/io/BNWriter.h>
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 
 namespace gum {
 
   /**
-   * @class NetWriter netWriter.h <agrum/BN/io/net/netWriter.h>
+   * @class NetWriter
+   * @headerfile netWriter.h <agrum/BN/io/net/netWriter.h>
    * @brief Writes a IBayesNet in the BN format.
    * @ingroup bn_io
    *
@@ -52,8 +53,8 @@ namespace gum {
    * for information on this format.
    *
    */
-  template <typename GUM_SCALAR>
-  class NetWriter : public BNWriter<GUM_SCALAR> {
+  template < typename GUM_SCALAR >
+  class NetWriter : public BNWriter< GUM_SCALAR > {
     public:
     // ==========================================================================
     /// @name Constructor & destructor
@@ -68,7 +69,7 @@ namespace gum {
     /**
      * Destructor.
      */
-    virtual ~NetWriter();
+    ~NetWriter() final;
 
     /// @}
 
@@ -79,7 +80,7 @@ namespace gum {
      * @param bn The Bayesian Network writen in output.
      * @throws IOError Raised if and I/O error occurs.
      */
-    virtual void write( std::ostream& output, const IBayesNet<GUM_SCALAR>& bn );
+    void write(std::ostream& output, const IBayesNet< GUM_SCALAR >& bn) final;
 
     /**
      * Writes a Bayesian Network in the referenced file using the BN format.
@@ -89,26 +90,27 @@ namespace gum {
      * @param bn The Bayesian Network writed in the file.
      * @throws IOError Raised if and I/O error occurs.
      */
-    virtual void write( std::string filePath, const IBayesNet<GUM_SCALAR>& bn );
+    void write(const std::string&             filePath,
+               const IBayesNet< GUM_SCALAR >& bn) final;
 
     private:
     // Returns the header of the BN file.
-    std::string __header( const IBayesNet<GUM_SCALAR>& bn );
+    std::string __header(const IBayesNet< GUM_SCALAR >& bn);
 
     // Returns a bloc defining a variable in the BN format.
-    std::string __variableBloc( const DiscreteVariable& var );
+    std::string __variableBloc(const DiscreteVariable& var);
 
     // Returns a bloc defining a variable's CPT in the BN format.
-    std::string __variableCPT( const Potential<GUM_SCALAR>& cpt );
+    std::string __variableCPT(const Potential< GUM_SCALAR >& cpt);
 
     // Returns the modalities labels of the variables in varsSeq
   };
 
 
-  extern template class NetWriter<float>;
-  extern template class NetWriter<double>;
+  extern template class NetWriter< float >;
+  extern template class NetWriter< double >;
 
 } /* namespace gum */
 
 #include <agrum/BN/io/net/netWriter_tpl.h>
-#endif  // GUM_NET_WRITER_H
+#endif   // GUM_NET_WRITER_H
