@@ -51,7 +51,6 @@ namespace gum {
    *
    */
   class E_GreedyDecider : public IDecisionStrategy {
-
     // ###################################################################
     /// @name Constructor & destructor.
     // ###################################################################
@@ -77,7 +76,7 @@ namespace gum {
     // ==========================================================================
     /// Initializes the learner
     // ==========================================================================
-    void initialize( const FMDP<double>* fmdp );
+    void initialize(const FMDP< double >* fmdp);
 
     /// @}
 
@@ -87,9 +86,9 @@ namespace gum {
     // ###################################################################
     /// @{
     public:
-    void checkState( const Instantiation& newState, Idx actionId );
+    void checkState(const Instantiation& newState, Idx actionId);
 
-    ActionSet stateOptimalPolicy( const Instantiation& curState );
+    ActionSet stateOptimalPolicy(const Instantiation& curState);
 
     /// @}
 
@@ -97,5 +96,5 @@ namespace gum {
     StatesChecker __statecpt;
     double        __sss;
   };
-}
-#endif  // GUM_E_GREEDY_DECIDER_H
+}   // namespace gum
+#endif   // GUM_E_GREEDY_DECIDER_H
