@@ -45,9 +45,8 @@ namespace gum {
    * @ingroup fmdp_group
    *
    */
-  template <typename GUM_SCALAR>
+  template < typename GUM_SCALAR >
   class IOperatorStrategy {
-
     // ###################################################################
     /// @name Constructor & destructor.
     // ###################################################################
@@ -66,13 +65,13 @@ namespace gum {
     // ###################################################################
     /// @{
 
-    virtual MultiDimFunctionGraph<GUM_SCALAR, ExactTerminalNodePolicy>*
-    getFunctionInstance() = 0;
-    virtual MultiDimFunctionGraph<ArgMaxSet<GUM_SCALAR, Idx>,
-                                  SetTerminalNodePolicy>*
-    getArgMaxFunctionInstance() = 0;
-    virtual MultiDimFunctionGraph<ActionSet, SetTerminalNodePolicy>*
-    getAggregatorInstance() = 0;
+    virtual MultiDimFunctionGraph< GUM_SCALAR, ExactTerminalNodePolicy >*
+      getFunctionInstance() = 0;
+    virtual MultiDimFunctionGraph< ArgMaxSet< GUM_SCALAR, Idx >,
+                                   SetTerminalNodePolicy >*
+      getArgMaxFunctionInstance() = 0;
+    virtual MultiDimFunctionGraph< ActionSet, SetTerminalNodePolicy >*
+      getAggregatorInstance() = 0;
 
     /// @}
 
@@ -88,83 +87,83 @@ namespace gum {
     /// @return qAction : the computed Q(s,a)
     /// @warning given qAction is deleted, return the new one
     // ==========================================================================
-    virtual MultiDimFunctionGraph<GUM_SCALAR>*
-    regress( const MultiDimFunctionGraph<GUM_SCALAR>* Vold,
-             Idx                                      actionId,
-             const FMDP<GUM_SCALAR>*                  fmdp,
-             const Set<const DiscreteVariable*>&      elVarSeq ) = 0;
+    virtual MultiDimFunctionGraph< GUM_SCALAR >*
+      regress(const MultiDimFunctionGraph< GUM_SCALAR >* Vold,
+              Idx                                        actionId,
+              const FMDP< GUM_SCALAR >*                  fmdp,
+              const Set< const DiscreteVariable* >&      elVarSeq) = 0;
 
     // ==========================================================================
     /// @warning given vFunction and qAction are deleted, returns the new one
     // ==========================================================================
-    virtual MultiDimFunctionGraph<GUM_SCALAR>*
-    maximize( const MultiDimFunctionGraph<GUM_SCALAR>* f1,
-              const MultiDimFunctionGraph<GUM_SCALAR>* f2,
-              Idx                                      del = 3 ) = 0;
+    virtual MultiDimFunctionGraph< GUM_SCALAR >*
+      maximize(const MultiDimFunctionGraph< GUM_SCALAR >* f1,
+               const MultiDimFunctionGraph< GUM_SCALAR >* f2,
+               Idx                                        del = 3) = 0;
 
     // ==========================================================================
     /// @warning Minimze the two given functions
     // ==========================================================================
-    virtual MultiDimFunctionGraph<GUM_SCALAR>*
-    minimize( const MultiDimFunctionGraph<GUM_SCALAR>* f1,
-              const MultiDimFunctionGraph<GUM_SCALAR>* f2,
-              Idx                                      del = 3 ) = 0;
+    virtual MultiDimFunctionGraph< GUM_SCALAR >*
+      minimize(const MultiDimFunctionGraph< GUM_SCALAR >* f1,
+               const MultiDimFunctionGraph< GUM_SCALAR >* f2,
+               Idx                                        del = 3) = 0;
 
     // ==========================================================================
     /// @warning given f1 and f2 are deleted, returns the new one
     // ==========================================================================
-    virtual MultiDimFunctionGraph<GUM_SCALAR>*
-    multiply( const MultiDimFunctionGraph<GUM_SCALAR>* f1,
-              const MultiDimFunctionGraph<GUM_SCALAR>* f2,
-              Idx                                      del = 3 ) = 0;
+    virtual MultiDimFunctionGraph< GUM_SCALAR >*
+      multiply(const MultiDimFunctionGraph< GUM_SCALAR >* f1,
+               const MultiDimFunctionGraph< GUM_SCALAR >* f2,
+               Idx                                        del = 3) = 0;
 
     // ==========================================================================
     /// @warning given vFunction and qAction are deleted, returns the new one
     // ==========================================================================
-    virtual MultiDimFunctionGraph<ArgMaxSet<GUM_SCALAR, Idx>,
-                                  SetTerminalNodePolicy>*
-    argmaximize( const MultiDimFunctionGraph<ArgMaxSet<GUM_SCALAR, Idx>,
-                                             SetTerminalNodePolicy>* f1,
-                 const MultiDimFunctionGraph<ArgMaxSet<GUM_SCALAR, Idx>,
-                                             SetTerminalNodePolicy>* f2,
-                 Idx                                                 del = 3 ) = 0;
+    virtual MultiDimFunctionGraph< ArgMaxSet< GUM_SCALAR, Idx >,
+                                   SetTerminalNodePolicy >*
+      argmaximize(const MultiDimFunctionGraph< ArgMaxSet< GUM_SCALAR, Idx >,
+                                               SetTerminalNodePolicy >* f1,
+                  const MultiDimFunctionGraph< ArgMaxSet< GUM_SCALAR, Idx >,
+                                               SetTerminalNodePolicy >* f2,
+                  Idx del = 3) = 0;
 
     // ==========================================================================
     /// @warning given function is deleted, returns the new one
     // ==========================================================================
-    virtual MultiDimFunctionGraph<GUM_SCALAR>*
-    add( const MultiDimFunctionGraph<GUM_SCALAR>* f1,
-         const MultiDimFunctionGraph<GUM_SCALAR>* f2,
-         Idx                                      del = 1 ) = 0;
+    virtual MultiDimFunctionGraph< GUM_SCALAR >*
+      add(const MultiDimFunctionGraph< GUM_SCALAR >* f1,
+          const MultiDimFunctionGraph< GUM_SCALAR >* f2,
+          Idx                                        del = 1) = 0;
 
     // ==========================================================================
     /// @warning this time, nothing is deleted
     // ==========================================================================
-    virtual MultiDimFunctionGraph<GUM_SCALAR>*
-    subtract( const MultiDimFunctionGraph<GUM_SCALAR>* f1,
-              const MultiDimFunctionGraph<GUM_SCALAR>* f2,
-              Idx                                      del = 0 ) = 0;
+    virtual MultiDimFunctionGraph< GUM_SCALAR >*
+      subtract(const MultiDimFunctionGraph< GUM_SCALAR >* f1,
+               const MultiDimFunctionGraph< GUM_SCALAR >* f2,
+               Idx                                        del = 0) = 0;
 
 
     /// @}
 
     protected:
-    INLINE void _deleteFunctionGraph( const MultiDimFunctionGraph<GUM_SCALAR>* f1,
-                                      const MultiDimFunctionGraph<GUM_SCALAR>* f2,
-                                      Idx del ) {
-      if ( del == 1 || del == 3 ) delete f1;
-      if ( del >= 2 ) delete f2;
+    INLINE void _deleteFunctionGraph(const MultiDimFunctionGraph< GUM_SCALAR >* f1,
+                                     const MultiDimFunctionGraph< GUM_SCALAR >* f2,
+                                     Idx del) {
+      if (del == 1 || del == 3) delete f1;
+      if (del >= 2) delete f2;
     }
 
-    INLINE void
-    _deleteFunctionGraph( const MultiDimFunctionGraph<ArgMaxSet<GUM_SCALAR, Idx>,
-                                                      SetTerminalNodePolicy>* f1,
-                          const MultiDimFunctionGraph<ArgMaxSet<GUM_SCALAR, Idx>,
-                                                      SetTerminalNodePolicy>* f2,
-                          Idx del ) {
-      if ( del == 1 || del == 3 ) delete f1;
-      if ( del >= 2 ) delete f2;
+    INLINE void _deleteFunctionGraph(
+      const MultiDimFunctionGraph< ArgMaxSet< GUM_SCALAR, Idx >,
+                                   SetTerminalNodePolicy >* f1,
+      const MultiDimFunctionGraph< ArgMaxSet< GUM_SCALAR, Idx >,
+                                   SetTerminalNodePolicy >* f2,
+      Idx                                                   del) {
+      if (del == 1 || del == 3) delete f1;
+      if (del >= 2) delete f2;
     }
   };
-}
-#endif  // GUM_SDYNA_OPERATOR_STRATEGY_H
+}   // namespace gum
+#endif   // GUM_SDYNA_OPERATOR_STRATEGY_H
