@@ -47,10 +47,9 @@ namespace gum {
    * process
    *
    */
-  class AdaptiveRMaxPlaner : public StructuredPlaner<double>,
-                             public IDecisionStrategy {
-
-
+  class AdaptiveRMaxPlaner
+      : public StructuredPlaner< double >
+      , public IDecisionStrategy {
     // ###################################################################
     /// @name
     // ###################################################################
@@ -60,29 +59,29 @@ namespace gum {
     ///
     // ==========================================================================
     static AdaptiveRMaxPlaner*
-    ReducedAndOrderedInstance( const ILearningStrategy* learner,
-                               double                   discountFactor = 0.9,
-                               double                   epsilon = 0.00001,
-                               bool                     verbose = true ) {
-      return new AdaptiveRMaxPlaner( new MDDOperatorStrategy<double>(),
-                                     discountFactor,
-                                     epsilon,
-                                     learner,
-                                     verbose );
+      ReducedAndOrderedInstance(const ILearningStrategy* learner,
+                                double                   discountFactor = 0.9,
+                                double                   epsilon = 0.00001,
+                                bool                     verbose = true) {
+      return new AdaptiveRMaxPlaner(new MDDOperatorStrategy< double >(),
+                                    discountFactor,
+                                    epsilon,
+                                    learner,
+                                    verbose);
     }
 
     // ==========================================================================
     ///
     // ==========================================================================
-    static AdaptiveRMaxPlaner* TreeInstance( const ILearningStrategy* learner,
-                                             double discountFactor = 0.9,
-                                             double epsilon = 0.00001,
-                                             bool   verbose = true ) {
-      return new AdaptiveRMaxPlaner( new TreeOperatorStrategy<double>(),
-                                     discountFactor,
-                                     epsilon,
-                                     learner,
-                                     verbose );
+    static AdaptiveRMaxPlaner* TreeInstance(const ILearningStrategy* learner,
+                                            double discountFactor = 0.9,
+                                            double epsilon = 0.00001,
+                                            bool   verbose = true) {
+      return new AdaptiveRMaxPlaner(new TreeOperatorStrategy< double >(),
+                                    discountFactor,
+                                    epsilon,
+                                    learner,
+                                    verbose);
     }
 
     /// @}
@@ -95,11 +94,11 @@ namespace gum {
     // ==========================================================================
     /// Default constructor
     // ==========================================================================
-    AdaptiveRMaxPlaner( IOperatorStrategy<double>* opi,
-                        double                     discountFactor,
-                        double                     epsilon,
-                        const ILearningStrategy*   learner,
-                        bool                       verbose );
+    AdaptiveRMaxPlaner(IOperatorStrategy< double >* opi,
+                       double                       discountFactor,
+                       double                       epsilon,
+                       const ILearningStrategy*     learner,
+                       bool                         verbose);
 
     // ==========================================================================
     /// Default destructor
@@ -123,7 +122,7 @@ namespace gum {
      * will surely and definitely result in a crash
      */
     // ==========================================================================
-    void initialize( const FMDP<double>* fmdp );
+    void initialize(const FMDP< double >* fmdp);
 
 
     // ==========================================================================
@@ -136,7 +135,7 @@ namespace gum {
      * or when nbStep have been performed
      */
     // ==========================================================================
-    void makePlanning( Idx nbStep = 1000000 );
+    void makePlanning(Idx nbStep = 1000000);
 
     /// @}
 
@@ -155,7 +154,7 @@ namespace gum {
     // ==========================================================================
     /// Performs a single step of value iteration
     // ==========================================================================
-    virtual MultiDimFunctionGraph<double>* _valueIteration();
+    virtual MultiDimFunctionGraph< double >* _valueIteration();
 
     /// @}
 
@@ -176,16 +175,16 @@ namespace gum {
     private:
     void __makeRMaxFunctionGraphs();
 
-    std::pair<NodeId, NodeId> __visitLearner( const IVisitableGraphLearner*,
-                                              NodeId currentNodeId,
-                                              MultiDimFunctionGraph<double>*,
-                                              MultiDimFunctionGraph<double>* );
-    void __clearTables();
+    std::pair< NodeId, NodeId > __visitLearner(const IVisitableGraphLearner*,
+                                               NodeId currentNodeId,
+                                               MultiDimFunctionGraph< double >*,
+                                               MultiDimFunctionGraph< double >*);
+    void                        __clearTables();
 
     private:
-    HashTable<Idx, MultiDimFunctionGraph<double>*> __actionsRMaxTable;
-    HashTable<Idx, MultiDimFunctionGraph<double>*> __actionsBoolTable;
-    const ILearningStrategy* __fmdpLearner;
+    HashTable< Idx, MultiDimFunctionGraph< double >* > __actionsRMaxTable;
+    HashTable< Idx, MultiDimFunctionGraph< double >* > __actionsBoolTable;
+    const ILearningStrategy*                           __fmdpLearner;
 
     double __rThreshold;
     double __rmax;
@@ -196,17 +195,17 @@ namespace gum {
     // ###################################################################
     /// @{
     public:
-    void checkState( const Instantiation& newState, Idx actionId ) {
-      if ( !__initializedTable[actionId] ) {
-        __counterTable[actionId]->reset( newState );
+    void checkState(const Instantiation& newState, Idx actionId) {
+      if (!__initializedTable[actionId]) {
+        __counterTable[actionId]->reset(newState);
         __initializedTable[actionId] = true;
       } else
-        __counterTable[actionId]->incState( newState );
+        __counterTable[actionId]->incState(newState);
     }
 
     private:
-    HashTable<Idx, StatesCounter*> __counterTable;
-    HashTable<Idx, bool>           __initializedTable;
+    HashTable< Idx, StatesCounter* > __counterTable;
+    HashTable< Idx, bool >           __initializedTable;
 
     bool __initialized;
     /// @}
@@ -214,6 +213,4 @@ namespace gum {
 
 } /* namespace gum */
 
-#endif  // GUM_ADAPTIVE_RMAX_PLANER_H
-
-// kate: indent-mode cstyle; indent-width 2; replace-tabs on; ;
+#endif   // GUM_ADAPTIVE_RMAX_PLANER_H
