@@ -68,17 +68,16 @@ namespace gum {
     PutDown = 5,
     FillUp = 6
   };
+
+  // clang-format off
   /**
-   * @class Factory factorySimulator.h
-   * <agrum/FMDP/simulation/factorySimulator.h>
+* @class FactorySimulator
+* @headerfile factorySimulator.h <agrum/FMDP/simulation/factorySimulator.h>
    * @brief A class to simulate the Factory problem
    * @ingroup fmdp_group
-   *
-   *
-   *
    */
+  // clang-format on
   class FactorySimulator : public AbstractSimulator {
-
     public:
     // ===========================================================================
     /// @name Constructors, Destructors.
@@ -110,7 +109,7 @@ namespace gum {
     bool hasReachEnd();
     ///
     double reward();
-    void   perform( Idx );
+    void   perform(Idx);
 
     /// @}
 
@@ -119,15 +118,15 @@ namespace gum {
     // ===========================================================================
     /// @{
 
-    const DiscreteVariable* primeVar( const DiscreteVariable* mainVar ) {
-      return __primeMap.second( mainVar );
+    const DiscreteVariable* primeVar(const DiscreteVariable* mainVar) {
+      return __primeMap.second(mainVar);
     }
 
     /// Iteration over the variables of the simulated probleme
-    SequenceIteratorSafe<const DiscreteVariable*> beginVariables() {
+    SequenceIteratorSafe< const DiscreteVariable* > beginVariables() {
       return __FactoryVars.beginSafe();
     }
-    SequenceIteratorSafe<const DiscreteVariable*> endVariables() {
+    SequenceIteratorSafe< const DiscreteVariable* > endVariables() {
       return __FactoryVars.endSafe();
     }
 
@@ -138,15 +137,13 @@ namespace gum {
     // ===========================================================================
     /// @{
 
-    const std::string& actionName( Idx actionId ) {
-      return *__actionMap[actionId];
-    }
+    const std::string& actionName(Idx actionId) { return *__actionMap[actionId]; }
 
     /// Iteration over the variables of the simulated probleme
-    SequenceIteratorSafe<Idx> beginActions() {
+    SequenceIteratorSafe< Idx > beginActions() {
       return __FactoryActions.beginSafe();
     }
-    SequenceIteratorSafe<Idx> endActions() { return __FactoryActions.endSafe(); }
+    SequenceIteratorSafe< Idx > endActions() { return __FactoryActions.endSafe(); }
 
 
     /// @}
@@ -162,17 +159,17 @@ namespace gum {
     void __fillUp();
 
     /// Variables data structures
-    Sequence<const DiscreteVariable*> __FactoryVars;
-    Bijection<const DiscreteVariable*, const DiscreteVariable*> __primeMap;
-    DiscreteVariable* __xPos;
-    DiscreteVariable* __yPos;
-    DiscreteVariable* __passengerPos;
-    DiscreteVariable* __passengerDest;
-    DiscreteVariable* __fuelLevel;
+    Sequence< const DiscreteVariable* >                           __FactoryVars;
+    Bijection< const DiscreteVariable*, const DiscreteVariable* > __primeMap;
+    DiscreteVariable*                                             __xPos;
+    DiscreteVariable*                                             __yPos;
+    DiscreteVariable*                                             __passengerPos;
+    DiscreteVariable*                                             __passengerDest;
+    DiscreteVariable*                                             __fuelLevel;
 
     /// Actions
-    Sequence<Idx> __FactoryActions;
-    HashTable<Idx, std::string*> __actionMap;  //__actionMap.insert ( actionId,
+    Sequence< Idx >                __FactoryActions;
+    HashTable< Idx, std::string* > __actionMap;   //__actionMap.insert ( actionId,
     // new std::string ( action ) );
     FactorySimulationAction __lastAction;
   };
@@ -180,4 +177,4 @@ namespace gum {
 } /* namespace gum */
 
 
-#endif  // GUM_FACTORY_SIMULATOR_H
+#endif   // GUM_FACTORY_SIMULATOR_H
