@@ -30,7 +30,7 @@
 // =========================================================================
 // =========================================================================
 #include <agrum/core/sequence.h>
-#include <agrum/multidim/multiDimFunctionGraph.h>
+#include <agrum/multidim/implementations/multiDimFunctionGraph.h>
 // =========================================================================
 
 namespace gum {
@@ -44,7 +44,6 @@ namespace gum {
    * @ingroup fmdp_group
    */
   class StatesChecker {
-
     public:
     // ==========================================================================
     /// @name Constructor & destructor.
@@ -68,30 +67,26 @@ namespace gum {
     // ==========================================================================
     /// @{
 
-    bool checkState( const Instantiation& state ) {
-      return __checker->get( state );
-    }
+    bool checkState(const Instantiation& state) { return __checker->get(state); }
 
-    void addState( const Instantiation& );
+    void addState(const Instantiation&);
 
     Idx nbVisitedStates() { return __nbVisitedStates; }
 
-    void reset( const Instantiation& );
+    void reset(const Instantiation&);
 
     /// @}
 
     private:
-    void __insertState( const Instantiation&, NodeId, Idx );
+    void __insertState(const Instantiation&, NodeId, Idx);
 
     Idx __nbVisitedStates;
 
-    MultiDimFunctionGraph<bool>* __checker;
-    NodeId                       __checkerTrueId, __checkerFalseId;
+    MultiDimFunctionGraph< bool >* __checker;
+    NodeId                         __checkerTrueId, __checkerFalseId;
 
-    Set<Instantiation*> __visitedStates;
+    Set< Instantiation* > __visitedStates;
   };
 } /* namespace gum */
 
-#endif  // GUM_STATES_CHECKER_H
-
-// kate: indent-mode cstyle; indent-width 2; replace-tabs on; ;
+#endif   // GUM_STATES_CHECKER_H
