@@ -32,20 +32,20 @@
 #include <utility>
 #include <vector>
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 
 #include <agrum/core/list.h>
 
 #include <agrum/graphs/algorithms/triangulations/partialOrderedTriangulation.h>
 
-#include <agrum/multidim/multiDimBucket.h>
-#include <agrum/multidim/multiDimSparse.h>
+#include <agrum/multidim/implementations/multiDimBucket.h>
+#include <agrum/multidim/implementations/multiDimSparse.h>
 
 #include <agrum/ID/inference/IInfluenceDiagramInference.h>
 
 namespace gum {
 
-  template <typename GUM_SCALAR>
+  template < typename GUM_SCALAR >
   class CliqueProperties;
 
   /**
@@ -58,9 +58,9 @@ namespace gum {
    *
    * The class used for the triangulation is partialOrderedTriangulation.
    */
-  template <typename GUM_SCALAR>
-  class InfluenceDiagramInference : public IInfluenceDiagramInference<GUM_SCALAR> {
-
+  template < typename GUM_SCALAR >
+  class InfluenceDiagramInference
+      : public IInfluenceDiagramInference< GUM_SCALAR > {
     public:
     // ====================================================================
     /// @name Constructor & destructor
@@ -71,7 +71,8 @@ namespace gum {
      * Default constructor.
      * @param infDiag the influence diagram we want to perform inference upon
      */
-    InfluenceDiagramInference( const InfluenceDiagram<GUM_SCALAR>& infDiag );
+    explicit InfluenceDiagramInference(
+      const InfluenceDiagram< GUM_SCALAR >& infDiag);
 
     /**
      * Destructor.
@@ -92,10 +93,10 @@ namespace gum {
 
     /// @see gum::IInfluenceDiagramInference::getBestDecisionChoice( NodeId
     /// decisionId )
-    Idx getBestDecisionChoice( NodeId decisionId );
+    Idx getBestDecisionChoice(NodeId decisionId);
 
     /// displays the result of an inference
-    std::string displayResult( void );
+    std::string displayResult();
 
     /// @}
     // ====================================================================
@@ -105,10 +106,10 @@ namespace gum {
 
     /// @see gum::IInfluenceDiagramInference::insertEvidence().
     virtual void
-    insertEvidence( const List<const Potential<GUM_SCALAR>*>& evidenceList );
+      insertEvidence(const List< const Potential< GUM_SCALAR >* >& evidenceList);
 
     /// @see gum::IInfluenceDiagramInference::eraseEvidence().
-    virtual void eraseEvidence( const Potential<GUM_SCALAR>* evidence );
+    virtual void eraseEvidence(const Potential< GUM_SCALAR >* evidence);
 
     /// @see gum::IInfluenceDiagramInference::eraseAllEvidence().
     virtual void eraseAllEvidence();
@@ -124,7 +125,7 @@ namespace gum {
 
     /// Displays on terminal the result of strong junction tree computation
     /// for test purpose only
-    void displayStrongJunctionTree( std::ostream& stream = std::cout );
+    void displayStrongJunctionTree(std::ostream& stream = std::cout);
 
     private:
     // ====================================================================
@@ -136,16 +137,16 @@ namespace gum {
     Triangulation* __triangulation;
 
     /// The set of dummies sparse potential matrix created.
-    Set<Potential<GUM_SCALAR>*> __potentialDummies;
+    Set< Potential< GUM_SCALAR >* > __potentialDummies;
 
     /// The set of dummies sparse utilities matrix created.
-    Set<UtilityTable<GUM_SCALAR>*> __utilityDummies;
+    Set< Potential< GUM_SCALAR >* > __utilityDummies;
 
     /// The resulting potential from inference
-    Potential<GUM_SCALAR>* __inferencePotential;
+    Potential< GUM_SCALAR >* __inferencePotential;
 
     /// The resulting utility from inference
-    UtilityTable<GUM_SCALAR>* __inferenceUtility;
+    Potential< GUM_SCALAR >* __inferenceUtility;
 
     /// @}
     // ====================================================================
@@ -154,13 +155,13 @@ namespace gum {
     /// @{
 
     /// Mapping of the nodes with the clique used to put their CPT
-    NodeProperty<NodeId> __nodeToCliqueMap;
+    NodeProperty< NodeId > __nodeToCliqueMap;
 
-    NodeProperty<CliqueProperties<GUM_SCALAR>*> __cliquePropertiesMap;
+    NodeProperty< CliqueProperties< GUM_SCALAR >* > __cliquePropertiesMap;
 
-    HashTable<Size, NodeId> __cliqueEliminationMap;
+    HashTable< Size, NodeId > __cliqueEliminationMap;
 
-    HashTable<NodeId, Idx> __utakenDecisionMap;
+    HashTable< NodeId, Idx > __utakenDecisionMap;
 
     bool __inferenceMade;
 
@@ -171,10 +172,10 @@ namespace gum {
     /// @{
 
     /// @return Returns a separator given two adjacent cliques
-    const NodeSet& __getSeparator( NodeId clique_1, NodeId clique_2 );
+    const NodeSet& __getSeparator(NodeId clique_1, NodeId clique_2);
 
     /// @return Returns the clique in which the node's potentials must be stored
-    NodeId __getClique( const std::vector<NodeId>& eliminationOrder, NodeId id );
+    NodeId __getClique(const std::vector< NodeId >& eliminationOrder, NodeId id);
 
     /// @}
     // ====================================================================
@@ -194,23 +195,23 @@ namespace gum {
     void __cleanUp();
 
     /// collect child clique for inferences
-    void __collectChild( NodeId parent, NodeId child );
+    void __collectChild(NodeId parent, NodeId child);
 
     /// Performs the operation of absorption of a clique by another
-    void __absorbClique( NodeId absorbedCliqueId, NodeId absorbingCliqueId );
+    void __absorbClique(NodeId absorbedCliqueId, NodeId absorbingCliqueId);
 
     /// Reduces a clique down to her separator from another clique elements
-    void __reduceClique( CliqueProperties<GUM_SCALAR>* absorbedClique,
-                         NodeSet&                      separator,
-                         Potential<GUM_SCALAR>*&       potentialMarginal,
-                         UtilityTable<GUM_SCALAR>*&    utilityMarginal );
+    void __reduceClique(CliqueProperties< GUM_SCALAR >* absorbedClique,
+                        NodeSet&                        separator,
+                        Potential< GUM_SCALAR >*&       potentialMarginal,
+                        Potential< GUM_SCALAR >*&       utilityMarginal);
 
     /// Returns a pointer over a "dummy" potential, which is a CPT filled with
     /// one MultiDimSparse filled with 1. This is used by empty cliques.
     /// @param cliqueId The NodeId of the cliqueId for which we build a dummy
     /// potential.
     /// @return A pointer over the dummy bucket.
-    Potential<GUM_SCALAR>* __makeDummyPotential( NodeId cliqueId );
+    Potential< GUM_SCALAR >* __makeDummyPotential(NodeId cliqueId);
 
     /// Returns a pointer over a "dummy" utility, which is a utility table
     /// filled
@@ -219,10 +220,10 @@ namespace gum {
     /// @param cliqueId The NodeId of the cliqueId for which we build a dummy
     /// utility.
     /// @return A pointer over the dummy bucket.
-    UtilityTable<GUM_SCALAR>* __makeDummyUtility( NodeId cliqueId );
+    Potential< GUM_SCALAR >* __makeDummyUtility(NodeId cliqueId);
 
     /// Returns true if observed  node is eliminated after current node
-    bool __IsEliminatedAfter( NodeId observedNode, NodeId currentNode );
+    bool __IsEliminatedAfter(NodeId observedNode, NodeId currentNode);
 
     /// @}
   };
@@ -231,7 +232,7 @@ namespace gum {
   /// @class CliqueProperties
   /// Private class to keep clique's properties.
   /// It used MultiDimBucket to compute the cliques potentials.
-  template <typename GUM_SCALAR>
+  template < typename GUM_SCALAR >
   class CliqueProperties {
     public:
     /// Default constructor.
@@ -243,26 +244,26 @@ namespace gum {
 
     /// Add a variable to this clique
     /// @param v The variable added.
-    void addVariable( const DiscreteVariable& v );
+    void addVariable(const DiscreteVariable& v);
 
     /// Determines in which order nodes will be eliminated from clique
     /// @param elim the global elimination order.
-    void makeEliminationOrder( const std::vector<NodeId>&          elim,
-                               const InfluenceDiagram<GUM_SCALAR>& infDiag );
+    void makeEliminationOrder(const std::vector< NodeId >&          elim,
+                              const InfluenceDiagram< GUM_SCALAR >& infDiag);
 
     /// Add a potential to this clique
     /// @param cpt v's cpt.
     /// @param removable for cleaning purpose after inference, we have to keep
     /// track
     /// of adding potential during inference
-    void addPotential( const Potential<GUM_SCALAR>& cpt, bool removable = false );
+    void addPotential(const Potential< GUM_SCALAR >& cpt, bool removable = false);
 
     /// Add a potential to this clique
     /// @param cpt v's cpt.
     /// @param removable for cleaning purpose after inference, we have to keep
     /// track
     /// of adding potential during inference
-    void addUtility( const UtilityTable<GUM_SCALAR>& ut, bool removable = false );
+    void addUtility(const Potential< GUM_SCALAR >& ut, bool removable = false);
 
     /// Removes all potential and utility table added during an inference
     void cleanFromInference();
@@ -274,63 +275,64 @@ namespace gum {
     /// @throw NotFound Raised if the evidence is on a variable not present
     ///        in this clique.
     /// @throw OperationNotAllowed If the evidence isn't valid.
-    void addEvidence( const Potential<GUM_SCALAR>& evidence );
+    void addEvidence(const Potential< GUM_SCALAR >& evidence);
 
     /// Removes all the evidences containing v
-    void removeEvidence( const DiscreteVariable& v );
+    void removeEvidence(const DiscreteVariable& v);
 
     /// Remove all the evidences
     void removeAllEvidence();
 
     /// @return Returns the mapping of evidences on the variables in this
     /// clique.
-    const HashTable<const DiscreteVariable*, const Potential<GUM_SCALAR>*>&
-    evidences() const;
+    const HashTable< const DiscreteVariable*, const Potential< GUM_SCALAR >* >&
+      evidences() const;
 
     /// @return Returns the bucket of this Clique
-    const HashTable<const Potential<GUM_SCALAR>*, Instantiation*>&
-    potentialBucket();
+    const HashTable< const Potential< GUM_SCALAR >*, Instantiation* >&
+      potentialBucket();
 
     /// @return Returns the bucket of this Clique
-    const HashTable<const UtilityTable<GUM_SCALAR>*, Instantiation*>&
-    utilityBucket();
+    const HashTable< const Potential< GUM_SCALAR >*, Instantiation* >&
+      utilityBucket();
 
     /// @return returns the elimination sequence for this clique
-    const Sequence<NodeId>& cliqueEliminationOrder();
+    const Sequence< NodeId >& cliqueEliminationOrder();
 
     /// @return returns List containing all variables contained in this clique
-    const Sequence<const DiscreteVariable*>& cliqueVariables();
+    const Sequence< const DiscreteVariable* >& cliqueVariables();
 
     /// @return returns instanciation on variable within this clique
     Instantiation& cliqueInstantiation();
 
     private:
     /// Evidences on the variables in this clique
-    HashTable<const DiscreteVariable*, const Potential<GUM_SCALAR>*> __evidences;
+    HashTable< const DiscreteVariable*, const Potential< GUM_SCALAR >* >
+      __evidences;
 
     /// The potential bucket of this clique with evidences
-    HashTable<const Potential<GUM_SCALAR>*, Instantiation*> __potentialBucket;
+    HashTable< const Potential< GUM_SCALAR >*, Instantiation* > __potentialBucket;
 
     /// The utility bucket of this clique
-    HashTable<const UtilityTable<GUM_SCALAR>*, Instantiation*> __utilityBucket;
+    HashTable< const Potential< GUM_SCALAR >*, Instantiation* > __utilityBucket;
 
     /// The sequence of elimination of node in the clique
-    Sequence<NodeId> __eliminationOrder;
+    Sequence< NodeId > __eliminationOrder;
 
     /// Instantiation on variable in that clique
     Instantiation __allVarsInst;
 
     /// The list of var that have been had during an inference
-    List<const DiscreteVariable*> __removableVarList;
+    List< const DiscreteVariable* > __removableVarList;
 
     /// The list of potentials that have been had during an inference
-    List<const Potential<GUM_SCALAR>*> __removablePotentialList;
+    List< const Potential< GUM_SCALAR >* > __removablePotentialList;
 
     /// The list of utilities that have been had during an inference
-    List<const UtilityTable<GUM_SCALAR>*> __removableUtilityList;
+    List< const Potential< GUM_SCALAR >* > __removableUtilityList;
   };
 
-#endif  // DOXYGEN_SHOULD_SKIP_THIS
+#endif   // DOXYGEN_SHOULD_SKIP_THIS
 
 } /* namespace gum */
 
