@@ -31,7 +31,7 @@
 #define GUM_ID_READER_H
 
 #include <agrum/ID/influenceDiagram.h>
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 #include <iostream>
 #include <string>
 
@@ -45,7 +45,7 @@ namespace gum {
    * All classes used to read an influence diagram from
    * a file must inherit from this class
    */
-  template <typename GUM_SCALAR>
+  template < typename GUM_SCALAR >
   class IDReader {
     public:
     /**
@@ -53,7 +53,7 @@ namespace gum {
      * A reader is created to reading a defined file.
      * Note that an ID as to be created before and given in parameter.
      */
-    IDReader( InfluenceDiagram<GUM_SCALAR>* infdiag, const std::string& filePath );
+    IDReader(InfluenceDiagram< GUM_SCALAR >* infdiag, const std::string& filePath);
 
     /**
      * Default destructor.
@@ -71,6 +71,6 @@ namespace gum {
 
 } /* namespace gum */
 
-#include "IDReader.tcc"
+#include "IDReader_tpl.h"
 
-#endif  // GUM_ID_READER_H
+#endif   // GUM_ID_READER_H
