@@ -47,21 +47,22 @@
 namespace gum {
   namespace prm {
 
-    template <typename GUM_SCALAR>
+    template < typename GUM_SCALAR >
     class PRMSystem;
-    template <typename GUM_SCALAR>
+    template < typename GUM_SCALAR >
     class PRMFactory;
     /**
-     * @class PRM PRM.h <agrum/PRM/PRM.h>
+     * @class PRM
+     * @headerfile PRM.h <agrum/PRM/PRM.h>
      * @brief This class represents a Probabilistic Relational
      *PRMSystem<GUM_SCALAR>.
      *
      * @ingroup prm_group
      */
-    template <typename GUM_SCALAR>
+    template < typename GUM_SCALAR >
     class PRM {
       public:
-      friend class PRMFactory<GUM_SCALAR>;
+      friend class PRMFactory< GUM_SCALAR >;
 
       // ========================================================================
       /// @name Destructor.
@@ -88,13 +89,13 @@ namespace gum {
        * @param name The name of a possible PRMType<GUM_SCALAR> in this PRM.
        * @return Returns true if name names a PRMType<GUM_SCALAR> in this PRM.
        */
-      bool isType( const std::string name ) const;
+      bool isType(const std::string& name) const;
 
       /**
        * @param name The name of a possible Class<GUM_SCALAR> in this PRM.
        * @return Returns true if name names a Class<GUM_SCALAR> in this PRM.
        */
-      bool isClass( const std::string name ) const;
+      bool isClass(const std::string& name) const;
 
       /**
        * @param name The name of a possible PRMInterface<GUM_SCALAR> in this
@@ -102,84 +103,84 @@ namespace gum {
        * @return Returns true if name names a PRMInterface<GUM_SCALAR> in this
        * PRM.
        */
-      bool isInterface( const std::string name ) const;
+      bool isInterface(const std::string& name) const;
 
       /**
        * @param name The name of a possible PRMSystem<GUM_SCALAR> in this PRM.
        * @return Returns true if name names a PRMSystem<GUM_SCALAR> in this PRM.
        */
-      bool isSystem( const std::string name ) const;
+      bool isSystem(const std::string& name) const;
 
       /**
        * Returns a constant reference on a PRMType<GUM_SCALAR> given it's name.
        * @throw NotFound Raised if no type is found with the given name.
        */
-      PRMType<GUM_SCALAR>& type( const std::string& name );
+      PRMType< GUM_SCALAR >& type(const std::string& name);
 
       /**
        * Returns a constant reference on a PRMType<GUM_SCALAR> given it's name.
        * @throw NotFound Raised if no type is found with the given name.
        */
-      const PRMType<GUM_SCALAR>& type( const std::string& name ) const;
+      const PRMType< GUM_SCALAR >& type(const std::string& name) const;
 
       /**
        * Returns the Set of all PRMType<GUM_SCALAR> in this PRM.
        */
-      const Set<PRMType<GUM_SCALAR>*>& types() const;
+      const Set< PRMType< GUM_SCALAR >* >& types() const;
 
       /**
        * Returns a constant reference on a Class<GUM_SCALAR> given it's name.
        * @throw NotFound Raised if no class is found with the given name.
        */
-      PRMClass<GUM_SCALAR>& getClass( const std::string& name );
+      PRMClass< GUM_SCALAR >& getClass(const std::string& name);
 
       /**
        * Returns a constant reference on a Class<GUM_SCALAR> given it's name.
        * @throw NotFound Raised if no class is found with the given name.
        */
-      const PRMClass<GUM_SCALAR>& getClass( const std::string& name ) const;
+      const PRMClass< GUM_SCALAR >& getClass(const std::string& name) const;
 
       /**
        * Returns the Set of all Class<GUM_SCALAR> in this PRM.
        */
-      const Set<PRMClass<GUM_SCALAR>*>& classes() const;
+      const Set< PRMClass< GUM_SCALAR >* >& classes() const;
 
       /**
        * Returns a constant reference on a Class<GUM_SCALAR> given it's name.
        * @throw NotFound Raised if no class is found with the given name.
        */
-      PRMInterface<GUM_SCALAR>& getInterface( const std::string& name );
+      PRMInterface< GUM_SCALAR >& getInterface(const std::string& name);
 
       /**
        * Returns a constant reference on a Class<GUM_SCALAR> given it's name.
        * @throw NotFound Raised if no class is found with the given name.
        */
-      const PRMInterface<GUM_SCALAR>&
-      getInterface( const std::string& name ) const;
+      const PRMInterface< GUM_SCALAR >&
+        getInterface(const std::string& name) const;
 
       /**
        * Returns the Set of all Class<GUM_SCALAR> in this PRM.
        */
-      const Set<PRMInterface<GUM_SCALAR>*>& interfaces() const;
+      const Set< PRMInterface< GUM_SCALAR >* >& interfaces() const;
 
       /**
        * Returns a constant reference on a PRMSystem<GUM_SCALAR> given it's
        * name.
        * @throw NotFound Raised if no model is found with the given name.
        */
-      PRMSystem<GUM_SCALAR>& getSystem( const std::string& name );
+      PRMSystem< GUM_SCALAR >& getSystem(const std::string& name);
 
       /**
        * Returns a constant reference on a PRMSystem<GUM_SCALAR> given it's
        * name.
        * @throw NotFound Raised if no model is found with the given name.
        */
-      const PRMSystem<GUM_SCALAR>& getSystem( const std::string& name ) const;
+      const PRMSystem< GUM_SCALAR >& getSystem(const std::string& name) const;
 
       /**
        * Returns the Set of all Systems in this PRM.
        */
-      const Set<PRMSystem<GUM_SCALAR>*>& systems() const;
+      const Set< PRMSystem< GUM_SCALAR >* >& systems() const;
 
       /// @}
       private:
@@ -191,12 +192,12 @@ namespace gum {
       /**
        * Copy constructor. Not Implemented.
        */
-      PRM( const PRM<GUM_SCALAR>& source );
+      PRM(const PRM< GUM_SCALAR >& source);
 
       /**
        * Copy operator. Not Implemented.
        */
-      PRM<GUM_SCALAR>& operator=( const PRM<GUM_SCALAR>& source );
+      PRM< GUM_SCALAR >& operator=(const PRM< GUM_SCALAR >& source);
 
       /// Add the built-in types in the PRM
       void __addBuiltInTypes();
@@ -208,35 +209,35 @@ namespace gum {
       /// @{
 
       /// Mapping of all Class<GUM_SCALAR> given their name.
-      HashTable<std::string, PRMClass<GUM_SCALAR>*> __classMap;
+      HashTable< std::string, PRMClass< GUM_SCALAR >* > __classMap;
 
       /// Set of all Class<GUM_SCALAR> in this PRM.
-      Set<PRMClass<GUM_SCALAR>*> __classes;
+      Set< PRMClass< GUM_SCALAR >* > __classes;
 
       /// Mapping of all Class<GUM_SCALAR> given their name.
-      HashTable<std::string, PRMInterface<GUM_SCALAR>*> __interfaceMap;
+      HashTable< std::string, PRMInterface< GUM_SCALAR >* > __interfaceMap;
 
       /// Set of all Class<GUM_SCALAR> in this PRM.
-      Set<PRMInterface<GUM_SCALAR>*> __interfaces;
+      Set< PRMInterface< GUM_SCALAR >* > __interfaces;
 
       /// Mapping of all PRMType<GUM_SCALAR> given their name.
-      HashTable<std::string, PRMType<GUM_SCALAR>*> __typeMap;
+      HashTable< std::string, PRMType< GUM_SCALAR >* > __typeMap;
 
       /// Set of all PRMType<GUM_SCALAR> in this PRM.
-      Set<PRMType<GUM_SCALAR>*> __types;
+      Set< PRMType< GUM_SCALAR >* > __types;
 
       /// Mapping of all Systems given their name.
-      HashTable<std::string, PRMSystem<GUM_SCALAR>*> __systemMap;
+      HashTable< std::string, PRMSystem< GUM_SCALAR >* > __systemMap;
 
       /// Set of all Systems in this PRM.
-      Set<PRMSystem<GUM_SCALAR>*> __systems;
+      Set< PRMSystem< GUM_SCALAR >* > __systems;
 
       /// @}
     };
 
 
-    extern template class PRM<float>;
-    extern template class PRM<double>;
+    extern template class PRM< float >;
+    extern template class PRM< double >;
 
 
   } /* namespace prm */
