@@ -39,25 +39,24 @@
 #include <agrum/core/bijection.h>
 #include <agrum/core/sequence.h>
 #include <agrum/core/set.h>
-#include <agrum/multidim/multiDimImplementation.h>
-#include <agrum/multidim/multiDimSparse.h>
+#include <agrum/multidim/implementations/multiDimImplementation.h>
+#include <agrum/multidim/implementations/multiDimSparse.h>
 
 namespace gum {
   namespace prm {
 
     /**
-     * @class Class<GUM_SCALAR> class.h <agrum/PRM/class.h>
-     * @brief A Class<GUM_SCALAR> is an object of a PRM representing a fragment
-     *of a
-     *        Bayesian Network which can be instantiated in PRMInstance.
+     * @class PRMClass
+     * @headerfile PRMClass.h <agrum/PRM/elements/PRMClass.h>
+     * @brief A PRMClass is an object of a PRM representing a fragment
+     *        of a Bayesian Network which can be instantiated in PRMInstance.
      *
-     * @see PRM Class<GUM_SCALAR> PRMClassElement<GUM_SCALAR>
+     * @see PRMClassElement
      * @ingroup prm_group
      */
-    template <typename GUM_SCALAR>
-    class PRMClass : public PRMClassElementContainer<GUM_SCALAR> {
-
-      friend class PRMInterface<GUM_SCALAR>;
+    template < typename GUM_SCALAR >
+    class PRMClass : public PRMClassElementContainer< GUM_SCALAR > {
+      friend class PRMInterface< GUM_SCALAR >;
 
       public:
       /// @name Constructors & destructor.
@@ -67,7 +66,7 @@ namespace gum {
        * Default constructor.
        * @param name The class name.
        */
-      PRMClass( const std::string& name );
+      explicit PRMClass(const std::string& name);
 
       /**
        * Constructor for building a subclass of super.
@@ -75,9 +74,9 @@ namespace gum {
        * @param super The super Class<GUM_SCALAR> of this.
        * @param delayInheritance If true, inheritance will be delayed.
        */
-      PRMClass( const std::string&    name,
-                PRMClass<GUM_SCALAR>& super,
-                bool                  delayInheritance = false );
+      PRMClass(const std::string&      name,
+               PRMClass< GUM_SCALAR >& super,
+               bool                    delayInheritance = false);
 
       /**
        * Constructor for building a Class<GUM_SCALAR> implementing several each
@@ -87,9 +86,9 @@ namespace gum {
        * @param set The Set of implemented interfaces.
        * @param delayInheritance If true, inheritance will be delayed.
        */
-      PRMClass( const std::string&                    name,
-                const Set<PRMInterface<GUM_SCALAR>*>& set,
-                bool                                  delayInheritance = false );
+      PRMClass(const std::string&                        name,
+               const Set< PRMInterface< GUM_SCALAR >* >& set,
+               bool                                      delayInheritance = false);
 
       /**
        * Constructor for building a subclass of super and implementing each
@@ -99,24 +98,24 @@ namespace gum {
        * @param set The Set of implemented interfaces.
        * @param delayInheritance If true, inheritance will be delayed.
        */
-      PRMClass( const std::string&                    name,
-                PRMClass<GUM_SCALAR>&                 super,
-                const Set<PRMInterface<GUM_SCALAR>*>& set,
-                bool                                  delayInheritance = false );
+      PRMClass(const std::string&                        name,
+               PRMClass< GUM_SCALAR >&                   super,
+               const Set< PRMInterface< GUM_SCALAR >* >& set,
+               bool                                      delayInheritance = false);
 
       /// Copy constructor.
-      PRMClass( const PRMClass<GUM_SCALAR>& source ) = delete;
+      PRMClass(const PRMClass< GUM_SCALAR >& source) = delete;
 
       /// Move constructor.
-      PRMClass( const PRMClass<GUM_SCALAR>&& source ) = delete;
+      PRMClass(const PRMClass< GUM_SCALAR >&& source) = delete;
 
       /// Copy operator. Don't use it.
-      PRMClass<GUM_SCALAR>&
-      operator=( const PRMClass<GUM_SCALAR>& source ) = delete;
+      PRMClass< GUM_SCALAR >&
+        operator=(const PRMClass< GUM_SCALAR >& source) = delete;
 
       /// Move operator. Don't use it.
-      PRMClass<GUM_SCALAR>&
-      operator=( const PRMClass<GUM_SCALAR>&& source ) = delete;
+      PRMClass< GUM_SCALAR >&
+        operator=(const PRMClass< GUM_SCALAR >&& source) = delete;
 
       /// Destructor.
       virtual ~PRMClass();
@@ -130,10 +129,10 @@ namespace gum {
       /// @{
 
       /// See gum::prm::PRMClassElementContainer<GUM_SCALAR>::get(NodeId).
-      PRMClassElement<GUM_SCALAR>& get( NodeId id );
+      PRMClassElement< GUM_SCALAR >& get(NodeId id);
 
       /// See gum::prm::PRMClassElementContainer<GUM_SCALAR>::get(NodeId).
-      const PRMClassElement<GUM_SCALAR>& get( NodeId id ) const;
+      const PRMClassElement< GUM_SCALAR >& get(NodeId id) const;
 
       /// @}
       // ========================================================================
@@ -146,7 +145,7 @@ namespace gum {
        * @param elt A node of this class.
        * @return Returns true if elt is an output node.
        */
-      virtual bool isOutputNode( const PRMClassElement<GUM_SCALAR>& elt ) const;
+      virtual bool isOutputNode(const PRMClassElement< GUM_SCALAR >& elt) const;
 
       /**
        * @brief Return true if the attribute named safe_name is a cast
@@ -160,50 +159,50 @@ namespace gum {
        * @throw NotFound Raised if safe_name does not name an
        * PRMAttribute<GUM_SCALAR> in this Class<GUM_SCALAR>.
        */
-      bool isCastDescendant( const std::string& safe_name ) const;
+      bool isCastDescendant(const std::string& safe_name) const;
 
       /// See gum::prm::PRMClassElementContainer<GUM_SCALAR>::get(const
       /// std::string&).
-      PRMClassElement<GUM_SCALAR>& get( const std::string& name );
+      PRMClassElement< GUM_SCALAR >& get(const std::string& name);
 
       /// See gum::prm::PRMClassElementContainer<GUM_SCALAR>::get(const
       /// std::string&).
-      const PRMClassElement<GUM_SCALAR>& get( const std::string& name ) const;
+      const PRMClassElement< GUM_SCALAR >& get(const std::string& name) const;
 
       /// See gum::prm::add(PRMClassElement<GUM_SCALAR>*).
-      virtual NodeId add( PRMClassElement<GUM_SCALAR>* elt );
+      virtual NodeId add(PRMClassElement< GUM_SCALAR >* elt);
 
       /// See gum::prm::overload(PRMClassElement<GUM_SCALAR>*).
-      virtual NodeId overload( PRMClassElement<GUM_SCALAR>* elt );
+      virtual NodeId overload(PRMClassElement< GUM_SCALAR >* elt);
 
       /// See gum::prm::PRMClassElementContainer<GUM_SCALAR>::addArc().
-      virtual void addArc( const std::string& tail, const std::string& head );
+      virtual void addArc(const std::string& tail, const std::string& head);
 
       /**
        * Returns the set of PRMAttribute<GUM_SCALAR> of this Class<GUM_SCALAR>.
        * @return Returns the set of PRMAttribute<GUM_SCALAR> of this
        * Class<GUM_SCALAR>.
        */
-      const Set<PRMAttribute<GUM_SCALAR>*>& attributes() const;
+      const Set< PRMAttribute< GUM_SCALAR >* >& attributes() const;
 
       /**
        * Returns the set of parameters of this Class<GUM_SCALAR>.
        * @return Returns the set of parameters of this Class<GUM_SCALAR>.
        */
-      const Set<PRMParameter<GUM_SCALAR>*>& parameters() const;
+      const Set< PRMParameter< GUM_SCALAR >* >& parameters() const;
 
       /**
        * Returns all the parameters in the scope of this class.
        * &return all the parameters in the scope of this class.
        */
-      HashTable<std::string, const PRMParameter<GUM_SCALAR>*> scope() const;
+      HashTable< std::string, const PRMParameter< GUM_SCALAR >* > scope() const;
 
       /**
        * Returns the set of PRMAggregate<GUM_SCALAR> of this Class<GUM_SCALAR>.
        * @return Returns the set of PRMAggregate<GUM_SCALAR> of this
        * Class<GUM_SCALAR>.
        */
-      const Set<PRMAggregate<GUM_SCALAR>*>& aggregates() const;
+      const Set< PRMAggregate< GUM_SCALAR >* >& aggregates() const;
 
       /**
        * Returns the set of PRMReferenceSlot<GUM_SCALAR> of this
@@ -211,14 +210,14 @@ namespace gum {
        * @return Returns the set of PRMReferenceSlot<GUM_SCALAR> of this
        * Class<GUM_SCALAR>.
        */
-      const Set<PRMReferenceSlot<GUM_SCALAR>*>& referenceSlots() const;
+      const Set< PRMReferenceSlot< GUM_SCALAR >* >& referenceSlots() const;
 
       /**
        * Returns the set of PRMSlotChain<GUM_SCALAR> of this Class<GUM_SCALAR>.
        * @return Returns the set of PRMSlotChain<GUM_SCALAR> of this
        * Class<GUM_SCALAR>.
        */
-      const Set<PRMSlotChain<GUM_SCALAR>*>& slotChains() const;
+      const Set< PRMSlotChain< GUM_SCALAR >* >& slotChains() const;
 
       /// @}
       // ========================================================================
@@ -247,14 +246,14 @@ namespace gum {
        * @return Returns true if this Class<GUM_SCALAR> is a subclass of cec.
        */
       virtual bool
-      isSubTypeOf( const PRMClassElementContainer<GUM_SCALAR>& cec ) const;
+        isSubTypeOf(const PRMClassElementContainer< GUM_SCALAR >& cec) const;
 
       /**
        * @brief Returns the super Class<GUM_SCALAR> of this Class<GUM_SCALAR>.
        * @return Returns the super Class<GUM_SCALAR> of this Class<GUM_SCALAR>.
        * @throw NotFound Raised if this has no super Class<GUM_SCALAR>.
        */
-      const PRMClass<GUM_SCALAR>& super() const;
+      const PRMClass< GUM_SCALAR >& super() const;
 
       /**
        * @brief Returns the Set of PRMInterface<GUM_SCALAR> implemented by this
@@ -264,11 +263,11 @@ namespace gum {
        * @throw NotFound Raised if this Class<GUM_SCALAR> doesn't implement any
        * PRMInterface<GUM_SCALAR>.
        */
-      const Set<PRMInterface<GUM_SCALAR>*>& implements() const;
+      const Set< PRMInterface< GUM_SCALAR >* >& implements() const;
 
       /// Returns the set of Class@<GUM_SCALAR@> which are direct
       /// sub-Class@<GUM_SCALAR@> of this Class@<GUM_SCALAR@>.
-      const Set<PRMClass<GUM_SCALAR>*>& extensions() const;
+      const Set< PRMClass< GUM_SCALAR >* >& extensions() const;
 
       /// @}
       // ========================================================================
@@ -278,20 +277,20 @@ namespace gum {
 
       /// See
       /// gum::prm::PRMClassElementContainer<GUM_SCALAR>::operator[](NodeId).
-      PRMClassElement<GUM_SCALAR>& operator[]( NodeId id );
+      PRMClassElement< GUM_SCALAR >& operator[](NodeId id);
 
       /// See
       /// gum::prm::PRMClassElementContainer<GUM_SCALAR>::operator[](NodeId).
-      const PRMClassElement<GUM_SCALAR>& operator[]( NodeId id ) const;
+      const PRMClassElement< GUM_SCALAR >& operator[](NodeId id) const;
 
       /// See gum::prm::PRMClassElementContainer<GUM_SCALAR>::operator[](const
       /// std::string&).
-      PRMClassElement<GUM_SCALAR>& operator[]( const std::string& name );
+      PRMClassElement< GUM_SCALAR >& operator[](const std::string& name);
 
       /// See gum::prm::PRMClassElementContainer<GUM_SCALAR>::operator[](const
       /// std::string&).
-      const PRMClassElement<GUM_SCALAR>&
-      operator[]( const std::string& name ) const;
+      const PRMClassElement< GUM_SCALAR >&
+        operator[](const std::string& name) const;
 
       /// @}
 
@@ -303,7 +302,7 @@ namespace gum {
       void inheritAggregates();
       void inheritSlotChains();
       void initializeInheritance();
-      void completeInheritance( const std::string& attr );
+      void completeInheritance(const std::string& attr);
       /// @}
 
       protected:
@@ -315,11 +314,11 @@ namespace gum {
       virtual DAG& _dag();
 
       /// Fills set with all the subtypes of this Class<GUM_SCALAR>.
-      void _findAllSubtypes( Set<PRMClassElementContainer<GUM_SCALAR>*>& set );
+      void _findAllSubtypes(Set< PRMClassElementContainer< GUM_SCALAR >* >& set);
 
       /// See gum::prm::PRMClassElementContainer<GUM_SCALAR>(const
       /// PRMClassElement<GUM_SCALAR>&).
-      void _updateDescendants( const PRMClassElement<GUM_SCALAR>& elt );
+      void _updateDescendants(const PRMClassElement< GUM_SCALAR >& elt);
 
       private:
       /// Proceed with the copy of c in this.
@@ -336,7 +335,7 @@ namespace gum {
 
       /// Mapping between node's id and their name (being an attribute or a
       /// slot). Used for fast access to a member given it's node id.
-      NodeProperty<PRMClassElement<GUM_SCALAR>*> __nodeIdMap;
+      NodeProperty< PRMClassElement< GUM_SCALAR >* > __nodeIdMap;
 
       /// @}
       // ========================================================================
@@ -346,30 +345,30 @@ namespace gum {
 
       /// Mapping between a member's name and itself.
       /// Used for fast access to a member given it's name
-      HashTable<std::string, PRMClassElement<GUM_SCALAR>*> __nameMap;
+      HashTable< std::string, PRMClassElement< GUM_SCALAR >* > __nameMap;
 
       /// The sequence of PRMAttribute<GUM_SCALAR>s.
-      Set<PRMAttribute<GUM_SCALAR>*> __attributes;
+      Set< PRMAttribute< GUM_SCALAR >* > __attributes;
 
       /// The sequence of PRMReferenceSlot<GUM_SCALAR>.
-      Set<PRMReferenceSlot<GUM_SCALAR>*> __referenceSlots;
+      Set< PRMReferenceSlot< GUM_SCALAR >* > __referenceSlots;
 
       /// The sequence of aggregate.
-      Set<PRMAggregate<GUM_SCALAR>*> __aggregates;
+      Set< PRMAggregate< GUM_SCALAR >* > __aggregates;
 
       /// The set of gum::PRMSlotChain<GUM_SCALAR>s
-      Set<PRMSlotChain<GUM_SCALAR>*> __slotChains;
+      Set< PRMSlotChain< GUM_SCALAR >* > __slotChains;
 
       /// The Set of parameters in this Class<GUM_SCALAR>.
-      Set<PRMParameter<GUM_SCALAR>*> __parameters;
+      Set< PRMParameter< GUM_SCALAR >* > __parameters;
 
       /// Recursively adds cast descendant of attr in this Class<GUM_SCALAR>.
-      void __addCastDescendants( PRMClassElement<GUM_SCALAR>* attr );
+      void __addCastDescendants(PRMClassElement< GUM_SCALAR >* attr);
 
       /// Recursively adds cast descendant from start to end in this
       /// Class<GUM_SCALAR>.
-      void __addCastDescendants( PRMAttribute<GUM_SCALAR>* start,
-                                 PRMAttribute<GUM_SCALAR>* end );
+      void __addCastDescendants(PRMAttribute< GUM_SCALAR >* start,
+                                PRMAttribute< GUM_SCALAR >* end);
 
       /// @}
       // ========================================================================
@@ -381,44 +380,44 @@ namespace gum {
       /// elements defined in
       ///        this.
       /// Note that this is first searched for gum::PRMClassElement<GUM_SCALAR>.
-      PRMClass<GUM_SCALAR>* __superClass;
+      PRMClass< GUM_SCALAR >* __superClass;
 
       /// The Set of implemented interface of this.
-      Set<PRMInterface<GUM_SCALAR>*>* __implements;
+      Set< PRMInterface< GUM_SCALAR >* >* __implements;
 
       /// The set of Class<GUM_SCALAR> which are extension of this
       /// Class<GUM_SCALAR> (i.e. direct
       /// subtypes).
-      Set<PRMClass<GUM_SCALAR>*> __extensions;
+      Set< PRMClass< GUM_SCALAR >* > __extensions;
 
       /// The bijection between variables in super and variables in this
       /// The bijection's firsts are attributes in this and its seconds are
       /// attributes in c.
-      Bijection<const DiscreteVariable*, const DiscreteVariable*>* __bijection;
+      Bijection< const DiscreteVariable*, const DiscreteVariable* >* __bijection;
 
       /// Proceed with the copy when this inherits c.
-      void __inheritClass( const PRMClass<GUM_SCALAR>& c );
+      void __inheritClass(const PRMClass< GUM_SCALAR >& c);
 
       /// Proceed with the implementation of interfaces
-      void __implementInterfaces( bool delayInheritance );
+      void __implementInterfaces(bool delayInheritance);
 
       /// Check that a given element respects all the class interfaces
-      void __checkInterfaces( PRMClassElement<GUM_SCALAR>* elt );
+      void __checkInterfaces(PRMClassElement< GUM_SCALAR >* elt);
 
       /// Check that a given element respects a specific interface
-      void __checkInterface( PRMClassElement<GUM_SCALAR>* elt,
-                             PRMInterface<GUM_SCALAR>*    i );
+      void __checkInterface(PRMClassElement< GUM_SCALAR >* elt,
+                            PRMInterface< GUM_SCALAR >*    i);
 
       /// Check that a given element respects all the class interfaces
-      void __checkRefInterfaces( PRMReferenceSlot<GUM_SCALAR>* elt );
+      void __checkRefInterfaces(PRMReferenceSlot< GUM_SCALAR >* elt);
 
       /// Check that a given element respects a specific interface
-      void __checkRefInterface( PRMReferenceSlot<GUM_SCALAR>* elt,
-                                PRMInterface<GUM_SCALAR>*     i );
+      void __checkRefInterface(PRMReferenceSlot< GUM_SCALAR >* elt,
+                               PRMInterface< GUM_SCALAR >*     i);
 
       /// Check if elt is present in an implementation. If it is, its IO flags
       /// are updated.
-      void __addIOInterfaceFlags( PRMClassElement<GUM_SCALAR>* elt );
+      void __addIOInterfaceFlags(PRMClassElement< GUM_SCALAR >* elt);
 
       /// This method is called when a sub-Class@<GUM_SCALAR@> of this
       /// Class@<GUM_SCALAR@> is created.
@@ -428,38 +427,42 @@ namespace gum {
       /// @throw DuplicateElement Raised if c is already a
       /// sub-Class@<GUM_SCALAR@>
       /// of this.
-      void __addExtension( PRMClass<GUM_SCALAR>* c );
+      void __addExtension(PRMClass< GUM_SCALAR >* c);
 
       /// Return true of overloaded can be overload by overloader.
       bool
-      __checkOverloadLegality( const PRMClassElement<GUM_SCALAR>* overloaded,
-                               const PRMClassElement<GUM_SCALAR>* overloader );
+        __checkOverloadLegality(const PRMClassElement< GUM_SCALAR >* overloaded,
+                                const PRMClassElement< GUM_SCALAR >* overloader);
 
       /// Overloads an attribute.
-      void __overloadAttribute( PRMAttribute<GUM_SCALAR>* overloader,
-                                PRMAttribute<GUM_SCALAR>* overloaded );
+      void __overloadAttribute(PRMAttribute< GUM_SCALAR >* overloader,
+                               PRMAttribute< GUM_SCALAR >* overloaded);
 
       /// Overloads an aggregate.
-      void __overloadAggregate( PRMAggregate<GUM_SCALAR>*    overloader,
-                                PRMClassElement<GUM_SCALAR>* overloaded );
+      void __overloadAggregate(PRMAggregate< GUM_SCALAR >*    overloader,
+                               PRMClassElement< GUM_SCALAR >* overloaded);
 
       /// Overloads a reference slot.
-      void __overloadReference( PRMReferenceSlot<GUM_SCALAR>* overloader,
-                                PRMReferenceSlot<GUM_SCALAR>* overloaded );
+      void __overloadReference(PRMReferenceSlot< GUM_SCALAR >* overloader,
+                               PRMReferenceSlot< GUM_SCALAR >* overloaded);
 
       /// Overloads a parameter.
-      void __overloadParameter( PRMParameter<GUM_SCALAR>* overloader,
-                                PRMParameter<GUM_SCALAR>* overloaded );
+      void __overloadParameter(PRMParameter< GUM_SCALAR >* overloader,
+                               PRMParameter< GUM_SCALAR >* overloaded);
 
       /// @}
     };
 
 
-    extern template class PRMClass<float>;
-    extern template class PRMClass<double>;
+    extern template class PRMClass< float >;
+    extern template class PRMClass< double >;
 
   } /* namespace prm */
-}  // namespace gum
+#ifdef __clang__
+  extern template class HashFuncMediumCastKey< gum::prm::PRMClass< float >* >;
+  extern template class HashFuncMediumCastKey< gum::prm::PRMClass< double >* >;
+#endif
+}   // namespace gum
 
 #include <agrum/PRM/elements/PRMClass_tpl.h>
 
