@@ -28,15 +28,16 @@
 #include <string>
 
 #include <agrum/PRM/elements/PRMObject.h>
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 
 #ifndef GUM_NAME_GENERATOR_H
-#define GUM_NAME_GENERATOR_H
+#  define GUM_NAME_GENERATOR_H
 namespace gum {
   namespace prm {
 
     /**
-     * @class NameGenerator PRMGenerator.h <agrum/PRM/generator/PRMGenerator.h>
+     * @class NameGenerator
+     * @headerfile PRMGenerator.h <agrum/PRM/generator/PRMGenerator.h>
      * @brief This is a name generator for classes, types, systems, instances
      *and
      *        class elements.
@@ -56,11 +57,11 @@ namespace gum {
       /// Default constructor.
       NameGenerator();
       /// Copy constructor.
-      NameGenerator( const NameGenerator& source );
+      NameGenerator(const NameGenerator& source);
       /// Destructor.
       virtual ~NameGenerator();
       /// Affectation operator
-      NameGenerator& operator=( const NameGenerator& source );
+      NameGenerator& operator=(const NameGenerator& source);
 
       /// @}
       // ========================================================================
@@ -69,19 +70,19 @@ namespace gum {
       /// @{
 
       /// Returns the next name w.r.t. the given PRMType.
-      std::string nextName( PRMObject::prm_type type );
+      std::string nextName(PRMObject::prm_type type);
 
       /// @}
       private:
       /// The vector of counters.
-      std::vector<Size> __counters;
+      std::vector< Size > __counters;
     };
 
   } /* namespace prm */
 } /* namespace gum */
 
-#ifndef GUM_NO_INLINE
-#include <agrum/PRM/generator/nameGenerator_inl.h>
-#endif
+#  ifndef GUM_NO_INLINE
+#    include <agrum/PRM/generator/nameGenerator_inl.h>
+#  endif
 
 #endif /* GUM_NAME_GENERATOR_H */
