@@ -30,6 +30,7 @@
  * @author Pierre-Henri WUILLEMIN
  */
 
+#include <agrum/agrum.h>
 // To help IDE parser
 #include <agrum/core/approximations/approximationScheme.h>
 
@@ -37,17 +38,15 @@ namespace gum {
 
   // Given that we approximate f(t), stopping criterion on |f(t+1)-f(t)| If
   // the criterion was disabled it will be enabled
-  INLINE void ApproximationScheme::setEpsilon( double eps ) {
-    if ( eps < 0. ) {
-      GUM_ERROR( OutOfLowerBound, "eps should be >=0" );
-    }
+  INLINE void ApproximationScheme::setEpsilon(double eps) {
+    if (eps < 0.) { GUM_ERROR(OutOfLowerBound, "eps should be >=0"); }
 
     _eps = eps;
     _enabled_eps = true;
   }
 
   // Get the value of epsilon
-  INLINE double ApproximationScheme::epsilon( void ) const { return _eps; }
+  INLINE double ApproximationScheme::epsilon() const { return _eps; }
 
   // Disable stopping criterion on epsilon
   INLINE void ApproximationScheme::disableEpsilon() { _enabled_eps = false; }
@@ -62,17 +61,15 @@ namespace gum {
   }
 
   // Given that we approximate f(t), stopping criterion on d/dt(|f(t+1)-f(t)|)
-  INLINE void ApproximationScheme::setMinEpsilonRate( double rate ) {
-    if ( rate < 0 ) {
-      GUM_ERROR( OutOfLowerBound, "rate should be >=0" );
-    }
+  INLINE void ApproximationScheme::setMinEpsilonRate(double rate) {
+    if (rate < 0) { GUM_ERROR(OutOfLowerBound, "rate should be >=0"); }
 
     _min_rate_eps = rate;
     _enabled_min_rate_eps = true;
   }
 
   // Get the value of the minimal epsilon rate
-  INLINE double ApproximationScheme::minEpsilonRate( void ) const {
+  INLINE double ApproximationScheme::minEpsilonRate() const {
     return _min_rate_eps;
   }
 
@@ -93,16 +90,14 @@ namespace gum {
   }
 
   // stopping criterion on number of iterations
-  INLINE void ApproximationScheme::setMaxIter( Size max ) {
-    if ( max < 1 ) {
-      GUM_ERROR( OutOfLowerBound, "max should be >=1" );
-    }
+  INLINE void ApproximationScheme::setMaxIter(Size max) {
+    if (max < 1) { GUM_ERROR(OutOfLowerBound, "max should be >=1"); }
     _max_iter = max;
     _enabled_max_iter = true;
   }
 
   // @return the criterion on number of iterations
-  INLINE Size ApproximationScheme::maxIter( void ) const { return _max_iter; }
+  INLINE Size ApproximationScheme::maxIter() const { return _max_iter; }
 
   // Disable stopping criterion on max iterations
   INLINE void ApproximationScheme::disableMaxIter() { _enabled_max_iter = false; }
@@ -116,23 +111,19 @@ namespace gum {
     return _enabled_max_iter;
   }
 
-  // stopping criterion on timeout If the criterion was disabled it will be
-  // enabled
-  INLINE void ApproximationScheme::setMaxTime( double timeout ) {
-    if ( timeout <= 0. ) {
-      GUM_ERROR( OutOfLowerBound, "timeout should be >0." );
-    }
+  // stopping criterion on timeout (in seconds)
+  // If the criterion was disabled it will be enabled
+  INLINE void ApproximationScheme::setMaxTime(double timeout) {
+    if (timeout <= 0.) { GUM_ERROR(OutOfLowerBound, "timeout should be >0."); }
     _max_time = timeout;
     _enabled_max_time = true;
   }
 
   // returns the timeout (in seconds)
-  INLINE double ApproximationScheme::maxTime( void ) const { return _max_time; }
+  INLINE double ApproximationScheme::maxTime() const { return _max_time; }
 
   // get the current running time in second (double)
-  INLINE double ApproximationScheme::currentTime( void ) const {
-    return _timer.step();
-  }
+  INLINE double ApproximationScheme::currentTime() const { return _timer.step(); }
 
   // Disable stopping criterion on timeout
   INLINE void ApproximationScheme::disableMaxTime() { _enabled_max_time = false; }
@@ -147,29 +138,18 @@ namespace gum {
   }
 
   // how many samples between 2 stopping isEnableds
-  INLINE void ApproximationScheme::setPeriodSize( Size p ) {
-    if ( p < 1 ) {
-      GUM_ERROR( OutOfLowerBound, "p should be >=1" );
-    }
+  INLINE void ApproximationScheme::setPeriodSize(Size p) {
+    if (p < 1) { GUM_ERROR(OutOfLowerBound, "p should be >=1"); }
 
     _period_size = p;
   }
 
-  INLINE Size ApproximationScheme::periodSize( void ) const {
-    return _period_size;
-  }
-
-  // size of burn in on number of iteration
-  INLINE void ApproximationScheme::setBurnIn( Size b ) {
-    _burn_in = b;
-  }
-
-  INLINE Size ApproximationScheme::burnIn( void ) const { return _burn_in; }
+  INLINE Size ApproximationScheme::periodSize() const { return _period_size; }
 
   // verbosity
-  INLINE void ApproximationScheme::setVerbosity( bool v ) { _verbosity = v; }
+  INLINE void ApproximationScheme::setVerbosity(bool v) { _verbosity = v; }
 
-  INLINE bool ApproximationScheme::verbosity( void ) const { return _verbosity; }
+  INLINE bool ApproximationScheme::verbosity() const { return _verbosity; }
 
   // history
   INLINE IApproximationSchemeConfiguration::ApproximationSchemeSTATE
@@ -179,23 +159,23 @@ namespace gum {
 
   // @throw OperationNotAllowed if scheme not performed
   INLINE Size ApproximationScheme::nbrIterations() const {
-    if ( stateApproximationScheme() == ApproximationSchemeSTATE::Undefined ) {
-      GUM_ERROR( OperationNotAllowed,
-                 "state of the approximation scheme is undefined" );
+    if (stateApproximationScheme() == ApproximationSchemeSTATE::Undefined) {
+      GUM_ERROR(OperationNotAllowed,
+                "state of the approximation scheme is undefined");
     }
 
     return _current_step;
   }
 
   // @throw OperationNotAllowed if scheme not performed or verbosity=false
-  INLINE const std::vector<double>& ApproximationScheme::history() const {
-    if ( stateApproximationScheme() == ApproximationSchemeSTATE::Undefined ) {
-      GUM_ERROR( OperationNotAllowed,
-                 "state of the approximation scheme is udefined" );
+  INLINE const std::vector< double >& ApproximationScheme::history() const {
+    if (stateApproximationScheme() == ApproximationSchemeSTATE::Undefined) {
+      GUM_ERROR(OperationNotAllowed,
+                "state of the approximation scheme is udefined");
     }
 
-    if ( verbosity() == false ) {
-      GUM_ERROR( OperationNotAllowed, "No history when verbosity=false" );
+    if (verbosity() == false) {
+      GUM_ERROR(OperationNotAllowed, "No history when verbosity=false");
     }
 
     return _history;
@@ -213,24 +193,20 @@ namespace gum {
   // @return true if we are at the beginning of a period (compute error is
   // mandatory)
   INLINE bool ApproximationScheme::startOfPeriod() {
-    if ( _current_step < _burn_in ) {
-      return false;
-    }
+    if (_current_step < _burn_in) { return false; }
 
-    if ( _period_size == 1 ) {
-      return true;
-    }
+    if (_period_size == 1) { return true; }
 
-    return ( ( _current_step - _burn_in ) % _period_size == 0 );
+    return ((_current_step - _burn_in) % _period_size == 0);
   }
 
   // update the scheme w.r.t the new error and incr steps
-  INLINE void ApproximationScheme::updateApproximationScheme( unsigned int incr ) {
+  INLINE void ApproximationScheme::updateApproximationScheme(unsigned int incr) {
     _current_step += incr;
   }
 
   INLINE Size ApproximationScheme::remainingBurnIn() {
-    if ( _burn_in > _current_step ) {
+    if (_burn_in > _current_step) {
       return _burn_in - _current_step;
     } else {
       return 0;
@@ -239,63 +215,59 @@ namespace gum {
 
   // stop approximation scheme by user request.
   INLINE void ApproximationScheme::stopApproximationScheme() {
-    if ( _current_state == ApproximationSchemeSTATE::Continue ) {
-      _stopScheme( ApproximationSchemeSTATE::Stopped );
+    if (_current_state == ApproximationSchemeSTATE::Continue) {
+      _stopScheme(ApproximationSchemeSTATE::Stopped);
     }
   }
 
   // update the scheme w.r.t the new error. Test the stopping criterions that
   // are enabled
-  INLINE bool ApproximationScheme::continueApproximationScheme( double error ) {
+  INLINE bool ApproximationScheme::continueApproximationScheme(double error) {
     // For coherence, we fix the time used in the method
 
     double timer_step = _timer.step();
 
-    if ( _enabled_max_time ) {
-      if ( timer_step > _max_time ) {
-        _stopScheme( ApproximationSchemeSTATE::TimeLimit );
+    if (_enabled_max_time) {
+      if (timer_step > _max_time) {
+        _stopScheme(ApproximationSchemeSTATE::TimeLimit);
         return false;
       }
     }
 
-    if ( !startOfPeriod() ) {
-      return true;
+    if (!startOfPeriod()) { return true; }
+
+    if (_current_state != ApproximationSchemeSTATE::Continue) {
+      GUM_ERROR(OperationNotAllowed,
+                "state of the approximation scheme is not correct : "
+                  + messageApproximationScheme());
     }
 
-    if ( _current_state != ApproximationSchemeSTATE::Continue ) {
-      GUM_ERROR( OperationNotAllowed,
-                 "state of the approximation scheme is not correct : " +
-                     messageApproximationScheme() );
-    }
+    if (verbosity()) { _history.push_back(error); }
 
-    if ( verbosity() ) {
-      _history.push_back( error );
-    }
-
-    if ( _enabled_max_iter ) {
-      if ( _current_step > _max_iter ) {
-        _stopScheme( ApproximationSchemeSTATE::Limit );
+    if (_enabled_max_iter) {
+      if (_current_step > _max_iter) {
+        _stopScheme(ApproximationSchemeSTATE::Limit);
         return false;
       }
     }
 
     _last_epsilon = _current_epsilon;
-    _current_epsilon = error;  // eps rate isEnabled needs it so affectation was
+    _current_epsilon = error;   // eps rate isEnabled needs it so affectation was
     // moved from eps isEnabled below
 
-    if ( _enabled_eps ) {
-      if ( _current_epsilon <= _eps ) {
-        _stopScheme( ApproximationSchemeSTATE::Epsilon );
+    if (_enabled_eps) {
+      if (_current_epsilon <= _eps) {
+        _stopScheme(ApproximationSchemeSTATE::Epsilon);
         return false;
       }
     }
 
-    if ( _last_epsilon >= 0. ) {
-      if ( _current_epsilon > .0 ) {
+    if (_last_epsilon >= 0.) {
+      if (_current_epsilon > .0) {
         // ! _current_epsilon can be 0. AND epsilon
         // isEnabled can be disabled !
         _current_rate =
-            std::fabs( ( _current_epsilon - _last_epsilon ) / _current_epsilon );
+          std::fabs((_current_epsilon - _last_epsilon) / _current_epsilon);
       }
       // limit with current eps ---> 0 is | 1 - ( last_eps / 0 ) | --->
       // infinity the else means a return false if we isEnabled the rate below,
@@ -304,20 +276,17 @@ namespace gum {
         _current_rate = _min_rate_eps;
       }
 
-      if ( _enabled_min_rate_eps ) {
-        if ( _current_rate <= _min_rate_eps ) {
-          _stopScheme( ApproximationSchemeSTATE::Rate );
+      if (_enabled_min_rate_eps) {
+        if (_current_rate <= _min_rate_eps) {
+          _stopScheme(ApproximationSchemeSTATE::Rate);
           return false;
         }
       }
     }
 
-    if ( stateApproximationScheme() == ApproximationSchemeSTATE::Continue ) {
-      if ( onProgress.hasListener() ) {
-        GUM_EMIT3( onProgress,
-                   ( _current_step * 100 ) / _max_iter,
-                   _current_epsilon,
-                   timer_step );
+    if (stateApproximationScheme() == ApproximationSchemeSTATE::Continue) {
+      if (onProgress.hasListener()) {
+        GUM_EMIT3(onProgress, _current_step, _current_epsilon, timer_step);
       }
 
       return true;
@@ -327,21 +296,15 @@ namespace gum {
   }
 
   INLINE void
-  ApproximationScheme::_stopScheme( ApproximationSchemeSTATE new_state ) {
-    if ( new_state == ApproximationSchemeSTATE::Continue ) {
-      return;
-    }
+    ApproximationScheme::_stopScheme(ApproximationSchemeSTATE new_state) {
+    if (new_state == ApproximationSchemeSTATE::Continue) { return; }
 
-    if ( new_state == ApproximationSchemeSTATE::Undefined ) {
-      return;
-    }
+    if (new_state == ApproximationSchemeSTATE::Undefined) { return; }
 
     _current_state = new_state;
     _timer.pause();
 
-    if ( onStop.hasListener() ) {
-      GUM_EMIT1( onStop, messageApproximationScheme() );
-    }
+    if (onStop.hasListener()) { GUM_EMIT1(onStop, messageApproximationScheme()); }
   }
 
-}  // namespace gum
+}   // namespace gum
