@@ -28,7 +28,7 @@
 
 #include <iostream>
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 #include <agrum/core/hashTable.h>
 
 namespace gum {
@@ -38,14 +38,15 @@ namespace gum {
   // =========================================================================
 
   /**
-   * @class IndexedTree indexedTree.h <agrum/core/indexedTree.h>
+   * @class IndexedTree
+   * @headerfile indexedTree.h <agrum/core/indexedTree.h>
    * @brief The class for storing the nodes of the Arborescence
    * @ingroup basicstruct_group
    *
    * @tparam Key The tree's keys type.
    * @tparam Data The tree's values type.
    */
-  template <typename Key, typename Data>
+  template < typename Key, typename Data >
   class IndexedTree {
     public:
     // ============================================================================
@@ -61,7 +62,7 @@ namespace gum {
      *
      * @param data Adds data as the root of the tree.
      */
-    IndexedTree( Data* data = nullptr );
+    IndexedTree(Data* data = nullptr);
 
     /**
      * @brief Creates a tree with one node (with or without data).
@@ -76,7 +77,7 @@ namespace gum {
      * @param theKey The data's key.
      * @param data The data added to the tree.
      */
-    IndexedTree( const Key& theKey, Data* data = nullptr );
+    IndexedTree(const Key& theKey, Data* data = nullptr);
 
     /**
      * @brief Creates a tree with one node with data.
@@ -87,20 +88,20 @@ namespace gum {
      * @param theKey The data's key.
      * @param data The data added to the tree.
      */
-    IndexedTree( const Key& theKey, const Data& data );
+    IndexedTree(const Key& theKey, const Data& data);
 
     /**
      * @brief Copy constructor.
      * @param from The gum::IndexedTree to copy.
      */
-    IndexedTree( const IndexedTree<Key, Data>& from );
+    IndexedTree(const IndexedTree< Key, Data >& from);
 
     /**
      * @brief Copy operator.
      * @param from The gum::IndexedTree to copy.
      * @return Returns this gum::IndexedTree.
      */
-    IndexedTree<Key, Data>& operator=( const IndexedTree<Key, Data>& from );
+    IndexedTree< Key, Data >& operator=(const IndexedTree< Key, Data >& from);
 
     /**
      * @brief Class destructor.
@@ -122,7 +123,7 @@ namespace gum {
      * index has already been entered into the tree. If, in this case, you
      * would like the value of the to be updated, use function setNode instead.
      */
-    void insertNode( const std::vector<Key>& index, const Data* data );
+    void insertNode(const std::vector< Key >& index, const Data* data);
 
     /**
      * @brief Adds a new node into the tree.
@@ -133,7 +134,7 @@ namespace gum {
      * index has already been entered into the tree. If, in this case, you
      * would like the value of the to be updated, use function setNode instead.
      */
-    void insertNode( const std::vector<Key>& index, const Data& data );
+    void insertNode(const std::vector< Key >& index, const Data& data);
 
     /**
      * @brief Updates the value of a node (or adds it if it does not already
@@ -142,7 +143,7 @@ namespace gum {
      * @param index The node's index.
      * @param data The node's data.
      */
-    void setNode( const std::vector<Key>& index, Data* data );
+    void setNode(const std::vector< Key >& index, Data* data);
 
     /**
      * @brief Updates the value of a node (or adds it if it does not already
@@ -151,7 +152,7 @@ namespace gum {
      * @param index The node's index.
      * @param data The node's data.
      */
-    void setNode( const std::vector<Key>& index, const Data& data );
+    void setNode(const std::vector< Key >& index, const Data& data);
 
     /**
      * @brief Returns the value of a given node of the tree.
@@ -161,7 +162,7 @@ namespace gum {
      * @throw NotFound exception is thrown if the so-called value
      * cannot be found in the tree.
      */
-    Data& getData( const std::vector<Key>& index ) const;
+    Data& getData(const std::vector< Key >& index) const;
 
     /**
      * @brief Returns a given node of the tree.
@@ -170,7 +171,7 @@ namespace gum {
      * @throw NotFound exception is thrown if the node we look for cannot
      * be found in the tree.
      */
-    IndexedTree<Key, Data>& getNode( const std::vector<Key>& index ) const;
+    IndexedTree< Key, Data >& getNode(const std::vector< Key >& index) const;
 
     /// @}
 
@@ -182,15 +183,15 @@ namespace gum {
     Data* data;
 
     /// The parent of the node.
-    IndexedTree<Key, Data>* parent;
+    IndexedTree< Key, Data >* parent;
 
     /// The list of children nodes of the current node.
-    HashTable<Key, IndexedTree<Key, Data>*> children;
+    HashTable< Key, IndexedTree< Key, Data >* > children;
   };
 
   /// Necessary for the hashtable operator <<
-  template <typename Key, typename Data>
-  std::ostream& operator<<( std::ostream&, const IndexedTree<Key, Data>& );
+  template < typename Key, typename Data >
+  std::ostream& operator<<(std::ostream&, const IndexedTree< Key, Data >&);
 
 } /* namespace gum */
 
