@@ -32,7 +32,7 @@
 
 #include <cmath>
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 #include <agrum/core/hashTable.h>
 
 #define GUM_LEARNING_CONFIDENCE_PROBA 0.05
@@ -44,7 +44,8 @@ namespace gum {
   // =========================================================================
 
   /**
-   * @class Chi2 chi2.h <agrum/core/math/chi2.h>
+   * @class Chi2
+   * @headerfile chi2.h <agrum/core/math/chi2.h>
    * @brief Represent the chi2 distribution.
    * @ingroup math_group
    *
@@ -64,8 +65,8 @@ namespace gum {
      * @param var_modalities The variables modalities.
      * @param confidence_proba The confidence probability.
      */
-    Chi2( const std::vector<Idx>& var_modalities,
-          double confidence_proba = GUM_LEARNING_CONFIDENCE_PROBA );
+    Chi2(const std::vector< Idx >& var_modalities,
+         double confidence_proba = GUM_LEARNING_CONFIDENCE_PROBA);
 
     /**
      * @brief Class destructor.
@@ -84,15 +85,15 @@ namespace gum {
      *
      * @param db_conditioning_ids The conditioning nodes id.
      */
-    void setConditioningNodes( const std::vector<Idx>& db_conditioning_ids );
+    void setConditioningNodes(const std::vector< Idx >& db_conditioning_ids);
 
     /**
-    * @brief Computes the critical value according to the number of degrees of
-    * freedom.
-    * @param pair A pair of variables ids.
-    * @return Returns the critical values.
-    */
-    double criticalValue( const std::pair<Idx, Idx>& pair );
+     * @brief Computes the critical value according to the number of degrees of
+     * freedom.
+     * @param pair A pair of variables ids.
+     * @return Returns the critical values.
+     */
+    double criticalValue(const std::pair< Idx, Idx >& pair);
 
     /**
      * @brief Computes the critical value according to the number of degrees of
@@ -101,14 +102,14 @@ namespace gum {
      * @param var2 The second variable id.
      * @return Returns the critical value.
      */
-    double criticalValue( Idx var1, Idx var2 );
+    double criticalValue(Idx var1, Idx var2);
 
     /**
      * @brief Returns the number of degrees of freedom.
      * @param pair A pair of variables ids.
      * @return Returns the number of degrees of freedom.
      */
-    Size degreesOfFreedom( const std::pair<Idx, Idx>& pair );
+    Size degreesOfFreedom(const std::pair< Idx, Idx >& pair);
 
     /**
      * @brief Returns the number of degrees of freedom.
@@ -116,19 +117,19 @@ namespace gum {
      * @param var2 The second variable id.
      * @return Returns the number of degrees of freedom.
      */
-    Size degreesOfFreedom( Idx var1, Idx var2 );
+    Size degreesOfFreedom(Idx var1, Idx var2);
 
     /**
      * @brief Modifies the confidence probability.
      * @param new_proba The new confidence probability
      */
-    void setConfidenceProba( double new_proba );
+    void setConfidenceProba(double new_proba);
 
     /// @}
 
     private:
     /// The modalities of the random variables.
-    const std::vector<Idx>& __modalities;
+    const std::vector< Idx >& __modalities;
 
     /// The confidence probability used for critical values.
     double __confidence_proba;
@@ -137,7 +138,7 @@ namespace gum {
     Size __conditioning_size;
 
     /// A set of already computed critical values.
-    HashTable<Idx, double> __critical_values;
+    HashTable< Idx, double > __critical_values;
 
     /**
      * @brief Computes the critical value of a given chi2 test (used by the
@@ -149,7 +150,7 @@ namespace gum {
      * @param df The number of degrees of freedom.
      * @return Returns the critical value of a given chi2 test.
      */
-    static double __criticalValue( double proba, Size df );
+    static double __criticalValue(double proba, Size df);
 
     /**
      * @brief Computes the probability of chi2 value.
@@ -167,7 +168,7 @@ namespace gum {
      * @param df The number of degrees of freedom.
      * @return The probability of x given df degrees of freedom.
      */
-    static double __probaChi2( double x, Size df );
+    static double __probaChi2(double x, Size df);
 
     /**
      * @brief Computes the probability of normal z value.
@@ -184,20 +185,20 @@ namespace gum {
      * @param z A value.
      * @return The probability of z.
      */
-    static double __probaZValue( double z );
+    static double __probaZValue(double z);
 
     /// Forbid use of the copy constructor.
-    Chi2( const Chi2& ) = delete;
+    Chi2(const Chi2&) = delete;
 
     /// Forbid used of the copy operator.
-    Chi2& operator=( const Chi2& ) = delete;
+    Chi2& operator=(const Chi2&) = delete;
   };
 
 } /* namespace gum */
 
 /// include the inlined functions if necessary
 #ifndef GUM_NO_INLINE
-#include <agrum/core/math/chi2_inl.h>
+#  include <agrum/core/math/chi2_inl.h>
 #endif /* GUM_NO_INLINE */
 
 #endif /* GUM_LEARNING_CHI2_H */
