@@ -22,14 +22,14 @@
  * @file
  * @brief Headers of gum::SmallObjectAllocator
  *
- * @author Jean-Christophe Magnan and Pierre-Henri WUILLEMIN
+ * @author Jean-Christophe MAGNAN and Pierre-Henri WUILLEMIN
  *
  */
 #ifndef GUM_SMALL_OBJECT_ALLOCATOR_H
 #define GUM_SMALL_OBJECT_ALLOCATOR_H
 
 // ============================================================================
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 // ============================================================================
 #include <agrum/core/hashTable.h>
 #include <agrum/core/smallobjectallocator/fixedAllocator.h>
@@ -51,7 +51,6 @@ namespace gum {
    * @ingroup core
    */
   class SmallObjectAllocator {
-
     public:
     /**
      * @param The default size of chunck of memory.
@@ -84,12 +83,12 @@ namespace gum {
     // ============================================================================
     /// Copy Constructor (does nothing since we use a Singleton)
     // ============================================================================
-    SmallObjectAllocator( const SmallObjectAllocator& )  {};
+    SmallObjectAllocator(const SmallObjectAllocator&){};
 
     // ============================================================================
     /// Operator = (does nothing since we use a Singleton)
     // ============================================================================
-    SmallObjectAllocator& operator=( const SmallObjectAllocator& ) {
+    SmallObjectAllocator& operator=(const SmallObjectAllocator&) {
       return instance();
     }
 
@@ -110,7 +109,7 @@ namespace gum {
     // ============================================================================
     /// Allocates a block
     // ============================================================================
-    void* allocate( const size_t& objectSize );
+    void* allocate(const size_t& objectSize);
 
     // ============================================================================
     /// Deallocates an object
@@ -118,7 +117,7 @@ namespace gum {
     /// @param objectSize is the size of that object (useful for faster
     /// deallocation)
     // ============================================================================
-    void deallocate( void* pDeallocatedObject, const size_t& objectSize );
+    void deallocate(void* pDeallocatedObject, const size_t& objectSize);
 
     /// @}
 
@@ -126,9 +125,9 @@ namespace gum {
     /// Displays the number of allocation and deallocation made so far
     // ============================================================================
     void displayStats() {
-      GUM_TRACE( "Nb Small Allocation : " << nbAllocation
-                                          << " -  Nb Small Deallocation : "
-                                          << nbDeallocation );
+      GUM_TRACE("Nb Small Allocation : " << nbAllocation
+                                         << " -  Nb Small Deallocation : "
+                                         << nbDeallocation);
     }
 
     Idx nbAlloc() { return nbAllocation; }
@@ -138,8 +137,8 @@ namespace gum {
     // ============================================================================
     /// The pool containing FixedAllocator
     // ============================================================================
-    typedef HashTable<Size, FixedAllocator*> __Pool;
-    __Pool __pool;
+    typedef HashTable< Size, FixedAllocator* > __Pool;
+    __Pool                                     __pool;
 
     // ============================================================================
     /// The memory that a chunk allocates
@@ -154,14 +153,14 @@ namespace gum {
     Idx nbAllocation;
     Idx nbDeallocation;
   };
-}  // namespace gum
+}   // namespace gum
 
 // Macro used to shorten code in classes using SmallObjectAllocator
-#define SOA_ALLOCATE( x ) SmallObjectAllocator::instance().allocate( x )
-#define SOA_DEALLOCATE( x, y ) SmallObjectAllocator::instance().deallocate( x, y )
+#define SOA_ALLOCATE(x) SmallObjectAllocator::instance().allocate(x)
+#define SOA_DEALLOCATE(x, y) SmallObjectAllocator::instance().deallocate(x, y)
 
 #ifndef GUM_NO_INLINE
-#include <agrum/core/smallobjectallocator/smallObjectAllocator.inl>
+#  include <agrum/core/smallobjectallocator/smallObjectAllocator_inl.h>
 #endif
 
-#endif  // GUM_SMALL_OBJECT_ALLOCATOR_H
+#endif   // GUM_SMALL_OBJECT_ALLOCATOR_H
