@@ -28,13 +28,14 @@
 #define GUM_UTILS_STRING_H
 
 #include <cstdlib>
+#include <sstream>
 #include <string>
 #include <vector>
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 
-#ifndef HAVE_MKSTEMP  // mainly windows
-#include <io.h>
+#ifndef HAVE_MKSTEMP   // mainly windows
+#  include <io.h>
 #endif
 
 namespace gum {
@@ -51,19 +52,39 @@ namespace gum {
    * @brief Returns the lowercase version of str.
    * @return Returns the lowercase version of str.
    */
-  std::string toLower( std::string str );
+  std::string toLower(std::string str);
 
   /**
    * @brief Returns true if value ends with ending.
    * @return Returns true if value ends with ending.
    */
-  bool endsWith( std::string const& value, std::string const& ending );
+  bool endsWith(std::string const& value, std::string const& ending);
+
+  /**
+   * @brief Split str using the delimiter
+   * @param orig searched string
+   * @param delimiter string
+   * @return Vector of splitted strings
+   */
+  std::vector< std::string > split(const std::string& orig,
+                                   const std::string& delimiter);
+
+  /**
+   * @brief Replace val by new_val in s.
+   * @param s A string.
+   * @param val The value to replace in s.
+   * @param new_val The new value to replace val in s.
+   * @return A new string with val replaced by new_val.
+   */
+  std::string replace(const std::string& s,
+                      const std::string& val,
+                      const std::string& new_val);
 
   /// @}
 } /* namespace gum */
 
 #ifndef GUM_NO_INLINE
-#include <agrum/core/utils_string_inl.h>
-#endif  // GUM_NO_INLINE
+#  include <agrum/core/utils_string_inl.h>
+#endif   // GUM_NO_INLINE
 
 #endif /* GUM_UTILS_STRING_H */
