@@ -27,7 +27,7 @@
 
 #include <utility>
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 
 #include <agrum/core/hashTable.h>
 #include <agrum/core/set.h>
@@ -61,7 +61,7 @@ namespace gum {
    * operations of the schedule can be performed. It is up to the user to check
    * this (function schedulePossible () may help here).
    */
-  template <typename GUM_SCALAR>
+  template < typename GUM_SCALAR >
   class Schedule {
     public:
     /// to identify correctly the ids that correspond to ScheduleOperation ids
@@ -79,7 +79,7 @@ namespace gum {
     Schedule();
 
     /// copy constructor
-    Schedule( const Schedule<GUM_SCALAR>& );
+    Schedule(const Schedule< GUM_SCALAR >&);
 
     /// destructor
     ~Schedule();
@@ -93,7 +93,7 @@ namespace gum {
     /// @{
 
     /// copy operator
-    Schedule<GUM_SCALAR>& operator=( const Schedule<GUM_SCALAR>& );
+    Schedule< GUM_SCALAR >& operator=(const Schedule< GUM_SCALAR >&);
 
     /// @}
 
@@ -106,56 +106,59 @@ namespace gum {
     /** The Schedule class is able to determined by itself when the operation
      * should be performed.
      * @warning operations are inserted by copy */
-    NodeId insert( const ScheduleOperation<GUM_SCALAR>& );
+    NodeId insert(const ScheduleOperation< GUM_SCALAR >&);
 
     /** @brief adds a constraint indicating that an operation cannot be
      * performed
      * before another one */
-    void forceAfter( const ScheduleOperation<GUM_SCALAR>& op_to_force,
-                     const ScheduleOperation<GUM_SCALAR>& op_before );
-    void forceAfter( NodeId op_to_force, NodeId op_before );
+    void forceAfter(const ScheduleOperation< GUM_SCALAR >& op_to_force,
+                    const ScheduleOperation< GUM_SCALAR >& op_before);
+    void forceAfter(NodeId op_to_force, NodeId op_before);
 
     /** @brief adds a constraint indicating that an operation cannot be
      * performed
      * before a set of operations */
-    void forceAfter( const ScheduleOperation<GUM_SCALAR>&             op_to_force,
-                     const Set<const ScheduleOperation<GUM_SCALAR>*>& ops_before );
-    void forceAfter( NodeId op_to_force, const NodeSet& ops_before );
+    void
+         forceAfter(const ScheduleOperation< GUM_SCALAR >&               op_to_force,
+                    const Set< const ScheduleOperation< GUM_SCALAR >* >& ops_before);
+    void forceAfter(NodeId op_to_force, const NodeSet& ops_before);
 
     /** @brief adds a constraint indicating that an operation must be performed
      * before another one */
-    void forceBefore( const ScheduleOperation<GUM_SCALAR>& op_to_force,
-                      const ScheduleOperation<GUM_SCALAR>& op_after );
-    void forceBefore( NodeId op_to_force, NodeId op_after );
+    void forceBefore(const ScheduleOperation< GUM_SCALAR >& op_to_force,
+                     const ScheduleOperation< GUM_SCALAR >& op_after);
+    void forceBefore(NodeId op_to_force, NodeId op_after);
 
     /** @brief adds a constraint indicating that an operation must be performed
      * before a set of operations */
-    void forceBefore( const ScheduleOperation<GUM_SCALAR>&             op_to_force,
-                      const Set<const ScheduleOperation<GUM_SCALAR>*>& ops_after );
-    void forceBefore( NodeId op_to_force, const NodeSet& ops_after );
+    void
+         forceBefore(const ScheduleOperation< GUM_SCALAR >&               op_to_force,
+                     const Set< const ScheduleOperation< GUM_SCALAR >* >& ops_after);
+    void forceBefore(NodeId op_to_force, const NodeSet& ops_after);
 
     /// returns a DAG indicating in which order the operations can be performed
     /** In this DAG, each node corresponds to an operation and an operation
      * can be performed only if its ancestors have all been performed. */
-    const DAG& dag() const;
+    const DAG& scheduling_dag() const;
 
     /// returns the scheduleOperation corresponding to an id in the DAG
     /** @throws NotFound exception is raised if the DAG does not contain the id
      */
-    const ScheduleOperation<GUM_SCALAR>& operation( NodeId ) const;
+    const ScheduleOperation< GUM_SCALAR >& operation(NodeId) const;
 
     /// returns the id of the node corresponding to a given ScheduleOperation
     /** @throws NotFound exception is raised the operation does not belong to
      * the Schedule */
-    NodeId nodeId( const ScheduleOperation<GUM_SCALAR>& ) const;
+    NodeId nodeId(const ScheduleOperation< GUM_SCALAR >&) const;
 
     /// resturns the association between operations anf nodeIds
-    const NodeProperty<const ScheduleOperation<GUM_SCALAR>*>& operations() const;
+    const NodeProperty< const ScheduleOperation< GUM_SCALAR >* >&
+      operations() const;
 
     /// returns the set of operations involving a given multidim table
     const NodeSet&
-    operationsInvolving( const ScheduleMultiDim<GUM_SCALAR>& table ) const;
-    const NodeSet& operationsInvolving( MultiDimId table_id ) const;
+                   operationsInvolving(const ScheduleMultiDim< GUM_SCALAR >& table) const;
+    const NodeSet& operationsInvolving(MultiDimId table_id) const;
 
     /// returns the set of ScheduleOperations that can be executed at once
     /** The scheduleOperations that can be executed at once are those that
@@ -170,14 +173,14 @@ namespace gum {
      * be
      * executed yet because some of its arguments have not already been computed
      * @throws NotFound exception is thrown if the operation cannot be found */
-    void execute( NodeId );
-    void execute( const ScheduleOperation<GUM_SCALAR>& );
+    void execute(NodeId);
+    void execute(const ScheduleOperation< GUM_SCALAR >&);
 
     /** @brief returns an estimation of the number of elementary operations
      * needed
      * to perform a given ScheduleOperation */
-    float nbOperations( NodeId ) const;
-    float nbOperations( ScheduleOperation<GUM_SCALAR>& ) const;
+    float nbOperations(NodeId) const;
+    float nbOperations(ScheduleOperation< GUM_SCALAR >&) const;
 
     /// returns the memory consumption used during the execution of an operation
     /** Actually, this function does not return a precise account of the memory
@@ -189,8 +192,8 @@ namespace gum {
      * amount of memory still used at the end of the operation ( the memory used
      * by
      * the resulting table ) */
-    std::pair<long, long> memoryUsage( NodeId ) const;
-    std::pair<long, long> memoryUsage( ScheduleOperation<GUM_SCALAR>& ) const;
+    std::pair< long, long > memoryUsage(NodeId) const;
+    std::pair< long, long > memoryUsage(ScheduleOperation< GUM_SCALAR >&) const;
 
     /// @}
 
@@ -202,14 +205,14 @@ namespace gum {
     mutable DAG __dag;
 
     /// a hashtable assigning to each node of the DAG an operation
-    NodeProperty<ScheduleOperation<GUM_SCALAR>*> __node2operation;
+    NodeProperty< ScheduleOperation< GUM_SCALAR >* > __node2operation;
 
     /// a hashtable assigning to each operation id a node id in the DAG
-    HashTable<OperationId, NodeId> __operation2node;
+    HashTable< OperationId, NodeId > __operation2node;
 
     /** @brief a hashtable assigning to each ScheduleMultiDim resulting from a
      * computation the MultiDimOperation node id that created it */
-    HashTable<MultiDimId, NodeId> __created_multidims;
+    HashTable< MultiDimId, NodeId > __created_multidims;
 
     /// a list of operations whose parents are not properly set
     /** when entering operations to be performed in a "wrong" order, it may
@@ -225,7 +228,7 @@ namespace gum {
     mutable NodeSet __operations_available;
 
     /// for each multidim, store the set of operations involving it
-    HashTable<MultiDimId, NodeSet*> __multidim2operations;
+    HashTable< MultiDimId, NodeSet* > __multidim2operations;
 
     /** @brief updates the set of parents for the nodes whoses parents are not
      * correct yet and update accordingly the available operations */
@@ -235,6 +238,6 @@ namespace gum {
 } /* namespace gum */
 
 // always include the template implementation
-#include <agrum/graphicalModels/inference/schedule.tcc>
+#include <agrum/graphicalModels/inference/schedule_tpl.h>
 
 #endif /* GUM_SCHEDULE_H */
