@@ -29,11 +29,11 @@
 #include <sstream>
 #include <utility>
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 #include <agrum/core/sequence.h>
 
-#include <agrum/graphs/arcGraphPart.h>
-#include <agrum/graphs/nodeGraphPart.h>
+#include <agrum/graphs/parts/arcGraphPart.h>
+#include <agrum/graphs/parts/nodeGraphPart.h>
 
 namespace gum {
 
@@ -105,7 +105,9 @@ namespace gum {
    */
   /* ===========================================================================
    */
-  class DiGraph : public virtual NodeGraphPart, public ArcGraphPart {
+  class DiGraph
+      : public virtual NodeGraphPart
+      , public ArcGraphPart {
     public:
     // ############################################################################
     /// @name Constructors / Destructors
@@ -117,14 +119,14 @@ namespace gum {
      * @param nodes_resize_policy the resizing policy of this hash table
      * @param arcs_size the size of the hash table used to store all the arcs
      * @param arcs_resize_policy the resizing policy of this hash table */
-    explicit DiGraph( Size nodes_size = HashTableConst::default_size,
-                      bool nodes_resize_policy = true,
-                      Size arcs_size = HashTableConst::default_size,
-                      bool arcs_resize_policy = true );
+    explicit DiGraph(Size nodes_size = HashTableConst::default_size,
+                     bool nodes_resize_policy = true,
+                     Size arcs_size = HashTableConst::default_size,
+                     bool arcs_resize_policy = true);
 
     /// copy constructor
     /** @param g the DiGraph to copy */
-    DiGraph( const DiGraph& g );
+    DiGraph(const DiGraph& g);
 
     /// destructor
     virtual ~DiGraph();
@@ -138,17 +140,17 @@ namespace gum {
 
     /// copy operator
     /** @param g the DiGraph to copy */
-    DiGraph& operator=( const DiGraph& g );
+    DiGraph& operator=(const DiGraph& g);
 
     /// tests whether two DiGraphs are identical (same nodes, same arcs)
     /** @param g the DiGraph with which "this" is compared */
     // not virtual : it is a feature !!! :)
-    bool operator==( const DiGraph& g ) const;
+    bool operator==(const DiGraph& g) const;
 
     /// tests whether two DiGraphs are different
     /** @param g the DiGraph with which "this" is compared */
     // not virtual : it is a feature !!! :)
-    bool operator!=( const DiGraph& g ) const;
+    bool operator!=(const DiGraph& g) const;
 
     /// @}
 
@@ -163,13 +165,13 @@ namespace gum {
      * @warning if the arc already exists, nothing is done. In particular, no
      * exception is raised.
      * @throw InvalidNode if head or tail does not belong to the graph nodes */
-    virtual void addArc( const NodeId tail, const NodeId head );
+    virtual void addArc(const NodeId tail, const NodeId head);
 
     /// remove a node and its adjacent arcs from the graph
     /** @param id the id of the node to be removed
      * @warning if the node does not exist, nothing is done. In particular, no
      * exception is raised.*/
-    virtual void eraseNode( const NodeId id );
+    virtual void eraseNode(const NodeId id);
 
     /// removes all the nodes and arcs from the graph
     virtual void clear();
@@ -180,7 +182,7 @@ namespace gum {
     /// to friendly display the content of the graph in the DOT syntax
     /** @param name The graph name in the dot syntax. Default is G.
      * @return Returns a string describing the graph in the dot syntax */
-    virtual const std::string toDot( const std::string& name = "G" ) const;
+    virtual const std::string toDot() const;
 
     /**
      * The topological order stays the same as long as no variable or arcs are
@@ -188,12 +190,12 @@ namespace gum {
      * @param clear If false returns the previously created topology.
      * @throw InvalidDirectedCycle Raised if this DiGraph contains cycles.
      */
-    const Sequence<NodeId>& topologicalOrder( bool clear = true ) const;
+    const Sequence< NodeId >& topologicalOrder(bool clear = true) const;
     /// @}
 
     private:
     /// The topology sequence of this Directed Graphical Model.
-    mutable Sequence<NodeId>* __mutableTopologicalOrder;
+    mutable Sequence< NodeId >* __mutableTopologicalOrder;
 
     /// Returns a topological order of this DAGModel.
     /// @warning __mutableTopologicalOrder is assumed to be valid and empty
@@ -201,12 +203,12 @@ namespace gum {
   };
 
   /// for friendly displaying the content of directed graphs
-  std::ostream& operator<<( std::ostream&, const DiGraph& );
+  std::ostream& operator<<(std::ostream&, const DiGraph&);
 
 } /* namespace gum */
 
 #ifndef GUM_NO_INLINE
-#include <agrum/graphs/diGraph_inl.h>
-#endif  // GUM_NOINLINE
+#  include <agrum/graphs/diGraph_inl.h>
+#endif   // GUM_NOINLINE
 
 #endif /* GUM_DIGRAPH_H */
