@@ -28,7 +28,7 @@
 #include <iostream>
 #include <utility>
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 
 #include <agrum/graphs/diGraph.h>
 #include <agrum/graphs/undiGraph.h>
@@ -121,7 +121,9 @@ namespace gum {
   /* ===========================================================================
    */
 
-  class MixedGraph : public virtual UndiGraph, public virtual DiGraph {
+  class MixedGraph
+      : public virtual UndiGraph
+      , public virtual DiGraph {
     public:
     // ############################################################################
     /// @name Constructors / Destructors
@@ -135,16 +137,16 @@ namespace gum {
      * @param arcs_resize_policy the resizing policy of this hash table
      * @param edges_size the size of the hash table used to store all the edges
      * @param edges_resize_policy the resizing policy of this hash table */
-    explicit MixedGraph( Size nodes_size = HashTableConst::default_size,
-                         bool nodes_resize_policy = true,
-                         Size arcs_size = HashTableConst::default_size,
-                         bool arcs_resize_policy = true,
-                         Size edges_size = HashTableConst::default_size,
-                         bool edges_resize_policy = true );
+    explicit MixedGraph(Size nodes_size = HashTableConst::default_size,
+                        bool nodes_resize_policy = true,
+                        Size arcs_size = HashTableConst::default_size,
+                        bool arcs_resize_policy = true,
+                        Size edges_size = HashTableConst::default_size,
+                        bool edges_resize_policy = true);
 
     /// copy constructor
     /** @param g the MixedGraph to copy */
-    MixedGraph( const MixedGraph& g );
+    MixedGraph(const MixedGraph& g);
 
     /// destructor
     virtual ~MixedGraph();
@@ -158,17 +160,17 @@ namespace gum {
 
     /// copy operator
     /** @param g the MixedGraph to copy */
-    MixedGraph& operator=( const MixedGraph& g );
+    MixedGraph& operator=(const MixedGraph& g);
 
     /// tests whether two MixedGraphs are identical (same nodes, arcs and edges)
     /** @param g the MixedGraph with which "this" is compared */
     // not virtual : it is a feature !!! :)
-    bool operator==( const MixedGraph& g ) const;
+    bool operator==(const MixedGraph& g) const;
 
     /// tests whether two MixedGraphs are different
     /** @param g the MixedGraph with which "this" is compared */
     // not virtual : it is a feature !!! :)
-    bool operator!=( const MixedGraph& g ) const;
+    bool operator!=(const MixedGraph& g) const;
 
     /// @}
 
@@ -181,7 +183,7 @@ namespace gum {
     /** @param id the id of the node to be removed
      * @warning if the node does not exist, nothing is done. In particular, no
      * exception is raised.*/
-    virtual void eraseNode( const NodeId id );
+    virtual void eraseNode(const NodeId id);
 
     /// removes all the nodes, arcs and edges from the graph
     virtual void clear();
@@ -195,8 +197,8 @@ namespace gum {
      * @param node2 the id to which the path ends
      * @throw NotFound exception is raised if no path can be found between the
      * two nodes */
-    const std::vector<NodeId> mixedOrientedPath( const NodeId node1,
-                                                 const NodeId node2 ) const;
+    const std::vector< NodeId > mixedOrientedPath(const NodeId node1,
+                                                  const NodeId node2) const;
 
     /// returns a mixed/directed path from node1 to node2 in the arc/edge set
     /** This function returns, if any, a path from node1 to node2, using edges
@@ -205,8 +207,11 @@ namespace gum {
      * @param node2 the id to which the path ends
      * @throw NotFound exception is raised if no path can be found between the
      * two nodes */
-    const std::vector<NodeId> mixedUnorientedPath( const NodeId node1,
-                                                   const NodeId node2 ) const;
+    const std::vector< NodeId > mixedUnorientedPath(const NodeId node1,
+                                                    const NodeId node2) const;
+
+    /// to friendly display mixed graph in DOT format
+    virtual const std::string toDot() const;
 
     /// to friendly display the content of the MixedGraph
     virtual const std::string toString() const;
@@ -215,12 +220,12 @@ namespace gum {
   };
 
   /// for friendly displaying the content of directed graphs
-  std::ostream& operator<<( std::ostream&, const MixedGraph& );
+  std::ostream& operator<<(std::ostream&, const MixedGraph&);
 
 } /* namespace gum */
 
 #ifndef GUM_NO_INLINE
-#include <agrum/graphs/mixedGraph_inl.h>
-#endif  // GUM_NOINLINE
+#  include <agrum/graphs/mixedGraph_inl.h>
+#endif   // GUM_NOINLINE
 
 #endif /* GUM_MIXEDGRAPH_H */
