@@ -26,7 +26,7 @@
 #ifndef BNLEARNERLISTENER_H
 #define BNLEARNERLISTENER_H
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 #include <agrum/core/approximations/approximationScheme.h>
 #include <agrum/core/approximations/approximationSchemeListener.h>
 
@@ -43,22 +43,22 @@ namespace gum {
      */
     class BNLearnerListener : public ApproximationSchemeListener {
       public:
-      BNLearnerListener( genericBNLearner* bnl, ApproximationScheme& sch );
+      BNLearnerListener(genericBNLearner* bnl, ApproximationScheme& sch);
       virtual ~BNLearnerListener();
 
-      virtual void whenProgress( const void*  src,
-                                 const Size   pourcent,
-                                 const double error,
-                                 const double time ) final;
-      virtual void whenStop( const void* src, const std::string message ) final;
+      virtual void whenProgress(const void*  src,
+                                const Size   pourcent,
+                                const double error,
+                                const double time) final;
+      virtual void whenStop(const void* src, const std::string message) final;
 
       private:
-      BNLearnerListener( const BNLearnerListener& other );
-      BNLearnerListener& operator=( const BNLearnerListener& other );
+      BNLearnerListener(const BNLearnerListener& other);
+      BNLearnerListener& operator=(const BNLearnerListener& other);
 
       genericBNLearner* __bnlearner;
     };
-  }  // namespace learning
-}  // namespace gum
+  }   // namespace learning
+}   // namespace gum
 
-#endif  // BNLEARNERLISTENER_H
+#endif   // BNLEARNERLISTENER_H
