@@ -22,7 +22,7 @@
  * @brief A class for generic framework of learning algorithms that can easily
  * be used.
  *
- * The pack currently contains K2, GreedyHillClimbing and
+ * The pack currently contains K2, GreedyHillClimbing, miic, 3off2 and
  * LocalSearchWithTabuList
  *
  * @author Christophe GONZALES and Pierre-Henri WUILLEMIN
@@ -33,17 +33,16 @@
 #include <sstream>
 
 #include <agrum/BN/BayesNet.h>
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 #include <agrum/core/bijection.h>
 #include <agrum/core/sequence.h>
 #include <agrum/graphs/DAG.h>
 
-#include <agrum/learning/database/DBCellTranslators/cellTranslatorCompactIntId.h>
-#include <agrum/learning/database/DBCellTranslators/cellTranslatorUniversal.h>
-#include <agrum/learning/database/DBRowTranslatorSet.h>
-#include <agrum/learning/database/DBTransformCompactInt.h>
-#include <agrum/learning/database/databaseFromCSV.h>
-#include <agrum/learning/database/filteredRowGenerators/rowGeneratorIdentity.h>
+#include <agrum/learning/database/DBTranslator4LabelizedVariable.h>
+#include <agrum/learning/database/DBRowGeneratorParser.h>
+#include <agrum/learning/database/DBInitializerFromCSV.h>
+#include <agrum/learning/database/databaseTable.h>
+#include <agrum/learning/database/DBRowGeneratorParser.h>
 
 #include <agrum/learning/scores_and_tests/scoreAIC.h>
 #include <agrum/learning/scores_and_tests/scoreBD.h>
@@ -77,6 +76,7 @@
 #include <agrum/core/approximations/approximationSchemeListener.h>
 
 #include <agrum/learning/K2.h>
+#include <agrum/learning/Miic.h>
 #include <agrum/learning/greedyHillClimbing.h>
 #include <agrum/learning/localSearchWithTabuList.h>
 
@@ -86,9 +86,6 @@ namespace gum {
 
   namespace learning {
 
-    /// reads a file and returns a databaseVectInRam
-    DatabaseVectInRAM readFile( const std::string& filename );
-
     class BNLearnerListener;
 
     /** @class genericBNLearner
@@ -115,9 +112,11 @@ namespace gum {
       enum class AlgoType {
         K2,
         GREEDY_HILL_CLIMBING,
-        LOCAL_SEARCH_WITH_TABU_LIST
+        LOCAL_SEARCH_WITH_TABU_LIST,
+        MIIC_THREE_OFF_TWO
       };
 
+
       /// a helper to easily read databases
       class Database {
         public:
@@ -127,8 +126,9 @@ namespace gum {
         /// @{
 
         /// default constructor
-        Database( const std::string& file );
-        Database( const DatabaseVectInRAM& db );
+        explicit Database(const std::string&                file,
+                          const std::vector< std::string >& missing_symbols);
+        explicit Database(const DatabaseTable<>& db);
 
         /// default constructor with defined modalities for some variables
         /**
@@ -142,9 +142,11 @@ namespace gum {
          * @param check_database If true, the database will be checked.
          *
          */
-        Database( std::string                                filename,
-                  const NodeProperty<Sequence<std::string>>& modalities,
-                  bool check_database = false );
+        /*
+        Database(std::string                                    filename,
+                 const NodeProperty< Sequence< std::string > >& modalities,
+                 bool check_database = false);
+        */
 
         /// default constructor for the aprioris
         /** We must ensure that, when reading the apriori database, if the
@@ -153,7 +155,9 @@ namespace gum {
          * apriori database is the same as in the score/parameter database
          * read before creating the apriori. This is compulsory to have
          * aprioris that make sense. */
-        Database( std::string filename, Database& score_database );
+        Database(const std::string&                filename,
+                 Database&                         score_database,
+                 const std::vector< std::string >& missing_symbols);
 
         /// default constructor for the aprioris
         /** We must ensure that, when reading the apriori database, if the
@@ -172,15 +176,22 @@ namespace gum {
          * of id 1 in the BN will have 3 modalities, the first one being True,
          * the second one being False, and the third bein Big.
          */
-        Database( std::string                                filename,
-                  Database&                                  score_database,
-                  const NodeProperty<Sequence<std::string>>& modalities );
+        template < typename GUM_SCALAR >
+        Database(const std::string&                 filename,
+                 const gum::BayesNet< GUM_SCALAR >& bn,
+                 const std::vector< std::string >&  missing_symbols);
+
+        template < typename GUM_SCALAR >
+        Database(const std::string&                 filename,
+                 Database&                          score_database,
+                 const gum::BayesNet< GUM_SCALAR >& bn,
+                 const std::vector< std::string >&  missing_symbols);
 
         /// copy constructor
-        Database( const Database& from );
+        Database(const Database& from);
 
         /// move constructor
-        Database( Database&& from );
+        Database(Database&& from);
 
         /// destructor
         ~Database();
@@ -193,10 +204,10 @@ namespace gum {
         /// @{
 
         /// copy operator
-        Database& operator=( const Database& from );
+        Database& operator=(const Database& from);
 
         /// move operator
-        Database& operator=( Database&& from );
+        Database& operator=(Database&& from);
 
         /// @}
 
@@ -205,62 +216,44 @@ namespace gum {
         // ########################################################################
         /// @{
 
-        /// returns the row filter
-        DBRowFilter<DatabaseVectInRAM::Handler,
-                    DBRowTranslatorSet<CellTranslatorCompactIntId>,
-                    FilteredRowGeneratorSet<RowGeneratorIdentity>>&
-        rowFilter();
+        /// returns the parser for the database
+        DBRowGeneratorParser<>& parser();
 
         /// returns the modalities of the variables
-        std::vector<Size>& modalities() noexcept;
+        std::vector< Size >& modalities() noexcept;
 
         /// returns the names of the variables in the database
-        const std::vector<std::string>& names() const noexcept;
+        const std::vector< std::string >& names() const noexcept;
 
         /// returns the node id corresponding to a variable name
-        NodeId idFromName( const std::string& var_name ) const;
+        NodeId idFromName(const std::string& var_name) const;
 
         /// returns the variable name corresponding to a given node id
-        const std::string& nameFromId( NodeId id ) const;
+        const std::string& nameFromId(NodeId id) const;
 
-        /// returns the "raw" translators (needed for the aprioris)
-        /** We must ensure that, when reading the apriori database, if the
-         * "apriori" rowFilter says that a given variable has value i
-         * (given by its fast translator), the corresponding "raw" value in the
-         * apriori database is the same as in the score/parameter database
-         * read before creating the apriori. This is compulsory to have
-         * aprioris that make sense. */
-        DBRowTranslatorSet<CellTranslatorUniversal>& rawTranslators();
+        /// returns the internal database table
+        const DatabaseTable<>& databaseTable() const;
+
+        /// returns the set of missing symbols taken into account
+        const std::vector< std::string >& missingSymbols() const;
 
         /// @}
 
         protected:
         /// the database itself
-        DatabaseVectInRAM __database;
+        DatabaseTable<> __database;
 
-        /// the rwo translators
-        DBRowTranslatorSet<CellTranslatorUniversal> __raw_translators;
-
-        /// the translators used for reading the database
-        DBRowTranslatorSet<CellTranslatorCompactIntId> __translators;
-
-        /// the generators used for reading the database
-        FilteredRowGeneratorSet<RowGeneratorIdentity> __generators;
-
-        /// the filtered row that reads the database
-        DBRowFilter<DatabaseVectInRAM::Handler,
-                    DBRowTranslatorSet<CellTranslatorCompactIntId>,
-                    FilteredRowGeneratorSet<RowGeneratorIdentity>>* __row_filter{
-            nullptr};
+        /// the parser used for reading the database
+        DBRowGeneratorParser<>* __parser{nullptr};
 
         /// the modalities of the variables
-        std::vector<Size> __modalities;
+        std::vector< Size > __modalities;
 
         /// a hashtable assigning to each variable name its NodeId
-        Bijection<std::string, NodeId> __name2nodeId;
+        Bijection< std::string, NodeId > __name2nodeId;
 
 /// the max number of threads authorized
-#if defined( _OPENMP ) && defined( NDEBUG )
+#if defined(_OPENMP) && defined(NDEBUG)
         Size __max_threads_number{getMaxNumberOfThreads()};
 #else
         Size __max_threads_number{1};
@@ -268,8 +261,15 @@ namespace gum {
 
         /// the minimal number of rows to parse (on average) by thread
         Size __min_nb_rows_per_thread{100};
+
+        private:
+        // returns the set of variables as a BN. This is convenient for
+        // the constructors of apriori Databases
+        template < typename GUM_SCALAR >
+        BayesNet< GUM_SCALAR > __BNVars() const;
       };
 
+
       public:
       // ##########################################################################
       /// @name Constructors / Destructors
@@ -281,8 +281,9 @@ namespace gum {
        * read the database file for the score / parameter estimation and var
        * names
        */
-      genericBNLearner( const std::string& db );
-      genericBNLearner( const DatabaseVectInRAM& db );
+      genericBNLearner(const std::string&                filename,
+                       const std::vector< std::string >& missing_symbols);
+      genericBNLearner(const DatabaseTable<>& db);
 
       /**
        * read the database file for the score / parameter estimation and var
@@ -303,15 +304,16 @@ namespace gum {
        * as being exactly those of the variables of the BN (as a consequence,
        * if we find other values in the database, an exception will be raised
        * during learning). */
-      genericBNLearner( const std::string&                         filename,
-                        const NodeProperty<Sequence<std::string>>& modalities,
-                        bool parse_database = false );
+      template < typename GUM_SCALAR >
+      genericBNLearner(const std::string&                 filename,
+                       const gum::BayesNet< GUM_SCALAR >& src,
+                       const std::vector< std::string >&  missing_symbols);
 
       /// copy constructor
-      genericBNLearner( const genericBNLearner& );
+      genericBNLearner(const genericBNLearner&);
 
       /// move constructor
-      genericBNLearner( genericBNLearner&& );
+      genericBNLearner(genericBNLearner&&);
 
       /// destructor
       virtual ~genericBNLearner();
@@ -324,10 +326,10 @@ namespace gum {
       /// @{
 
       /// copy operator
-      genericBNLearner& operator=( const genericBNLearner& );
+      genericBNLearner& operator=(const genericBNLearner&);
 
       /// move operator
-      genericBNLearner& operator=( genericBNLearner&& );
+      genericBNLearner& operator=(genericBNLearner&&);
 
       /// @}
 
@@ -339,24 +341,28 @@ namespace gum {
       /// learn a structure from a file (must have read the db before)
       DAG learnDAG();
 
+      /// learn a partial structure from a file (must have read the db before and
+      /// must have selected miic or 3off2)
+      MixedGraph learnMixedStructure();
+
       /// sets an initial DAG structure
-      void setInitialDAG( const DAG& );
+      void setInitialDAG(const DAG&);
 
       /// returns the names of the variables in the database
-      const std::vector<std::string>& names() const;
+      const std::vector< std::string >& names() const;
 
       /// returns the names of the variables in the database
-      const std::vector<Size>& modalities() noexcept;
+      const std::vector< Size >& modalities() noexcept;
 
       /// returns the node id corresponding to a variable name
       /**
        * @throw MissingVariableInDatabase if a variable of the BN is not found
        * in the database.
        */
-      NodeId idFromName( const std::string& var_name ) const;
+      NodeId idFromName(const std::string& var_name) const;
 
       /// returns the variable name corresponding to a given node id
-      const std::string& nameFromId( NodeId id ) const;
+      const std::string& nameFromId(NodeId id) const;
 
       /// @}
 
@@ -391,7 +397,7 @@ namespace gum {
       /// @{
 
       /// sets the apriori weight
-      void setAprioriWeight( double weight );
+      void setAprioriWeight(double weight);
 
       /// use no apriori
       void useNoApriori();
@@ -400,10 +406,10 @@ namespace gum {
       /** @param weight pass in argument a weight if you wish to assign a weight
        * to the smoothing, else the current weight of the genericBNLearner will
        * be used. */
-      void useAprioriSmoothing( double weight = -1 );
+      void useAprioriSmoothing(double weight = -1);
 
       /// use the Dirichlet apriori
-      void useAprioriDirichlet( const std::string& filename );
+      void useAprioriDirichlet(const std::string& filename);
 
       /// @}
 
@@ -419,60 +425,85 @@ namespace gum {
       /** @param tabu_size indicate the size of the tabu list
        * @param nb_decrease indicate the max number of changes decreasing the
        * score consecutively that we allow to apply */
-      void useLocalSearchWithTabuList( Size tabu_size = 100,
-                                       Size nb_decrease = 2 ) noexcept;
+      void useLocalSearchWithTabuList(Size tabu_size = 100,
+                                      Size nb_decrease = 2) noexcept;
 
       /// indicate that we wish to use K2
-      void useK2( const Sequence<NodeId>& order ) noexcept;
+      void useK2(const Sequence< NodeId >& order) noexcept;
 
       /// indicate that we wish to use K2
-      void useK2( const std::vector<NodeId>& order ) noexcept;
+      void useK2(const std::vector< NodeId >& order) noexcept;
+
+      /// indicate that we wish to use 3off2
+      void use3off2() noexcept;
+
+      /// indicate that we wish to use MIIC
+      void useMIIC() noexcept;
 
       /// @}
 
+      // ##########################################################################
+      /// @name 3off2/MIIC parameterization and specific results
+      // ##########################################################################
+      /// @{
+      /// indicate that we wish to use the NML correction for 3off2
+      /// @throws OperationNotAllowed when 3off2 is not the selected algorithm
+      void useNML();
+      /// indicate that we wish to use the MDL correction for 3off2
+      /// @throws OperationNotAllowed when 3off2 is not the selected algorithm
+      void useMDL();
+      /// indicate that we wish to use the NoCorr correction for 3off2
+      /// @throws OperationNotAllowed when 3off2 is not the selected algorithm
+      void useNoCorr();
+
+      /// get the list of arcs hiding latent variables
+      /// @throws OperationNotAllowed when 3off2 is not the selected algorithm
+      const std::vector< Arc > latentVariables() const;
+
+      /// @}
       // ##########################################################################
       /// @name Accessors / Modifiers for adding constraints on learning
       // ##########################################################################
       /// @{
 
       /// sets the max indegree
-      void setMaxIndegree( Size max_indegree );
+      void setMaxIndegree(Size max_indegree);
 
       /// sets a partial order on the nodes
-      void setSliceOrder( const NodeProperty<NodeId>& slice_order );
+      void setSliceOrder(const NodeProperty< NodeId >& slice_order);
 
       /// assign a set of forbidden arcs
-      void setForbiddenArcs( const ArcSet& set );
+      void setForbiddenArcs(const ArcSet& set);
 
       /// @name assign a new forbidden arc
       /// @{
-      void addForbiddenArc( const Arc& arc );
-      void addForbiddenArc( const NodeId tail, const NodeId head );
-      void addForbiddenArc( const std::string& tail, const std::string& head );
+      void addForbiddenArc(const Arc& arc);
+      void addForbiddenArc(const NodeId tail, const NodeId head);
+      void addForbiddenArc(const std::string& tail, const std::string& head);
       /// @}
 
       /// @name remove a forbidden arc
       /// @{
-      void eraseForbiddenArc( const Arc& arc );
-      void eraseForbiddenArc( const NodeId tail, const NodeId head );
-      void eraseForbiddenArc( const std::string& tail, const std::string& head );
+      void eraseForbiddenArc(const Arc& arc);
+      void eraseForbiddenArc(const NodeId tail, const NodeId head);
+      void eraseForbiddenArc(const std::string& tail, const std::string& head);
       ///@}
 
       /// assign a set of forbidden arcs
-      void setMandatoryArcs( const ArcSet& set );
+      void setMandatoryArcs(const ArcSet& set);
 
       /// @name assign a new forbidden arc
       ///@{
-      void addMandatoryArc( const Arc& arc );
-      void addMandatoryArc( const NodeId tail, const NodeId head );
-      void addMandatoryArc( const std::string& tail, const std::string& head );
+      void addMandatoryArc(const Arc& arc);
+      void addMandatoryArc(const NodeId tail, const NodeId head);
+      void addMandatoryArc(const std::string& tail, const std::string& head);
       ///@}
 
       /// @name remove a forbidden arc
       ///@{
-      void eraseMandatoryArc( const Arc& arc );
-      void eraseMandatoryArc( const NodeId tail, const NodeId head );
-      void eraseMandatoryArc( const std::string& tail, const std::string& head );
+      void eraseMandatoryArc(const Arc& arc);
+      void eraseMandatoryArc(const NodeId tail, const NodeId head);
+      void eraseMandatoryArc(const std::string& tail, const std::string& head);
       /// @}
 
       ///@}
@@ -490,6 +521,9 @@ namespace gum {
       /// the parameter estimator to use
       ParamEstimator<>* __param_estimator{nullptr};
 
+      /// the selected correction for 3off2 and miic
+      CorrectedMutualInformation<>* __mutual_info{nullptr};
+
       /// the a priori selected for the score and parameters
       AprioriType __apriori_type{AprioriType::NO_APRIORI};
 
@@ -520,6 +554,9 @@ namespace gum {
       /// the K2 algorithm
       K2 __K2;
 
+      /// the 3off2 algorithm
+      Miic __miic_3off2;
+
       /// the greedy hill climbing algorithm
       GreedyHillClimbing __greedy_hill_climbing;
 
@@ -530,7 +567,7 @@ namespace gum {
       Database __score_database;
 
       /// indicates the values the user specified for the translators
-      NodeProperty<Sequence<std::string>> __user_modalities;
+      NodeProperty< Sequence< std::string > > __user_modalities;
 
       /// indicates whether we shall parse the database to update
       /// __user_modalities
@@ -549,7 +586,12 @@ namespace gum {
       const ApproximationScheme* __current_algorithm{nullptr};
 
       /// reads a file and returns a databaseVectInRam
-      static DatabaseVectInRAM __readFile( const std::string& filename );
+      static DatabaseTable<>
+        __readFile(const std::string&                filename,
+                   const std::vector< std::string >& missing_symbols);
+
+      /// checks whether the extension of a CSV filename is correct
+      static void __checkFileName(const std::string& filename);
 
       /// create the apriori used for learning
       void __createApriori();
@@ -558,11 +600,14 @@ namespace gum {
       void __createScore();
 
       /// create the parameter estimator used for learning
-      void __createParamEstimator( bool take_into_account_score = true );
+      void __createParamEstimator(bool take_into_account_score = true);
 
       /// returns the DAG learnt
       DAG __learnDAG();
 
+      /// prepares the initial graph for 3off2 or miic
+      MixedGraph __prepare_miic_3off2();
+
       /// checks whether the current score and apriori are compatible
       /** @returns true if the apriori is compatible with the score.
        * @throws IncompatibleScoreApriori is raised if the apriori is known to
@@ -599,27 +644,26 @@ namespace gum {
       // very simples methods here.
       /// {@    /// distribute signals
       INLINE void setCurrentApproximationScheme(
-          const ApproximationScheme* approximationScheme ) {
+        const ApproximationScheme* approximationScheme) {
         __current_algorithm = approximationScheme;
       }
 
       INLINE void
-      distributeProgress( const ApproximationScheme* approximationScheme,
-                          Size                       pourcent,
-                          double                     error,
-                          double                     time ) {
-        setCurrentApproximationScheme( approximationScheme );
+        distributeProgress(const ApproximationScheme* approximationScheme,
+                           Size                       pourcent,
+                           double                     error,
+                           double                     time) {
+        setCurrentApproximationScheme(approximationScheme);
 
-        if ( onProgress.hasListener() )
-          GUM_EMIT3( onProgress, pourcent, error, time );
+        if (onProgress.hasListener()) GUM_EMIT3(onProgress, pourcent, error, time);
       };
 
       /// distribute signals
-      INLINE void distributeStop( const ApproximationScheme* approximationScheme,
-                                  std::string                message ) {
-        setCurrentApproximationScheme( approximationScheme );
+      INLINE void distributeStop(const ApproximationScheme* approximationScheme,
+                                 std::string                message) {
+        setCurrentApproximationScheme(approximationScheme);
 
-        if ( onStop.hasListener() ) GUM_EMIT1( onStop, message );
+        if (onStop.hasListener()) GUM_EMIT1(onStop, message);
       };
       /// @}
 
@@ -627,18 +671,18 @@ namespace gum {
       /// If the criterion was disabled it will be enabled
       /// @{
       /// @throw OutOfLowerBound if eps<0
-      void setEpsilon( double eps ) {
-        __K2.approximationScheme().setEpsilon( eps );
-        __greedy_hill_climbing.setEpsilon( eps );
-        __local_search_with_tabu_list.setEpsilon( eps );
+      void setEpsilon(double eps) {
+        __K2.approximationScheme().setEpsilon(eps);
+        __greedy_hill_climbing.setEpsilon(eps);
+        __local_search_with_tabu_list.setEpsilon(eps);
       };
 
       /// Get the value of epsilon
-      double epsilon( void ) const {
-        if ( __current_algorithm != nullptr )
+      double epsilon() const {
+        if (__current_algorithm != nullptr)
           return __current_algorithm->epsilon();
         else
-          GUM_ERROR( FatalError, "No chosen algorithm for learning" );
+          GUM_ERROR(FatalError, "No chosen algorithm for learning");
       };
 
       /// Disable stopping criterion on epsilon
@@ -658,10 +702,10 @@ namespace gum {
       /// @return true if stopping criterion on epsilon is enabled, false
       /// otherwise
       bool isEnabledEpsilon() const {
-        if ( __current_algorithm != nullptr )
+        if (__current_algorithm != nullptr)
           return __current_algorithm->isEnabledEpsilon();
         else
-          GUM_ERROR( FatalError, "No chosen algorithm for learning" );
+          GUM_ERROR(FatalError, "No chosen algorithm for learning");
       };
       /// @}
 
@@ -670,18 +714,18 @@ namespace gum {
       /// If the criterion was disabled it will be enabled
       /// @{
       /// @throw OutOfLowerBound if rate<0
-      void setMinEpsilonRate( double rate ) {
-        __K2.approximationScheme().setMinEpsilonRate( rate );
-        __greedy_hill_climbing.setMinEpsilonRate( rate );
-        __local_search_with_tabu_list.setMinEpsilonRate( rate );
+      void setMinEpsilonRate(double rate) {
+        __K2.approximationScheme().setMinEpsilonRate(rate);
+        __greedy_hill_climbing.setMinEpsilonRate(rate);
+        __local_search_with_tabu_list.setMinEpsilonRate(rate);
       };
 
       /// Get the value of the minimal epsilon rate
-      double minEpsilonRate( void ) const {
-        if ( __current_algorithm != nullptr )
+      double minEpsilonRate() const {
+        if (__current_algorithm != nullptr)
           return __current_algorithm->minEpsilonRate();
         else
-          GUM_ERROR( FatalError, "No chosen algorithm for learning" );
+          GUM_ERROR(FatalError, "No chosen algorithm for learning");
       };
 
       /// Disable stopping criterion on epsilon rate
@@ -699,10 +743,10 @@ namespace gum {
       /// @return true if stopping criterion on epsilon rate is enabled, false
       /// otherwise
       bool isEnabledMinEpsilonRate() const {
-        if ( __current_algorithm != nullptr )
+        if (__current_algorithm != nullptr)
           return __current_algorithm->isEnabledMinEpsilonRate();
         else
-          GUM_ERROR( FatalError, "No chosen algorithm for learning" );
+          GUM_ERROR(FatalError, "No chosen algorithm for learning");
       };
       /// @}
 
@@ -711,18 +755,18 @@ namespace gum {
       /// If the criterion was disabled it will be enabled
       /// @param max The maximum number of iterations
       /// @throw OutOfLowerBound if max<=1
-      void setMaxIter( Size max ) {
-        __K2.approximationScheme().setMaxIter( max );
-        __greedy_hill_climbing.setMaxIter( max );
-        __local_search_with_tabu_list.setMaxIter( max );
+      void setMaxIter(Size max) {
+        __K2.approximationScheme().setMaxIter(max);
+        __greedy_hill_climbing.setMaxIter(max);
+        __local_search_with_tabu_list.setMaxIter(max);
       };
 
       /// @return the criterion on number of iterations
-      Size maxIter( void ) const {
-        if ( __current_algorithm != nullptr )
+      Size maxIter() const {
+        if (__current_algorithm != nullptr)
           return __current_algorithm->maxIter();
         else
-          GUM_ERROR( FatalError, "No chosen algorithm for learning" );
+          GUM_ERROR(FatalError, "No chosen algorithm for learning");
       };
 
       /// Disable stopping criterion on max iterations
@@ -740,10 +784,10 @@ namespace gum {
       /// @return true if stopping criterion on max iterations is enabled, false
       /// otherwise
       bool isEnabledMaxIter() const {
-        if ( __current_algorithm != nullptr )
+        if (__current_algorithm != nullptr)
           return __current_algorithm->isEnabledMaxIter();
         else
-          GUM_ERROR( FatalError, "No chosen algorithm for learning" );
+          GUM_ERROR(FatalError, "No chosen algorithm for learning");
       };
       /// @}
 
@@ -753,26 +797,26 @@ namespace gum {
       /// @throw OutOfLowerBound if timeout<=0.0
       /** timeout is time in second (double).
        */
-      void setMaxTime( double timeout ) {
-        __K2.approximationScheme().setMaxTime( timeout );
-        __greedy_hill_climbing.setMaxTime( timeout );
-        __local_search_with_tabu_list.setMaxTime( timeout );
+      void setMaxTime(double timeout) {
+        __K2.approximationScheme().setMaxTime(timeout);
+        __greedy_hill_climbing.setMaxTime(timeout);
+        __local_search_with_tabu_list.setMaxTime(timeout);
       }
 
       /// returns the timeout (in seconds)
-      double maxTime( void ) const {
-        if ( __current_algorithm != nullptr )
+      double maxTime() const {
+        if (__current_algorithm != nullptr)
           return __current_algorithm->maxTime();
         else
-          GUM_ERROR( FatalError, "No chosen algorithm for learning" );
+          GUM_ERROR(FatalError, "No chosen algorithm for learning");
       };
 
       /// get the current running time in second (double)
-      double currentTime( void ) const {
-        if ( __current_algorithm != nullptr )
+      double currentTime() const {
+        if (__current_algorithm != nullptr)
           return __current_algorithm->currentTime();
         else
-          GUM_ERROR( FatalError, "No chosen algorithm for learning" );
+          GUM_ERROR(FatalError, "No chosen algorithm for learning");
       };
 
       /// Disable stopping criterion on timeout
@@ -789,61 +833,43 @@ namespace gum {
       /// @return true if stopping criterion on timeout is enabled, false
       /// otherwise
       bool isEnabledMaxTime() const {
-        if ( __current_algorithm != nullptr )
+        if (__current_algorithm != nullptr)
           return __current_algorithm->isEnabledMaxTime();
         else
-          GUM_ERROR( FatalError, "No chosen algorithm for learning" );
+          GUM_ERROR(FatalError, "No chosen algorithm for learning");
       };
       /// @}
 
       /// how many samples between 2 stopping isEnableds
       /// @{
       /// @throw OutOfLowerBound if p<1
-      void setPeriodSize( Size p ) {
-        __K2.approximationScheme().setPeriodSize( p );
-        __greedy_hill_climbing.setPeriodSize( p );
-        __local_search_with_tabu_list.setPeriodSize( p );
+      void setPeriodSize(Size p) {
+        __K2.approximationScheme().setPeriodSize(p);
+        __greedy_hill_climbing.setPeriodSize(p);
+        __local_search_with_tabu_list.setPeriodSize(p);
       };
 
-      Size periodSize( void ) const {
-        if ( __current_algorithm != nullptr )
+      Size periodSize() const {
+        if (__current_algorithm != nullptr)
           return __current_algorithm->periodSize();
         else
-          GUM_ERROR( FatalError, "No chosen algorithm for learning" );
-      };
-      /// @}
-
-      /// size of burn in on number of iteration
-      /// @{
-
-      /// @throw OutOfLowerBound if b<1
-      void setBurnIn( Size b ) {
-        __K2.approximationScheme().setBurnIn( b );
-        __greedy_hill_climbing.setBurnIn( b );
-        __local_search_with_tabu_list.setBurnIn( b );
-      };
-
-      Size burnIn( void ) const {
-        if ( __current_algorithm != nullptr )
-          return __current_algorithm->burnIn();
-        else
-          GUM_ERROR( FatalError, "No chosen algorithm for learning" );
+          GUM_ERROR(FatalError, "No chosen algorithm for learning");
       };
       /// @}
 
       /// verbosity
       /// @{
-      void setVerbosity( bool v ) {
-        __K2.approximationScheme().setVerbosity( v );
-        __greedy_hill_climbing.setVerbosity( v );
-        __local_search_with_tabu_list.setVerbosity( v );
+      void setVerbosity(bool v) {
+        __K2.approximationScheme().setVerbosity(v);
+        __greedy_hill_climbing.setVerbosity(v);
+        __local_search_with_tabu_list.setVerbosity(v);
       };
 
-      bool verbosity( void ) const {
-        if ( __current_algorithm != nullptr )
+      bool verbosity() const {
+        if (__current_algorithm != nullptr)
           return __current_algorithm->verbosity();
         else
-          GUM_ERROR( FatalError, "No chosen algorithm for learning" );
+          GUM_ERROR(FatalError, "No chosen algorithm for learning");
       };
       /// @}
 
@@ -851,26 +877,26 @@ namespace gum {
       /// @{
 
       ApproximationSchemeSTATE stateApproximationScheme() const {
-        if ( __current_algorithm != nullptr )
+        if (__current_algorithm != nullptr)
           return __current_algorithm->stateApproximationScheme();
         else
-          GUM_ERROR( FatalError, "No chosen algorithm for learning" );
+          GUM_ERROR(FatalError, "No chosen algorithm for learning");
       };
 
       /// @throw OperationNotAllowed if scheme not performed
       Size nbrIterations() const {
-        if ( __current_algorithm != nullptr )
+        if (__current_algorithm != nullptr)
           return __current_algorithm->nbrIterations();
         else
-          GUM_ERROR( FatalError, "No chosen algorithm for learning" );
+          GUM_ERROR(FatalError, "No chosen algorithm for learning");
       };
 
       /// @throw OperationNotAllowed if scheme not performed or verbosity=false
-      const std::vector<double>& history() const {
-        if ( __current_algorithm != nullptr )
+      const std::vector< double >& history() const {
+        if (__current_algorithm != nullptr)
           return __current_algorithm->history();
         else
-          GUM_ERROR( FatalError, "No chosen algorithm for learning" );
+          GUM_ERROR(FatalError, "No chosen algorithm for learning");
       };
       /// @}
     };
@@ -881,7 +907,9 @@ namespace gum {
 
 /// include the inlined functions if necessary
 #ifndef GUM_NO_INLINE
-#include <agrum/learning/BNLearnUtils/genericBNLearner_inl.h>
+#  include <agrum/learning/BNLearnUtils/genericBNLearner_inl.h>
 #endif /* GUM_NO_INLINE */
 
+#include <agrum/learning/BNLearnUtils/genericBNLearner_tpl.h>
+
 #endif /* GUM_LEARNING_GENERIC_BN_LEARNER_H */
