@@ -27,7 +27,7 @@
 
 #include <vector>
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 #include <agrum/learning/aprioris/apriori.h>
 
 namespace gum {
@@ -38,9 +38,9 @@ namespace gum {
      * @brief the smooth a priori: adds a weight w to all the countings
      * @ingroup learning_group
      */
-    template <typename IdSetAlloc = std::allocator<Idx>,
-              typename CountAlloc = std::allocator<double>>
-    class AprioriSmoothing : public Apriori<IdSetAlloc, CountAlloc> {
+    template < typename IdSetAlloc = std::allocator< Idx >,
+               typename CountAlloc = std::allocator< double > >
+    class AprioriSmoothing : public Apriori< IdSetAlloc, CountAlloc > {
       public:
       using type = AprioriSmoothingType;
 
@@ -53,7 +53,7 @@ namespace gum {
       AprioriSmoothing();
 
       /// virtual copy constructor
-      virtual AprioriSmoothing<IdSetAlloc, CountAlloc>* copyFactory() const;
+      virtual AprioriSmoothing< IdSetAlloc, CountAlloc >* copyFactory() const;
 
       /// destructor
       virtual ~AprioriSmoothing();
@@ -69,7 +69,7 @@ namespace gum {
       virtual void compute() final;
 
       /// indicates whether an apriori is of a certain type
-      virtual bool isOfType( const std::string& type ) final;
+      virtual bool isOfType(const std::string& type) final;
 
       /// returns the type of the apriori
       virtual const std::string& getType() const noexcept final;
@@ -78,14 +78,14 @@ namespace gum {
 
       protected:
       /// copy constructor
-      AprioriSmoothing( const AprioriSmoothing<IdSetAlloc, CountAlloc>& from );
+      AprioriSmoothing(const AprioriSmoothing< IdSetAlloc, CountAlloc >& from);
 
       /// move constructor
-      AprioriSmoothing( AprioriSmoothing<IdSetAlloc, CountAlloc>&& from );
+      AprioriSmoothing(AprioriSmoothing< IdSetAlloc, CountAlloc >&& from);
 
       /// prevent copy operator
-      AprioriSmoothing<IdSetAlloc, CountAlloc>&
-      operator=( const AprioriSmoothing<IdSetAlloc, CountAlloc>& ) = delete;
+      AprioriSmoothing< IdSetAlloc, CountAlloc >&
+        operator=(const AprioriSmoothing< IdSetAlloc, CountAlloc >&) = delete;
     };
 
   } /* namespace learning */
