@@ -26,7 +26,7 @@
 #ifndef GUM_LEARNING_STRUCTURAL_CONSTRAINT_DIGRAPH_H
 #define GUM_LEARNING_STRUCTURAL_CONSTRAINT_DIGRAPH_H
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 #include <agrum/graphs/diGraph.h>
 #include <agrum/learning/constraints/structuralConstraint.h>
 #include <agrum/learning/structureUtils/graphChange.h>
@@ -56,16 +56,16 @@ namespace gum {
       StructuralConstraintDiGraph();
 
       /// constructor starting with an empty graph with a given number of nodes
-      StructuralConstraintDiGraph( Size nb_nodes );
+      StructuralConstraintDiGraph(Size nb_nodes);
 
       /// constructor starting with a given graph
-      StructuralConstraintDiGraph( const DiGraph& graph );
+      StructuralConstraintDiGraph(const DiGraph& graph);
 
       /// copy constructor
-      StructuralConstraintDiGraph( const StructuralConstraintDiGraph& from );
+      StructuralConstraintDiGraph(const StructuralConstraintDiGraph& from);
 
       /// move constructor
-      StructuralConstraintDiGraph( StructuralConstraintDiGraph&& from );
+      StructuralConstraintDiGraph(StructuralConstraintDiGraph&& from);
 
       /// destructor
       virtual ~StructuralConstraintDiGraph();
@@ -79,10 +79,10 @@ namespace gum {
 
       /// copy operator
       StructuralConstraintDiGraph&
-      operator=( const StructuralConstraintDiGraph& from );
+        operator=(const StructuralConstraintDiGraph& from);
 
       /// move operator
-      StructuralConstraintDiGraph& operator=( StructuralConstraintDiGraph&& from );
+      StructuralConstraintDiGraph& operator=(StructuralConstraintDiGraph&& from);
 
       /// @}
 
@@ -92,36 +92,36 @@ namespace gum {
       /// @{
 
       /// sets a new empty graph from which we will perform checkings
-      void setGraph( Size nb_nodes );
+      void setGraph(Size nb_nodes);
 
       /// sets a new graph from which we will perform checkings
-      void setGraphAlone( const DiGraph& graph );
+      void setGraphAlone(const DiGraph& graph);
 
       /// notify the constraint of a modification of the graph
       /** @warning If an already existing arc is added nothing is done. In
        * particular, no exception is raised.
        * @throws InvalidNode exception is thrown if an arc (x,y) is added and x
        * or y does not belong to the graph nodes */
-      void modifyGraphAlone( const ArcAddition& change );
+      void modifyGraphAlone(const ArcAddition& change);
 
       /// notify the constraint of a modification of the graph
       /** @warning If a nonexisting arc is removed, nothing is done. In
        * particular, no exception is raised. */
-      void modifyGraphAlone( const ArcDeletion& change );
+      void modifyGraphAlone(const ArcDeletion& change);
 
       /// notify the constraint of a modification of the graph
       /** @warning If an already existing arc is added, or if a nonexisting arc
        * is removed, nothing is done. In particular, no exception is raised.
        * @throws InvalidNode exception is thrown if at least one extremity of
        * the arc does not belong to the graph nodes */
-      void modifyGraphAlone( const ArcReversal& change );
+      void modifyGraphAlone(const ArcReversal& change);
 
       /// notify the constraint of a modification of the graph
       /** @warning If an already existing arc is added, or if a nonexisting arc
        * is removed, nothing is done. In particular, no exception is raised.
        * @throws InvalidNode exception is thrown if an arc (x,y) is added and x
        * or y does not belong to the graph nodes */
-      void modifyGraphAlone( const GraphChange& change );
+      void modifyGraphAlone(const GraphChange& change);
 
       /// indicates whether a change will always violate the constraint
       /** Some learning algorithms need examine several times whether a given
@@ -137,21 +137,21 @@ namespace gum {
        * arc.
        * Such graph changes are always invalid and are therefore tagged as such
        * by the isAlwaysInvalid method. */
-      bool isAlwaysInvalidAlone( const GraphChange& change ) const;
+      bool isAlwaysInvalidAlone(const GraphChange& change) const;
 
       /// checks whether the constraints enable to add arc (x,y)
       /** an arc can be added if and only if its extremal nodes belong to the
        * graph and the arc does not already exist. */
-      bool checkArcAdditionAlone( NodeId x, NodeId y ) const;
+      bool checkArcAdditionAlone(NodeId x, NodeId y) const;
 
       /// checks whether the constraints enable to remove arc (x,y)
       /** an arc can be removed if and only if the arc exists. */
-      bool checkArcDeletionAlone( NodeId x, NodeId y ) const;
+      bool checkArcDeletionAlone(NodeId x, NodeId y) const;
 
       /// checks whether the constraints enable to reverse arc (x,y)
       /** an arc can be reversed if and only if it exists and arc (y,x)
        * does not. */
-      bool checkArcReversalAlone( NodeId x, NodeId y ) const;
+      bool checkArcReversalAlone(NodeId x, NodeId y) const;
 
       /// checks whether the constraints enable to perform a graph change
       /** An arc can be added if and only if its extremal nodes belong to the
@@ -159,32 +159,32 @@ namespace gum {
        * An arc can be removed if and only if the arc exists.
        * An arc (x,y) can be reversed if and only if it exists and arc (y,x)
        * does not. */
-      bool checkModificationAlone( const GraphChange& change ) const;
+      bool checkModificationAlone(const GraphChange& change) const;
 
       /// checks whether the constraints enable to add an arc
       /** an arc can be added if and only if its extremal nodes belong to the
        * graph and the arc does not already exist. */
-      bool checkModificationAlone( const ArcAddition& change ) const;
+      bool checkModificationAlone(const ArcAddition& change) const;
 
       /// checks whether the constraints enable to remove an arc
       /** an arc can be removed if and only if the arc exists. */
-      bool checkModificationAlone( const ArcDeletion& change ) const;
+      bool checkModificationAlone(const ArcDeletion& change) const;
 
       /// checks whether the constraints enable to reverse an arc
       /** an arc (x,y) can be reversed if and only if it exists and arc (y,x)
        * does not. */
-      bool checkModificationAlone( const ArcReversal& change ) const;
+      bool checkModificationAlone(const ArcReversal& change) const;
 
-/// @}
+      /// @}
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 // include the set of methods that enable the structural constraint to
 // be standalone, i.e., that it needs not be included into a
 // StructuralConstraintSetStatic to be used by learning algorithms
-#define GUM_CONSTRAINT_CLASS_NAME StructuralConstraintDiGraph
-#include <agrum/learning/constraints/structuralConstraintPatternHeader.h>
-#undef GUM_CONSTRAINT_CLASS_NAME
-#endif  // DOXYGEN_SHOULD_SKIP_THIS
+#  define GUM_CONSTRAINT_CLASS_NAME StructuralConstraintDiGraph
+#  include <agrum/learning/constraints/structuralConstraintPatternHeader.h>
+#  undef GUM_CONSTRAINT_CLASS_NAME
+#endif   // DOXYGEN_SHOULD_SKIP_THIS
 
       protected:
       /// the DiGraph on which we perform checks
@@ -197,7 +197,7 @@ namespace gum {
 
 /// include the inlined functions if necessary
 #ifndef GUM_NO_INLINE
-#include <agrum/learning/constraints/structuralConstraintDiGraph.inl>
+#  include <agrum/learning/constraints/structuralConstraintDiGraph_inl.h>
 #endif /* GUM_NO_INLINE */
 
 #endif /* GUM_LEARNING_STRUCTURAL_CONSTRAINT_DIGRAPH_H */
