@@ -26,7 +26,7 @@
 #ifndef GUM_LEARNING_STRUCTURAL_CONSTRAINT_FORBIDDEN_ARCS_H
 #define GUM_LEARNING_STRUCTURAL_CONSTRAINT_FORBIDDEN_ARCS_H
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 #include <agrum/graphs/diGraph.h>
 #include <agrum/learning/constraints/structuralConstraint.h>
 #include <agrum/learning/structureUtils/graphChange.h>
@@ -52,15 +52,14 @@ namespace gum {
       StructuralConstraintForbiddenArcs();
 
       /// constructor starting with a given graph
-      StructuralConstraintForbiddenArcs( const DiGraph& graph );
+      StructuralConstraintForbiddenArcs(const DiGraph& graph);
 
       /// copy constructor
       StructuralConstraintForbiddenArcs(
-          const StructuralConstraintForbiddenArcs& from );
+        const StructuralConstraintForbiddenArcs& from);
 
       /// move constructor
-      StructuralConstraintForbiddenArcs(
-          StructuralConstraintForbiddenArcs&& from );
+      StructuralConstraintForbiddenArcs(StructuralConstraintForbiddenArcs&& from);
 
       /// destructor
       virtual ~StructuralConstraintForbiddenArcs();
@@ -74,11 +73,11 @@ namespace gum {
 
       /// copy operator
       StructuralConstraintForbiddenArcs&
-      operator=( const StructuralConstraintForbiddenArcs& from );
+        operator=(const StructuralConstraintForbiddenArcs& from);
 
       /// move operator
       StructuralConstraintForbiddenArcs&
-      operator=( StructuralConstraintForbiddenArcs&& from );
+        operator=(StructuralConstraintForbiddenArcs&& from);
 
       /// @}
 
@@ -88,45 +87,45 @@ namespace gum {
       /// @{
 
       /// assign a set of forbidden arcs
-      void setArcs( const ArcSet& set );
+      void setArcs(const ArcSet& set);
 
       /// assign a new forbidden arc
-      void addArc( const Arc& arc );
+      void addArc(const Arc& arc);
 
       /// remove a forbidden arc
-      void eraseArc( const Arc& arc );
+      void eraseArc(const Arc& arc);
 
       /// returns the set of mandatory arcs
       const ArcSet& arcs() const;
 
       /// sets a new graph from which we will perform checkings
-      void setGraphAlone( const DiGraph& graph );
+      void setGraphAlone(const DiGraph& graph);
 
       /// notify the constraint of a modification of the graph
       /** @warning If an already existing arc is added nothing is done. In
        * particular, no exception is raised.
        * @throws InvalidNode exception is thrown if an arc (x,y) is added and x
        * or y does not belong to the graph nodes */
-      void modifyGraphAlone( const ArcAddition& change );
+      void modifyGraphAlone(const ArcAddition& change);
 
       /// notify the constraint of a modification of the graph
       /** @warning If a nonexisting arc is removed, nothing is done. In
        * particular, no exception is raised. */
-      void modifyGraphAlone( const ArcDeletion& change );
+      void modifyGraphAlone(const ArcDeletion& change);
 
       /// notify the constraint of a modification of the graph
       /** @warning If an already existing arc is added, or if a nonexisting arc
        * is removed, nothing is done. In particular, no exception is raised.
        * @throws InvalidNode exception is thrown if at least one extremity of
        * the arc does not belong to the graph nodes */
-      void modifyGraphAlone( const ArcReversal& change );
+      void modifyGraphAlone(const ArcReversal& change);
 
       /// notify the constraint of a modification of the graph
       /** @warning If an already existing arc is added, or if a nonexisting arc
        * is removed, nothing is done. In particular, no exception is raised.
        * @throws InvalidNode exception is thrown if an arc (x,y) is added and x
        * or y does not belong to the graph nodes */
-      void modifyGraphAlone( const GraphChange& change );
+      void modifyGraphAlone(const GraphChange& change);
 
       /// indicates whether a change will always violate the constraint
       /** Some learning algorithms need examine several times whether a given
@@ -142,21 +141,21 @@ namespace gum {
        * arc.
        * Such graph changes are always invalid and are therefore tagged as such
        * by the isAlwaysInvalid method. */
-      bool isAlwaysInvalidAlone( const GraphChange& change ) const;
+      bool isAlwaysInvalidAlone(const GraphChange& change) const;
 
       /// checks whether the constraints enable to add arc (x,y)
       /** an arc can be added if and only if its extremal nodes belong to the
        * graph and the arc does not already exist. */
-      bool checkArcAdditionAlone( NodeId x, NodeId y ) const;
+      bool checkArcAdditionAlone(NodeId x, NodeId y) const;
 
       /// checks whether the constraints enable to remove arc (x,y)
       /** an arc can be removed if and only if the arc exists. */
-      bool checkArcDeletionAlone( NodeId x, NodeId y ) const;
+      bool checkArcDeletionAlone(NodeId x, NodeId y) const;
 
       /// checks whether the constraints enable to reverse arc (x,y)
       /** an arc can be reversed if and only if it exists and arc (y,x)
        * does not. */
-      bool checkArcReversalAlone( NodeId x, NodeId y ) const;
+      bool checkArcReversalAlone(NodeId x, NodeId y) const;
 
       /// checks whether the constraints enable to perform a graph change
       /** An arc can be added if and only if its extremal nodes belong to the
@@ -164,32 +163,32 @@ namespace gum {
        * An arc can be removed if and only if the arc exists.
        * An arc (x,y) can be reversed if and only if it exists and arc (y,x)
        * does not. */
-      bool checkModificationAlone( const GraphChange& change ) const;
+      bool checkModificationAlone(const GraphChange& change) const;
 
       /// checks whether the constraints enable to add an arc
       /** an arc can be added if and only if its extremal nodes belong to the
        * graph and the arc does not already exist. */
-      bool checkModificationAlone( const ArcAddition& change ) const;
+      bool checkModificationAlone(const ArcAddition& change) const;
 
       /// checks whether the constraints enable to remove an arc
       /** an arc can be removed if and only if the arc exists. */
-      bool checkModificationAlone( const ArcDeletion& change ) const;
+      bool checkModificationAlone(const ArcDeletion& change) const;
 
       /// checks whether the constraints enable to reverse an arc
       /** an arc (x,y) can be reversed if and only if it exists and arc (y,x)
        * does not. */
-      bool checkModificationAlone( const ArcReversal& change ) const;
+      bool checkModificationAlone(const ArcReversal& change) const;
 
-/// @}
+      /// @}
 
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 // include the set of methods that enable the structural constraint to
 // be standalone, i.e., that it needs not be included into a
 // StructuralConstraintSetStatic to be used by learning algorithms
-#define GUM_CONSTRAINT_CLASS_NAME StructuralConstraintForbiddenArcs
-#include <agrum/learning/constraints/structuralConstraintPatternHeader.h>
-#undef GUM_CONSTRAINT_CLASS_NAME
-#endif  // DOXYGEN_SHOULD_SKIP_THIS
+#  define GUM_CONSTRAINT_CLASS_NAME StructuralConstraintForbiddenArcs
+#  include <agrum/learning/constraints/structuralConstraintPatternHeader.h>
+#  undef GUM_CONSTRAINT_CLASS_NAME
+#endif   // DOXYGEN_SHOULD_SKIP_THIS
 
       protected:
       /// the ForbiddenArcs on which we perform checks
@@ -202,7 +201,7 @@ namespace gum {
 
 /// include the inlined functions if necessary
 #ifndef GUM_NO_INLINE
-#include <agrum/learning/constraints/structuralConstraintForbiddenArcs_inl.h>
+#  include <agrum/learning/constraints/structuralConstraintForbiddenArcs_inl.h>
 #endif /* GUM_NO_INLINE */
 
 #endif /* GUM_LEARNING_STRUCTURAL_CONSTRAINT_FORBIDDEN_ARCS_H */
