@@ -27,72 +27,71 @@
 #ifdef GUM_CONSTRAINT_CLASS_NAME
 
 /// sets a new graph from which we will perform checkings
-INLINE void GUM_CONSTRAINT_CLASS_NAME::setGraph( const UndiGraph& graph ) {
-  constraints::setGraph( graph );
-  setGraphAlone( graph );
+INLINE void GUM_CONSTRAINT_CLASS_NAME::setGraph(const UndiGraph& graph) {
+  constraints::setGraph(graph);
+  setGraphAlone(graph);
 }
 
 /// checks whether the constraints enable to add edge (x,y)
-INLINE bool GUM_CONSTRAINT_CLASS_NAME::checkEdgeAddition( NodeId x,
-                                                          NodeId y ) const {
-  return constraints::checkEdgeAddition( x, y ) && checkEdgeAdditionAlone( x, y );
+INLINE bool GUM_CONSTRAINT_CLASS_NAME::checkEdgeAddition(NodeId x,
+                                                         NodeId y) const {
+  return constraints::checkEdgeAddition(x, y) && checkEdgeAdditionAlone(x, y);
 }
 
 /// checks whether the constraints enable to remove edge (x,y)
-INLINE bool GUM_CONSTRAINT_CLASS_NAME::checkEdgeDeletion( NodeId x,
-                                                          NodeId y ) const {
-  return constraints::checkEdgeDeletion( x, y ) && checkEdgeDeletionAlone( x, y );
+INLINE bool GUM_CONSTRAINT_CLASS_NAME::checkEdgeDeletion(NodeId x,
+                                                         NodeId y) const {
+  return constraints::checkEdgeDeletion(x, y) && checkEdgeDeletionAlone(x, y);
 }
 
 /// notify the constraint of a modification of the graph
-INLINE void GUM_CONSTRAINT_CLASS_NAME::modifyGraph( const EdgeAddition& change ) {
-  constraints::modifyGraph( change );
-  modifyGraphAlone( change );
+INLINE void GUM_CONSTRAINT_CLASS_NAME::modifyGraph(const EdgeAddition& change) {
+  constraints::modifyGraph(change);
+  modifyGraphAlone(change);
 }
 
 /// notify the constraint of a modification of the graph
-INLINE void GUM_CONSTRAINT_CLASS_NAME::modifyGraph( const EdgeDeletion& change ) {
-  constraints::modifyGraph( change );
-  modifyGraphAlone( change );
+INLINE void GUM_CONSTRAINT_CLASS_NAME::modifyGraph(const EdgeDeletion& change) {
+  constraints::modifyGraph(change);
+  modifyGraphAlone(change);
 }
 
 /// notify the constraint of a modification of the graph
-INLINE void GUM_CONSTRAINT_CLASS_NAME::modifyGraph( const GraphChange& change ) {
-  constraints::modifyGraph( change );
-  modifyGraphAlone( change );
+INLINE void GUM_CONSTRAINT_CLASS_NAME::modifyGraph(const GraphChange& change) {
+  constraints::modifyGraph(change);
+  modifyGraphAlone(change);
 }
 
 /// indicates whether a change will always violate the constraint
-INLINE bool
-GUM_CONSTRAINT_CLASS_NAME::isAlwaysInvalid( const GraphChange& ) const {
-  return constraints::isAlwaysInvalid( change ) || isAlwaysInvalidAlone( change );
+INLINE bool GUM_CONSTRAINT_CLASS_NAME::isAlwaysInvalid(const GraphChange&) const {
+  return constraints::isAlwaysInvalid(change) || isAlwaysInvalidAlone(change);
 }
 
 /// checks whether the constraints enable to add an edge
 INLINE bool
-GUM_CONSTRAINT_CLASS_NAME::checkModification( const EdgeAddition& change ) const {
-  return checkEdgeAddition( change.node1(), change.node2() );
+  GUM_CONSTRAINT_CLASS_NAME::checkModification(const EdgeAddition& change) const {
+  return checkEdgeAddition(change.node1(), change.node2());
 }
 
 /// checks whether the constraints enable to remove an edge
 INLINE bool
-GUM_CONSTRAINT_CLASS_NAME::checkModification( const EdgeDeletion& change ) const {
-  return checkEdgeDeletion( change.node1(), change.node2() );
+  GUM_CONSTRAINT_CLASS_NAME::checkModification(const EdgeDeletion& change) const {
+  return checkEdgeDeletion(change.node1(), change.node2());
 }
 
 /// checks whether the constraints enable to perform a graph change
 INLINE bool
-GUM_CONSTRAINT_CLASS_NAME::checkModification( const GraphChange& change ) const {
-  switch ( change.type() ) {
+  GUM_CONSTRAINT_CLASS_NAME::checkModification(const GraphChange& change) const {
+  switch (change.type()) {
     case GraphChangeType::EDGE_ADDITION:
-      return checkEdgeAddition( change.node1(), change.node2() );
+      return checkEdgeAddition(change.node1(), change.node2());
 
     case GraphChangeType::EDGE_DELETION:
-      return checkEdgeDeletion( change.node1(), change.node2() );
+      return checkEdgeDeletion(change.node1(), change.node2());
 
     default:
-      GUM_ERROR( OperationNotAllowed,
-                 "arc modifications are not supported by the constraint" );
+      GUM_ERROR(OperationNotAllowed,
+                "arc modifications are not supported by the constraint");
   }
 }
 
