@@ -30,76 +30,73 @@
 #ifdef GUM_CONSTRAINT_CLASS_NAME
 
 /// sets a new graph from which we will perform checkings
-INLINE void GUM_CONSTRAINT_CLASS_NAME::setGraph( const DiGraph& graph ) {
-  setGraphAlone( graph );
+INLINE void GUM_CONSTRAINT_CLASS_NAME::setGraph(const DiGraph& graph) {
+  setGraphAlone(graph);
 }
 
 /// notify the constraint of a modification of the graph
-INLINE void GUM_CONSTRAINT_CLASS_NAME::modifyGraph( const ArcAddition& change ) {
-  modifyGraphAlone( change );
+INLINE void GUM_CONSTRAINT_CLASS_NAME::modifyGraph(const ArcAddition& change) {
+  modifyGraphAlone(change);
 }
 
 /// notify the constraint of a modification of the graph
-INLINE void GUM_CONSTRAINT_CLASS_NAME::modifyGraph( const ArcDeletion& change ) {
-  modifyGraphAlone( change );
+INLINE void GUM_CONSTRAINT_CLASS_NAME::modifyGraph(const ArcDeletion& change) {
+  modifyGraphAlone(change);
 }
 
 /// notify the constraint of a modification of the graph
-INLINE void GUM_CONSTRAINT_CLASS_NAME::modifyGraph( const ArcReversal& change ) {
-  modifyGraphAlone( change );
+INLINE void GUM_CONSTRAINT_CLASS_NAME::modifyGraph(const ArcReversal& change) {
+  modifyGraphAlone(change);
 }
 
 /// notify the constraint of a modification of the graph
-INLINE void GUM_CONSTRAINT_CLASS_NAME::modifyGraph( const GraphChange& change ) {
-  modifyGraphAlone( change );
+INLINE void GUM_CONSTRAINT_CLASS_NAME::modifyGraph(const GraphChange& change) {
+  modifyGraphAlone(change);
 }
 
 /// checks whether the constraints enable to add arc (x,y)
-INLINE bool GUM_CONSTRAINT_CLASS_NAME::checkArcAddition( NodeId x,
-                                                         NodeId y ) const {
-  return checkArcAdditionAlone( x, y );
+INLINE bool GUM_CONSTRAINT_CLASS_NAME::checkArcAddition(NodeId x, NodeId y) const {
+  return checkArcAdditionAlone(x, y);
 }
 
 /// checks whether the constraints enable to remove arc (x,y)
-INLINE bool GUM_CONSTRAINT_CLASS_NAME::checkArcDeletion( NodeId x,
-                                                         NodeId y ) const {
-  return checkArcDeletionAlone( x, y );
+INLINE bool GUM_CONSTRAINT_CLASS_NAME::checkArcDeletion(NodeId x, NodeId y) const {
+  return checkArcDeletionAlone(x, y);
 }
 
 /// checks whether the constraints enable to reverse arc (x,y)
-INLINE bool GUM_CONSTRAINT_CLASS_NAME::checkArcReversal( NodeId x,
-                                                         NodeId y ) const {
-  return checkArcReversalAlone( x, y );
+INLINE bool GUM_CONSTRAINT_CLASS_NAME::checkArcReversal(NodeId x, NodeId y) const {
+  return checkArcReversalAlone(x, y);
 }
 
 /// checks whether the constraints enable to add an arc
 INLINE bool
-GUM_CONSTRAINT_CLASS_NAME::checkModification( const ArcAddition& change ) const {
-  return checkModificationAlone( change );
+  GUM_CONSTRAINT_CLASS_NAME::checkModification(const ArcAddition& change) const {
+  return checkModificationAlone(change);
 }
 
 /// checks whether the constraints enable to remove an arc
 INLINE bool
-GUM_CONSTRAINT_CLASS_NAME::checkModification( const ArcDeletion& change ) const {
-  return checkModificationAlone( change );
+  GUM_CONSTRAINT_CLASS_NAME::checkModification(const ArcDeletion& change) const {
+  return checkModificationAlone(change);
 }
 
 /// checks whether the constraints enable to reverse an arc
 INLINE bool
-GUM_CONSTRAINT_CLASS_NAME::checkModification( const ArcReversal& change ) const {
-  return checkModificationAlone( change );
+  GUM_CONSTRAINT_CLASS_NAME::checkModification(const ArcReversal& change) const {
+  return checkModificationAlone(change);
 }
 
 /// checks whether the constraints enable to perform a graph change
 INLINE bool
-GUM_CONSTRAINT_CLASS_NAME::checkModification( const GraphChange& change ) const {
-  return checkModificationAlone( change );
+  GUM_CONSTRAINT_CLASS_NAME::checkModification(const GraphChange& change) const {
+  return checkModificationAlone(change);
 }
 
 /// indicates whether a change will always violate the constraint
 INLINE bool
-GUM_CONSTRAINT_CLASS_NAME::isAlwaysInvalid( const GraphChange& change ) const {
-  return isAlwaysInvalidAlone( change );
+  GUM_CONSTRAINT_CLASS_NAME::isAlwaysInvalid(const GraphChange& change) const {
+  return isAlwaysInvalidAlone(change);
 }
 
 #endif /* GUM_CONSTRAINT_CLASS_NAME */
