@@ -53,7 +53,7 @@
 #ifndef GUM_LEARNING_COUNTER_H
 #define GUM_LEARNING_COUNTER_H
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 #include <agrum/core/math/math.h>
 #include <agrum/learning/scores_and_tests/recordCounter.h>
 #include <vector>
@@ -103,8 +103,8 @@ namespace gum {
      * been performed.  Note that this class is not intended to be used as is,
      * but is rather a basis for classes Score and IndependenceTest.
      */
-    template <typename IdSetAlloc = std::allocator<Idx>,
-              typename CountAlloc = std::allocator<double>>
+    template < typename IdSetAlloc = std::allocator< Idx >,
+               typename CountAlloc = std::allocator< double > >
     class Counter {
       public:
       // ##########################################################################
@@ -119,16 +119,16 @@ namespace gum {
        * @param min_range The minimal range
        * @param max_range The maximal range
        */
-      template <typename RowFilter>
-      Counter( const RowFilter&         filter,
-               const std::vector<Size>& var_modalities,
-               Size                     min_range = 0,
-               Size max_range = std::numeric_limits<Size>::max() );
+      template < typename RowFilter >
+      Counter(const RowFilter&           filter,
+              const std::vector< Size >& var_modalities,
+              Size                       min_range = 0,
+              Size max_range = std::numeric_limits< Size >::max());
       /// copy constructor
-      Counter( const Counter<IdSetAlloc, CountAlloc>& );
+      Counter(const Counter< IdSetAlloc, CountAlloc >&);
 
       /// move constructor
-      Counter( Counter<IdSetAlloc, CountAlloc>&& );
+      Counter(Counter< IdSetAlloc, CountAlloc >&&);
 
       /// destructor
       virtual ~Counter();
@@ -157,7 +157,7 @@ namespace gum {
        * this
        * index as argument to methods _getAllCounts to get the corresponding
        * counting vector. */
-      Idx addNodeSet( Idx var );
+      Idx addNodeSet(Idx var);
 
       /// @}
 
@@ -180,7 +180,7 @@ namespace gum {
        * argument
        * to methods _getAllCounts and _getConditioningCounts to get the observed
        * countings of (var2,var1) [in this order] and var2 respectively. */
-      Idx addNodeSet( Idx var1, Idx var2 );
+      Idx addNodeSet(Idx var1, Idx var2);
 
       /// add a new target node conditioned by another node to be counted
       /** @param vars contains the index of the target variable (first) in the
@@ -195,7 +195,7 @@ namespace gum {
        * _getAllCounts and _getConditioningCounts to get the observed
        * countings of (vars.second, vars.first) [in this order] and
        * vars.second respectively. */
-      Idx addNodeSet( const std::pair<Idx, Idx>& vars );
+      Idx addNodeSet(const std::pair< Idx, Idx >& vars);
 
       /// add a new target variable plus some conditioning vars
       /** @param var represents the index of the target variable in the filtered
@@ -212,7 +212,7 @@ namespace gum {
        * _getConditioningCounts to get the counting vectors of
        * (conditioning_ids,vars) [in this order] and conditioning_ids
        * respectively. */
-      Idx addNodeSet( Idx var, const std::vector<Idx>& conditioning_ids );
+      Idx addNodeSet(Idx var, const std::vector< Idx >& conditioning_ids);
 
       /// add a new target variable plus some conditioning vars
       /** @param var represents the index of the target variable in the filtered
@@ -229,7 +229,7 @@ namespace gum {
        * _getConditioningCounts to get the counting vectors of
        * (conditioning_ids,vars) [in this order] and conditioning_ids
        * respectively. */
-      Idx addNodeSet( Idx var, std::vector<Idx>&& conditioning_ids );
+      Idx addNodeSet(Idx var, std::vector< Idx >&& conditioning_ids);
 
       /// add a target conditioned by other variables to be counted
       /** @param var1 represents the index of the target variable in the
@@ -251,7 +251,7 @@ namespace gum {
        * (conditioning_ids, var2, var1) [in this order] and
        * (conditioning_ids, var2) [in this order] respectively. */
       Idx
-      addNodeSet( Idx var1, Idx var2, const std::vector<Idx>& conditioning_ids );
+        addNodeSet(Idx var1, Idx var2, const std::vector< Idx >& conditioning_ids);
 
       /// add a target conditioned by other variables to be counted
       /** @param var1 represents the index of the target variable in the
@@ -272,7 +272,7 @@ namespace gum {
        * _getAllCounts and _getConditioningCounts to get the countings of
        * (conditioning_ids, var2, var1) [in this order] and
        * (conditioning_ids, var2) [in this order] respectively. */
-      Idx addNodeSet( Idx var1, Idx var2, std::vector<Idx>&& conditioning_ids );
+      Idx addNodeSet(Idx var1, Idx var2, std::vector< Idx >&& conditioning_ids);
 
       /// add a target conditioned by other variables to be counted
       /** @param vars represents the index of the target variable (first) in the
@@ -290,8 +290,8 @@ namespace gum {
        * _getAllCounts and _getConditioningCounts to get the observed countings
        * of (conditioning_ids, vars.second, vars.first) [in this order] and
        * (conditioning_ids, vars.second) [in this order] respectively. */
-      Idx addNodeSet( const std::pair<Idx, Idx>& vars,
-                      const std::vector<Idx>& conditioning_ids );
+      Idx addNodeSet(const std::pair< Idx, Idx >& vars,
+                     const std::vector< Idx >&    conditioning_ids);
 
       /// add a target conditioned by other variables to be counted
       /** @param vars represents the index of the target variable (first) in the
@@ -309,8 +309,8 @@ namespace gum {
        * _getAllCounts and _getConditioningCounts to get the observed countings
        * of (conditioning_ids, vars.second, vars.first) [in this order] and
        * (conditioning_ids, vars.second) [in this order] respectively. */
-      Idx addNodeSet( const std::pair<Idx, Idx>& vars,
-                      std::vector<Idx>&& conditioning_ids );
+      Idx addNodeSet(const std::pair< Idx, Idx >& vars,
+                     std::vector< Idx >&&         conditioning_ids);
 
       /// @}
 
@@ -323,17 +323,17 @@ namespace gum {
       void clear();
 
       /// returns the modalities of the variables
-      const std::vector<Size>& modalities() const noexcept;
+      const std::vector< Size >& modalities() const noexcept;
 
       /// sets the maximum number of threads used to perform countings
-      void setMaxNbThreads( Size nb ) noexcept;
+      void setMaxNbThreads(Size nb) noexcept;
 
       /// sets the range of records taken into account by the counter
       /** @param min_range he number of the first record to be taken into
        * account during learning
        * @param max_range the number of the record after the last one taken
        * into account*/
-      void setRange( Size min_range, Size max_range );
+      void setRange(Size min_range, Size max_range);
 
       /// @}
 
@@ -342,22 +342,23 @@ namespace gum {
       const double _1log2{M_LOG2E};
 
       /// the modalities of the variables
-      const std::vector<Size>& _modalities;
+      const std::vector< Size >& _modalities;
 
       /// indicates whether we have already computed the countings of the
       /// nodesets
       bool _counts_computed{false};
 
       /// the recordCounter that will parse the database
-      RecordCounter<IdSetAlloc, CountAlloc> _record_counter;
+      RecordCounter< IdSetAlloc, CountAlloc > _record_counter;
 
       /// the target id sets to count and their indices in the record counter
-      std::vector<std::pair<std::vector<Idx, IdSetAlloc>, Idx>*> _target_nodesets;
+      std::vector< std::pair< std::vector< Idx, IdSetAlloc >, Idx >* >
+        _target_nodesets;
 
       /// the conditioning id sets to count and their indices in the record
       /// counter
-      std::vector<std::pair<std::vector<Idx, IdSetAlloc>, Idx>*>
-          _conditioning_nodesets;
+      std::vector< std::pair< std::vector< Idx, IdSetAlloc >, Idx >* >
+        _conditioning_nodesets;
 
 
       /// perform the computation of the countings
@@ -376,46 +377,46 @@ namespace gum {
        * when callind addNodeset, and then the target nodes).
        * @warning whenever you call this function, if the counts have not been
        * computed yet, they are computed before the function returns. */
-      const std::vector<double, CountAlloc>& _getAllCounts( Idx index );
+      const std::vector< double, CountAlloc >& _getAllCounts(Idx index);
 
       /// returns the counting vector for a conditioning set
       /** @warning whenever you call this function, if the counts have not been
        * computed yet, they are computed before the function returns. */
-      const std::vector<double, CountAlloc>& _getConditioningCounts( Idx index );
+      const std::vector< double, CountAlloc >& _getConditioningCounts(Idx index);
 
       /// returns all the countings performed (both targets and conditioned)
       /** this method returns the countings of the record counter. It should
        * be used in conjunction with methods _getConditioningNodes () and
        * _getTargetNodes () that indicate, for each nodeset, the index of
        * the corresponding counting in the vector returned by _getCounts (). */
-      std::vector<std::vector<double, CountAlloc>>& _getCounts() noexcept;
+      std::vector< std::vector< double, CountAlloc > >& _getCounts() noexcept;
 
       /// returns the set of target + conditioning nodes
       /** conditioning nodes are always the first ones in the vector and targets
        * are the last ones */
-      const std::vector<Idx, IdSetAlloc>& _getAllNodes( Idx index ) const noexcept;
+      const std::vector< Idx, IdSetAlloc >& _getAllNodes(Idx index) const noexcept;
 
       /// returns all the sets of target + cond nodes, and their counting
       /// indices
       /** conditioning nodes are always the first ones in the vector and targets
        * are the last ones */
-      const std::vector<std::pair<std::vector<Idx, IdSetAlloc>, Idx>*>&
-      _getAllNodes() const noexcept;
+      const std::vector< std::pair< std::vector< Idx, IdSetAlloc >, Idx >* >&
+        _getAllNodes() const noexcept;
 
       /// returns the conditioning nodes (nullptr if there are no such nodes)
-      const std::vector<Idx, IdSetAlloc>* _getConditioningNodes( Idx index ) const
-          noexcept;
+      const std::vector< Idx, IdSetAlloc >* _getConditioningNodes(Idx index) const
+        noexcept;
 
       /// returns all the sets of conditioning nodes
-      const std::vector<std::pair<std::vector<Idx, IdSetAlloc>, Idx>*>&
-      _getConditioningNodes() const noexcept;
+      const std::vector< std::pair< std::vector< Idx, IdSetAlloc >, Idx >* >&
+        _getConditioningNodes() const noexcept;
 
       // ##########################################################################
       // ##########################################################################
 
       /// prevent copy operator
-      Counter<IdSetAlloc, CountAlloc>&
-      operator=( const Counter<IdSetAlloc, CountAlloc>& ) = delete;
+      Counter< IdSetAlloc, CountAlloc >&
+        operator=(const Counter< IdSetAlloc, CountAlloc >&) = delete;
     };
 
   } /* namespace learning */
@@ -427,6 +428,6 @@ extern template class gum::learning::Counter<>;
 
 
 /// include the template implementation
-#include <agrum/learning/scores_and_tests/counter.tcc>
+#include <agrum/learning/scores_and_tests/counter_tpl.h>
 
 #endif /* GUM_LEARNING_COUNTER_H */
