@@ -60,9 +60,9 @@ namespace gum {
      *for
      * details.
      */
-    template <typename IdSetAlloc = std::allocator<Idx>,
-              typename CountAlloc = std::allocator<double>>
-    class IndepTestChi2 : public IndependenceTest<IdSetAlloc, CountAlloc> {
+    template < typename IdSetAlloc = std::allocator< Idx >,
+               typename CountAlloc = std::allocator< double > >
+    class IndepTestChi2 : public IndependenceTest< IdSetAlloc, CountAlloc > {
       public:
       // ##########################################################################
       /// @name Constructors / Destructors
@@ -73,9 +73,9 @@ namespace gum {
       /** @param filter the row filter that will be used to read the database
        * @param var_modalities the domain sizes of the variables in the database
        */
-      template <typename RowFilter>
-      IndepTestChi2( const RowFilter&         filter,
-                     const std::vector<Size>& var_modalities );
+      template < typename RowFilter >
+      IndepTestChi2(const RowFilter&           filter,
+                    const std::vector< Size >& var_modalities);
 
       /// destructor
       ~IndepTestChi2();
@@ -96,7 +96,7 @@ namespace gum {
        * @#sum corresponds to the summations mentioned above. Therefore, any
        * positive result should reflect a dependence whereas negative results
        * should reflect independences. */
-      double score( Idx nodeset_index );
+      double score(Idx nodeset_index);
 
       /// @}
 
@@ -105,7 +105,7 @@ namespace gum {
       Chi2 __chi2;
 
       /// an empty vector of ids
-      const std::vector<Idx, IdSetAlloc> __empty_set;
+      const std::vector< Idx, IdSetAlloc > __empty_set;
     };
 
   } /* namespace learning */
@@ -117,6 +117,6 @@ extern template class gum::learning::IndepTestChi2<>;
 
 
 // always include the template implementation
-#include <agrum/learning/scores_and_tests/indepTestChi2.tcc>
+#include <agrum/learning/scores_and_tests/indepTestChi2_tpl.h>
 
 #endif /* GUM_LEARNING_INDEP_TEST_CHI2_H */
