@@ -44,7 +44,8 @@ namespace gum {
     /* ===                       INDEP TEST G2 CLASS                         === */
     /* ========================================================================= */
     /**
-     * @class IndepTestG2 indepTestG2.h <agrum/learning/scores_and_tests/indepTestG2.h>
+* @class IndepTestG2
+* @headerfile indepTestG2.h <agrum/learning/scores_and_tests/indepTestG2.h>
      * @brief the class for computing G2 independence test scores
      * @ingroup learning_group
      *
@@ -58,9 +59,9 @@ namespace gum {
      * for details.
      */
     // clang-format on
-    template <typename IdSetAlloc = std::allocator<Idx>,
-              typename CountAlloc = std::allocator<double>>
-    class IndepTestG2 : public IndependenceTest<IdSetAlloc, CountAlloc> {
+    template < typename IdSetAlloc = std::allocator< Idx >,
+               typename CountAlloc = std::allocator< double > >
+    class IndepTestG2 : public IndependenceTest< IdSetAlloc, CountAlloc > {
       public:
       // ##########################################################################
       /// @name Constructors / Destructors
@@ -71,9 +72,9 @@ namespace gum {
       /** @param filter the row filter that will be used to read the database
        * @param var_modalities the domain sizes of the variables in the database
        */
-      template <typename RowFilter>
-      IndepTestG2( const RowFilter&         filter,
-                   const std::vector<Size>& var_modalities );
+      template < typename RowFilter >
+      IndepTestG2(const RowFilter&           filter,
+                  const std::vector< Size >& var_modalities);
 
       /// destructor
       ~IndepTestG2();
@@ -94,7 +95,7 @@ namespace gum {
        * the summations mentioned above. Therefore, any positive result should
        * reflect a dependence whereas negative results should reflect
        * independences. */
-      double score( Idx nodeset_index );
+      double score(Idx nodeset_index);
 
       /// @}
 
@@ -103,7 +104,7 @@ namespace gum {
       Chi2 __chi2;
 
       /// an empty vector of ids
-      const std::vector<Idx, IdSetAlloc> __empty_set;
+      const std::vector< Idx, IdSetAlloc > __empty_set;
     };
 
   } /* namespace learning */
