@@ -32,9 +32,9 @@
 #include <iostream>
 #include <string>
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 #include <agrum/core/hashFunc.h>
-#include <agrum/graphs/nodeGraphPart.h>
+#include <agrum/graphs/parts/nodeGraphPart.h>
 
 namespace gum {
 
@@ -67,13 +67,13 @@ namespace gum {
       /// @{
 
       /// default constructor
-      GraphChange( GraphChangeType type, NodeId node1, NodeId node2 ) noexcept;
+      GraphChange(GraphChangeType type, NodeId node1, NodeId node2) noexcept;
 
       /// copy constructor
-      GraphChange( const GraphChange& from ) noexcept;
+      GraphChange(const GraphChange& from) noexcept;
 
       /// move constructor
-      GraphChange( GraphChange&& from ) noexcept;
+      GraphChange(GraphChange&& from) noexcept;
 
       /// destructor
       ~GraphChange() noexcept;
@@ -86,16 +86,16 @@ namespace gum {
       /// @{
 
       /// copy constructor
-      GraphChange& operator=( const GraphChange& from ) noexcept;
+      GraphChange& operator=(const GraphChange& from) noexcept;
 
       /// move operator
-      GraphChange& operator=( GraphChange&& from ) noexcept;
+      GraphChange& operator=(GraphChange&& from) noexcept;
 
       /// returns whether two graph changes are identical or not
-      bool operator==( const GraphChange& from ) const noexcept;
+      bool operator==(const GraphChange& from) const noexcept;
 
       /// returns whether two graph changes are different or not
-      bool operator!=( const GraphChange& from ) const noexcept;
+      bool operator!=(const GraphChange& from) const noexcept;
 
       /// @}
 
@@ -152,13 +152,13 @@ namespace gum {
       /// @{
 
       /// default constructor
-      ArcAddition( NodeId node1, NodeId node2 ) noexcept;
+      ArcAddition(NodeId node1, NodeId node2) noexcept;
 
       /// copy constructor
-      ArcAddition( const ArcAddition& from ) noexcept;
+      ArcAddition(const ArcAddition& from) noexcept;
 
       /// move constructor
-      ArcAddition( ArcAddition&& from ) noexcept;
+      ArcAddition(ArcAddition&& from) noexcept;
 
       /// destructor
       ~ArcAddition() noexcept;
@@ -171,16 +171,16 @@ namespace gum {
       /// @{
 
       /// copy constructor
-      ArcAddition& operator=( const ArcAddition& from ) noexcept;
+      ArcAddition& operator=(const ArcAddition& from) noexcept;
 
       /// move operator
-      ArcAddition& operator=( ArcAddition&& from ) noexcept;
+      ArcAddition& operator=(ArcAddition&& from) noexcept;
 
       /// returns whether two arc additions are identical or not
-      bool operator==( const ArcAddition& from ) const noexcept;
+      bool operator==(const ArcAddition& from) const noexcept;
 
       /// returns whether two arc additions are different or not
-      bool operator!=( const ArcAddition& from ) const noexcept;
+      bool operator!=(const ArcAddition& from) const noexcept;
 
       /// @}
 
@@ -218,13 +218,13 @@ namespace gum {
       /// @{
 
       /// default constructor
-      ArcDeletion( NodeId node1, NodeId node2 ) noexcept;
+      ArcDeletion(NodeId node1, NodeId node2) noexcept;
 
       /// copy constructor
-      ArcDeletion( const ArcDeletion& from ) noexcept;
+      ArcDeletion(const ArcDeletion& from) noexcept;
 
       /// move constructor
-      ArcDeletion( ArcDeletion&& from ) noexcept;
+      ArcDeletion(ArcDeletion&& from) noexcept;
 
       /// destructor
       ~ArcDeletion() noexcept;
@@ -237,16 +237,16 @@ namespace gum {
       /// @{
 
       /// copy constructor
-      ArcDeletion& operator=( const ArcDeletion& from ) noexcept;
+      ArcDeletion& operator=(const ArcDeletion& from) noexcept;
 
       /// move operator
-      ArcDeletion& operator=( ArcDeletion&& from ) noexcept;
+      ArcDeletion& operator=(ArcDeletion&& from) noexcept;
 
       /// returns whether two arc deletions are identical or not
-      bool operator==( const ArcDeletion& from ) const noexcept;
+      bool operator==(const ArcDeletion& from) const noexcept;
 
       /// returns whether two arc deletions are different or not
-      bool operator!=( const ArcDeletion& from ) const noexcept;
+      bool operator!=(const ArcDeletion& from) const noexcept;
 
       /// @}
 
@@ -284,13 +284,13 @@ namespace gum {
       /// @{
 
       /// default constructor
-      ArcReversal( NodeId node1, NodeId node2 ) noexcept;
+      ArcReversal(NodeId node1, NodeId node2) noexcept;
 
       /// copy constructor
-      ArcReversal( const ArcReversal& from ) noexcept;
+      ArcReversal(const ArcReversal& from) noexcept;
 
       /// move constructor
-      ArcReversal( ArcReversal&& from ) noexcept;
+      ArcReversal(ArcReversal&& from) noexcept;
 
       /// destructor
       ~ArcReversal() noexcept;
@@ -303,16 +303,16 @@ namespace gum {
       /// @{
 
       /// copy constructor
-      ArcReversal& operator=( const ArcReversal& from ) noexcept;
+      ArcReversal& operator=(const ArcReversal& from) noexcept;
 
       /// move operator
-      ArcReversal& operator=( ArcReversal&& from ) noexcept;
+      ArcReversal& operator=(ArcReversal&& from) noexcept;
 
       /// returns whether two arc reversals are identical or not
-      bool operator==( const ArcReversal& from ) const noexcept;
+      bool operator==(const ArcReversal& from) const noexcept;
 
       /// returns whether two arc reversals are different or not
-      bool operator!=( const ArcReversal& from ) const noexcept;
+      bool operator!=(const ArcReversal& from) const noexcept;
 
       /// @}
 
@@ -350,13 +350,13 @@ namespace gum {
       /// @{
 
       /// default constructor
-      EdgeAddition( NodeId node1, NodeId node2 ) noexcept;
+      EdgeAddition(NodeId node1, NodeId node2) noexcept;
 
       /// copy constructor
-      EdgeAddition( const EdgeAddition& from ) noexcept;
+      EdgeAddition(const EdgeAddition& from) noexcept;
 
       /// move constructor
-      EdgeAddition( EdgeAddition&& from ) noexcept;
+      EdgeAddition(EdgeAddition&& from) noexcept;
 
       /// destructor
       ~EdgeAddition() noexcept;
@@ -369,16 +369,16 @@ namespace gum {
       /// @{
 
       /// copy constructor
-      EdgeAddition& operator=( const EdgeAddition& from ) noexcept;
+      EdgeAddition& operator=(const EdgeAddition& from) noexcept;
 
       /// move operator
-      EdgeAddition& operator=( EdgeAddition&& from ) noexcept;
+      EdgeAddition& operator=(EdgeAddition&& from) noexcept;
 
       /// returns whether two edge additions are identical or not
-      bool operator==( const EdgeAddition& from ) const noexcept;
+      bool operator==(const EdgeAddition& from) const noexcept;
 
       /// returns whether two edge additions are different or not
-      bool operator!=( const EdgeAddition& from ) const noexcept;
+      bool operator!=(const EdgeAddition& from) const noexcept;
 
       /// @}
 
@@ -416,13 +416,13 @@ namespace gum {
       /// @{
 
       /// default constructor
-      EdgeDeletion( NodeId node1, NodeId node2 ) noexcept;
+      EdgeDeletion(NodeId node1, NodeId node2) noexcept;
 
       /// copy constructor
-      EdgeDeletion( const EdgeDeletion& from ) noexcept;
+      EdgeDeletion(const EdgeDeletion& from) noexcept;
 
       /// move constructor
-      EdgeDeletion( EdgeDeletion&& from ) noexcept;
+      EdgeDeletion(EdgeDeletion&& from) noexcept;
 
       /// destructor
       ~EdgeDeletion() noexcept;
@@ -435,16 +435,16 @@ namespace gum {
       /// @{
 
       /// copy constructor
-      EdgeDeletion& operator=( const EdgeDeletion& from ) noexcept;
+      EdgeDeletion& operator=(const EdgeDeletion& from) noexcept;
 
       /// move operator
-      EdgeDeletion& operator=( EdgeDeletion&& from ) noexcept;
+      EdgeDeletion& operator=(EdgeDeletion&& from) noexcept;
 
       /// returns whether two edge deletions are identical or not
-      bool operator==( const EdgeDeletion& from ) const noexcept;
+      bool operator==(const EdgeDeletion& from) const noexcept;
 
       /// returns whether two edge deletions are different or not
-      bool operator!=( const EdgeDeletion& from ) const noexcept;
+      bool operator!=(const EdgeDeletion& from) const noexcept;
 
       /// @}
 
@@ -460,101 +460,101 @@ namespace gum {
     };
 
     /// a \c << operator for GraphChanges
-    std::ostream& operator<<( std::ostream& stream, const GraphChange& change );
+    std::ostream& operator<<(std::ostream& stream, const GraphChange& change);
 
     /// a \c << operator for ArcAddition
-    std::ostream& operator<<( std::ostream& stream, const ArcAddition& change );
+    std::ostream& operator<<(std::ostream& stream, const ArcAddition& change);
 
     /// a \c << operator for ArcDeletion
-    std::ostream& operator<<( std::ostream& stream, const ArcDeletion& change );
+    std::ostream& operator<<(std::ostream& stream, const ArcDeletion& change);
 
     /// a \c << operator for ArcReversal
-    std::ostream& operator<<( std::ostream& stream, const ArcReversal& change );
+    std::ostream& operator<<(std::ostream& stream, const ArcReversal& change);
 
     /// a \c << operator for EdgeAddition
-    std::ostream& operator<<( std::ostream& stream, const EdgeAddition& change );
+    std::ostream& operator<<(std::ostream& stream, const EdgeAddition& change);
 
     /// a \c << operator for EdgeDeletion
-    std::ostream& operator<<( std::ostream& stream, const EdgeDeletion& change );
+    std::ostream& operator<<(std::ostream& stream, const EdgeDeletion& change);
 
   } /* namespace learning */
 
   /// the hash function for Graph Changes
   template <>
-  class HashFunc<learning::GraphChange> : public HashFuncSmallKey<NodeId> {
+  class HashFunc< learning::GraphChange > : public HashFuncSmallKey< NodeId > {
     public:
     /// computes the hashed value of a key
-    Size operator()( const learning::GraphChange& key ) const {
-      return ( ( (unsigned long)key.node1() * HashFuncConst::gold +
-                 (unsigned long)key.node2() * HashFuncConst::pi ) >>
-               _right_shift );
+    Size operator()(const learning::GraphChange& key) const {
+      return (((unsigned long)key.node1() * HashFuncConst::gold
+               + (unsigned long)key.node2() * HashFuncConst::pi)
+              >> _right_shift);
     }
   };
 
   /// the hash function for Arc Additions
   template <>
-  class HashFunc<learning::ArcAddition> : public HashFuncSmallKey<NodeId> {
+  class HashFunc< learning::ArcAddition > : public HashFuncSmallKey< NodeId > {
     public:
     /// computes the hashed value of a key
-    Size operator()( const learning::ArcAddition& key ) const {
-      return ( ( (unsigned long)key.node1() * HashFuncConst::gold +
-                 (unsigned long)key.node2() * HashFuncConst::pi ) >>
-               _right_shift );
+    Size operator()(const learning::ArcAddition& key) const {
+      return (((unsigned long)key.node1() * HashFuncConst::gold
+               + (unsigned long)key.node2() * HashFuncConst::pi)
+              >> _right_shift);
     }
   };
 
   /// the hash function for Arc Deletions
   template <>
-  class HashFunc<learning::ArcDeletion> : public HashFuncSmallKey<NodeId> {
+  class HashFunc< learning::ArcDeletion > : public HashFuncSmallKey< NodeId > {
     public:
     /// computes the hashed value of a key
-    Size operator()( const learning::ArcDeletion& key ) const {
-      return ( ( (unsigned long)key.node1() * HashFuncConst::gold +
-                 (unsigned long)key.node2() * HashFuncConst::pi ) >>
-               _right_shift );
+    Size operator()(const learning::ArcDeletion& key) const {
+      return (((unsigned long)key.node1() * HashFuncConst::gold
+               + (unsigned long)key.node2() * HashFuncConst::pi)
+              >> _right_shift);
     }
   };
 
   /// the hash function for Arc Reversals
   template <>
-  class HashFunc<learning::ArcReversal> : public HashFuncSmallKey<NodeId> {
+  class HashFunc< learning::ArcReversal > : public HashFuncSmallKey< NodeId > {
     public:
     /// computes the hashed value of a key
-    Size operator()( const learning::ArcReversal& key ) const {
-      return ( ( (unsigned long)key.node1() * HashFuncConst::gold +
-                 (unsigned long)key.node2() * HashFuncConst::pi ) >>
-               _right_shift );
+    Size operator()(const learning::ArcReversal& key) const {
+      return (((unsigned long)key.node1() * HashFuncConst::gold
+               + (unsigned long)key.node2() * HashFuncConst::pi)
+              >> _right_shift);
     }
   };
 
   /// the hash function for Edge Additions
   template <>
-  class HashFunc<learning::EdgeAddition> : public HashFuncSmallKey<NodeId> {
+  class HashFunc< learning::EdgeAddition > : public HashFuncSmallKey< NodeId > {
     public:
     /// computes the hashed value of a key
-    Size operator()( const learning::EdgeAddition& key ) const {
-      return ( ( (unsigned long)key.node1() * HashFuncConst::gold +
-                 (unsigned long)key.node2() * HashFuncConst::pi ) >>
-               _right_shift );
+    Size operator()(const learning::EdgeAddition& key) const {
+      return (((unsigned long)key.node1() * HashFuncConst::gold
+               + (unsigned long)key.node2() * HashFuncConst::pi)
+              >> _right_shift);
     }
   };
 
   /// the hash function for Edge Deletions
   template <>
-  class HashFunc<learning::EdgeDeletion> : public HashFuncSmallKey<NodeId> {
+  class HashFunc< learning::EdgeDeletion > : public HashFuncSmallKey< NodeId > {
     public:
     /// computes the hashed value of a key
-    Size operator()( const learning::EdgeDeletion& key ) const {
-      return ( ( (unsigned long)key.node1() * HashFuncConst::gold +
-                 (unsigned long)key.node2() * HashFuncConst::pi ) >>
-               _right_shift );
+    Size operator()(const learning::EdgeDeletion& key) const {
+      return (((unsigned long)key.node1() * HashFuncConst::gold
+               + (unsigned long)key.node2() * HashFuncConst::pi)
+              >> _right_shift);
     }
   };
 
 } /* namespace gum */
 
 #ifndef GUM_NO_INLINE
-#include <agrum/learning/structureUtils/graphChange_inl.h>
-#endif  // GUM_NOINLINE
+#  include <agrum/learning/structureUtils/graphChange_inl.h>
+#endif   // GUM_NOINLINE
 
 #endif /* GUM_LEARNING_GRAPH_CHANGE_H */
