@@ -58,7 +58,7 @@
 #ifndef GUM_LEARNING_GRAPH_CHANGES_GENERATOR_4_K2_H
 #define GUM_LEARNING_GRAPH_CHANGES_GENERATOR_4_K2_H
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 #include <agrum/core/OMPThreads.h>
 #include <agrum/core/sequence.h>
 #include <agrum/core/set.h>
@@ -114,12 +114,13 @@ namespace gum {
      *
      * @ingroup learning_group
      */
-    template <typename STRUCT_CONSTRAINT>
-    class GraphChangesGenerator4K2 : public IGraphChangesGenerator4DiGraph,
-                                     __GraphChangesGenerator4K2 {
+    template < typename STRUCT_CONSTRAINT >
+    class GraphChangesGenerator4K2
+        : public IGraphChangesGenerator4DiGraph
+        , __GraphChangesGenerator4K2 {
       public:
       /// the iterator for parsing the list of possible graph change operators
-      using iterator = typename Set<GraphChange>::const_iterator;
+      using iterator = typename Set< GraphChange >::const_iterator;
 
       /// the const iterator for parsing the list of graph change operators
       using const_iterator = iterator;
@@ -130,15 +131,15 @@ namespace gum {
       /// @{
 
       /// default constructor
-      GraphChangesGenerator4K2( STRUCT_CONSTRAINT& constraint );
+      GraphChangesGenerator4K2(STRUCT_CONSTRAINT& constraint);
 
       /// copy constructor
       GraphChangesGenerator4K2(
-          const GraphChangesGenerator4K2<STRUCT_CONSTRAINT>& from );
+        const GraphChangesGenerator4K2< STRUCT_CONSTRAINT >& from);
 
       /// move operator
       GraphChangesGenerator4K2(
-          GraphChangesGenerator4K2<STRUCT_CONSTRAINT>&& from );
+        GraphChangesGenerator4K2< STRUCT_CONSTRAINT >&& from);
 
       /// destructor
       virtual ~GraphChangesGenerator4K2();
@@ -151,12 +152,12 @@ namespace gum {
       /// @{
 
       /// copy operator
-      GraphChangesGenerator4K2<STRUCT_CONSTRAINT>&
-      operator=( const GraphChangesGenerator4K2<STRUCT_CONSTRAINT>& from );
+      GraphChangesGenerator4K2< STRUCT_CONSTRAINT >&
+        operator=(const GraphChangesGenerator4K2< STRUCT_CONSTRAINT >& from);
 
       /// move operator
-      GraphChangesGenerator4K2<STRUCT_CONSTRAINT>&
-      operator=( GraphChangesGenerator4K2<STRUCT_CONSTRAINT>&& from );
+      GraphChangesGenerator4K2< STRUCT_CONSTRAINT >&
+        operator=(GraphChangesGenerator4K2< STRUCT_CONSTRAINT >&& from);
 
       /// @}
 
@@ -183,19 +184,19 @@ namespace gum {
 
       /// sets a new graph from which the generator will compute possible
       /// changes
-      void setGraph( const DiGraph& graph );
+      void setGraph(const DiGraph& graph);
 
       /// notify the generator of a change applied to the graph
-      void modifyGraph( const ArcAddition& change );
+      void modifyGraph(const ArcAddition& change);
 
       /// notify the generator of a change applied to the graph
-      void modifyGraph( const ArcDeletion& change );
+      void modifyGraph(const ArcDeletion& change);
 
       /// notify the generator of a change applied to the graph
-      void modifyGraph( const ArcReversal& change );
+      void modifyGraph(const ArcReversal& change);
 
       /// notify the generator of a change applied to the graph
-      void modifyGraph( const GraphChange& change );
+      void modifyGraph(const GraphChange& change);
 
       /// empty the set of possible change operators that can be applied
       void clearChanges() noexcept;
@@ -204,13 +205,13 @@ namespace gum {
       void notifyGetCompleted();
 
       /// sets the maximum number of threads used to compute the set of changes
-      void setMaxNbThreads( Size nb ) noexcept;
+      void setMaxNbThreads(Size nb) noexcept;
 
       /// set a new order on the random variables
-      void setOrder( const Sequence<NodeId>& order );
+      void setOrder(const Sequence< NodeId >& order);
 
       /// set a new order on the random variables
-      void setOrder( const std::vector<NodeId>& order );
+      void setOrder(const std::vector< NodeId >& order);
 
       /// @}
 
@@ -222,17 +223,17 @@ namespace gum {
       STRUCT_CONSTRAINT* _constraint;
 
       /// the order on the variables
-      Sequence<NodeId> _order;
+      Sequence< NodeId > _order;
 
       /// the current set of graph changes
-      Set<GraphChange> _legal_changes;
+      Set< GraphChange > _legal_changes;
 
       /// create the set of legal and illegal changes from a given graph
       void _createChanges();
 
       private:
 /// the max number of threads authorized
-#if defined( _OPENMP ) && defined( NDEBUG )
+#if defined(_OPENMP) && defined(NDEBUG)
       Size __max_threads_number{getMaxNumberOfThreads()};
 #else
       Size __max_threads_number{1};
