@@ -43,9 +43,9 @@ namespace gum {
      * directed structure learning search algorithms.
      * @ingroup learning_group
      */
-    template <typename SCORE,
-              typename STRUCTURAL_CONSTRAINT,
-              typename GRAPH_CHANGES_GENERATOR>
+    template < typename SCORE,
+               typename STRUCTURAL_CONSTRAINT,
+               typename GRAPH_CHANGES_GENERATOR >
     class GraphChangesSelector4DiGraph {
       public:
       /// the type of the generator
@@ -57,21 +57,21 @@ namespace gum {
       /// @{
 
       /// default constructor
-      GraphChangesSelector4DiGraph( SCORE&                   score,
-                                    STRUCTURAL_CONSTRAINT&   constraint,
-                                    GRAPH_CHANGES_GENERATOR& changes_generator );
+      GraphChangesSelector4DiGraph(SCORE&                   score,
+                                   STRUCTURAL_CONSTRAINT&   constraint,
+                                   GRAPH_CHANGES_GENERATOR& changes_generator);
 
       /// copy constructor
       GraphChangesSelector4DiGraph(
-          const GraphChangesSelector4DiGraph<SCORE,
-                                             STRUCTURAL_CONSTRAINT,
-                                             GRAPH_CHANGES_GENERATOR>& from );
+        const GraphChangesSelector4DiGraph< SCORE,
+                                            STRUCTURAL_CONSTRAINT,
+                                            GRAPH_CHANGES_GENERATOR >& from);
 
       /// move constructor
       GraphChangesSelector4DiGraph(
-          GraphChangesSelector4DiGraph<SCORE,
-                                       STRUCTURAL_CONSTRAINT,
-                                       GRAPH_CHANGES_GENERATOR>&& from );
+        GraphChangesSelector4DiGraph< SCORE,
+                                      STRUCTURAL_CONSTRAINT,
+                                      GRAPH_CHANGES_GENERATOR >&& from);
 
       /// destructor
       ~GraphChangesSelector4DiGraph();
@@ -84,21 +84,21 @@ namespace gum {
       /// @{
 
       /// copy operator
-      GraphChangesSelector4DiGraph<SCORE,
-                                   STRUCTURAL_CONSTRAINT,
-                                   GRAPH_CHANGES_GENERATOR>&
-      operator=(
-          const GraphChangesSelector4DiGraph<SCORE,
-                                             STRUCTURAL_CONSTRAINT,
-                                             GRAPH_CHANGES_GENERATOR>& from );
+      GraphChangesSelector4DiGraph< SCORE,
+                                    STRUCTURAL_CONSTRAINT,
+                                    GRAPH_CHANGES_GENERATOR >&
+        operator=(
+          const GraphChangesSelector4DiGraph< SCORE,
+                                              STRUCTURAL_CONSTRAINT,
+                                              GRAPH_CHANGES_GENERATOR >& from);
 
       /// move operator
-      GraphChangesSelector4DiGraph<SCORE,
-                                   STRUCTURAL_CONSTRAINT,
-                                   GRAPH_CHANGES_GENERATOR>&
-      operator=( GraphChangesSelector4DiGraph<SCORE,
-                                              STRUCTURAL_CONSTRAINT,
-                                              GRAPH_CHANGES_GENERATOR>&& from );
+      GraphChangesSelector4DiGraph< SCORE,
+                                    STRUCTURAL_CONSTRAINT,
+                                    GRAPH_CHANGES_GENERATOR >&
+        operator=(GraphChangesSelector4DiGraph< SCORE,
+                                                STRUCTURAL_CONSTRAINT,
+                                                GRAPH_CHANGES_GENERATOR >&& from);
 
       /// @}
 
@@ -116,7 +116,7 @@ namespace gum {
       /** @brief indicates whether the selector contains graph changes related
        * to
        * the ith node */
-      bool empty( NodeId i );
+      bool empty(NodeId i);
 
       /// returns the best graph change to examine
       /** @throws NotFound exception is thrown if the selector is empty */
@@ -128,7 +128,7 @@ namespace gum {
        * allows to get the change that is considered the best for modifying the
        * parents' set of the ith node.
        * @throws NotFound exception is thrown if the selector is empty */
-      const GraphChange& bestChange( NodeId i );
+      const GraphChange& bestChange(NodeId i);
 
       /// return the score of the best graph change
       /** @throws NotFound exception is thrown if the selector is empty */
@@ -140,10 +140,10 @@ namespace gum {
        * allows to get the score of the change that is considered the best for
        * modifying the parents' set of the ith node.
        * @throws NotFound exception is thrown if the selector is empty */
-      double bestScore( NodeId i );
+      double bestScore(NodeId i);
 
       /// indicate to the selector that a change has been applied
-      void applyChange( const GraphChange& change );
+      void applyChange(const GraphChange& change);
 
       /// indicate to the selector that one of serveral changes has been applied
       /** This function is to be used rather than applyChange when we wish to
@@ -152,7 +152,7 @@ namespace gum {
        * we shall compute the scores with function
        * updateScoresAfterAppliedChanges (). See class GreedyHillClimbing for
        * an illustration of the use of this method. */
-      void applyChangeWithoutScoreUpdate( const GraphChange& change );
+      void applyChangeWithoutScoreUpdate(const GraphChange& change);
 
       /// recompute all the scores after the application of several changes
       /** This method needs COMPULSORILY be used after applications of
@@ -162,16 +162,16 @@ namespace gum {
       void updateScoresAfterAppliedChanges();
 
       /// indicates whether a given change is valid or not
-      bool isChangeValid( const GraphChange& change ) const;
+      bool isChangeValid(const GraphChange& change) const;
 
       /// sets the graph from which scores are computed
-      void setGraph( DiGraph& graph, const std::vector<Size>& modal );
+      void setGraph(DiGraph& graph, const std::vector< Size >& modal);
 
       /// returns the set of queues sorted by decreasing top priority
-      std::vector<std::pair<NodeId, double>> nodesSortedByBestScore() const;
+      std::vector< std::pair< NodeId, double > > nodesSortedByBestScore() const;
 
       /// returns the set of queues top priorities
-      std::vector<std::pair<Idx, double>> nodesUnsortedWithScore() const;
+      std::vector< std::pair< Idx, double > > nodesUnsortedWithScore() const;
 
       /// @}
 
@@ -186,59 +186,59 @@ namespace gum {
       GRAPH_CHANGES_GENERATOR* __changes_generator;
 
       /// a sequence containing all the possible changes
-      Sequence<GraphChange> __changes;
+      Sequence< GraphChange > __changes;
 
       /// the scores for the head and tail of all the changes
       /** the scores are indexed by their index in sequence __changes */
-      std::vector<std::pair<double, double>> __change_scores;
+      std::vector< std::pair< double, double > > __change_scores;
 
       /// for each node, a priority queue sorting GraphChanges by decreasing
       /// score
       /** within each queue, the changes are determined by their index in
        * sequence __changes. */
-      std::vector<PriorityQueue<Idx, double, std::greater<double>>>
-          __change_queue_per_node;
+      std::vector< PriorityQueue< Idx, double, std::greater< double > > >
+        __change_queue_per_node;
 
       /// a global priority queue indicating for each node its best score
-      PriorityQueue<NodeId, double, std::greater<double>> __node_queue;
+      PriorityQueue< NodeId, double, std::greater< double > > __node_queue;
 
       /// the set of changes known to be currently illegal (due to the
       /// constraints)
       /** within each queue, the changes are determined by their index in
        * sequence __changes. */
-      Set<Idx> __illegal_changes;
+      Set< Idx > __illegal_changes;
 
       /// the current score of each node
-      std::vector<double> __node_current_scores;
+      std::vector< double > __node_current_scores;
 
       /// the set of parents of each node (speeds-up score computations)
-      std::vector<std::vector<Idx>> __parents;
+      std::vector< std::vector< Idx > > __parents;
 
       /// indicates whether we need to recompute whether the queue is empty or
       /// not
       bool __queues_valid{false};
 
       /// the set of queues to update when applying several changes
-      Set<Idx> __queues_to_update;
+      Set< Idx > __queues_to_update;
 
       /// prepare the next pack of  score computations
-      void __addScoreToCompute( Idx change_index ) const;
+      void __addScoreToCompute(Idx change_index) const;
 
       /// indicates whether a given change is valid or not
-      bool __isChangeValid( Idx index ) const;
+      bool __isChangeValid(Idx index) const;
 
       /// put a change into the illegal set
-      void __invalidateChange( Idx change_index );
+      void __invalidateChange(Idx change_index);
 
       /// remove the now legal changes from the illegal set
-      void __illegal2LegalChanges( Set<Idx>& changes_to_recompute );
+      void __illegal2LegalChanges(Set< Idx >& changes_to_recompute);
 
       /// finds the changes that are affected by a given node modification
-      void __findLegalChangesNeedingUpdate( Set<Idx>& changes_to_recompute,
-                                            NodeId    target_node );
+      void __findLegalChangesNeedingUpdate(Set< Idx >& changes_to_recompute,
+                                           NodeId      target_node);
 
       /// perform the necessary updates of the scores
-      void __updateScores( const Set<Idx>& changes_to_recompute );
+      void __updateScores(const Set< Idx >& changes_to_recompute);
 
       /// get from the graph change generator a new set of changes
       void __getNewChanges();
@@ -249,6 +249,6 @@ namespace gum {
 } /* namespace gum */
 
 /// always include templated methods
-#include <agrum/learning/structureUtils/graphChangesSelector4DiGraph.tcc>
+#include <agrum/learning/structureUtils/graphChangesSelector4DiGraph_tpl.h>
 
 #endif /* GUM_LEARNING_GRAPH_CHANGES_SELECTOR_4_DIGRAPH_H */
