@@ -27,10 +27,10 @@
 
 #include <vector>
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 #include <agrum/core/set.h>
-#include <agrum/multidim/multiDimDecorator.h>
-#include <agrum/multidim/multiDimImplementation.h>
+#include <agrum/multidim/implementations/multiDimDecorator.h>
+#include <agrum/multidim/implementations/multiDimImplementation.h>
 
 namespace gum {
 
@@ -39,20 +39,22 @@ namespace gum {
   // ==========================================================================
 
   /**
-   * @class Potential potential.h <agrum/multidim/potential.h>
+   * @class Potential
+   * @headerfile potential.h <agrum/multidim/potential.h>
    * @ingroup multidim_group
    *
-   * @brief Class representing a potential.
+   * @brief aGrUM's Potential is a multi-dimensional array with tensor operators.
+   * It is used to represent probabilities and utilities in aGrUMs'
+   * multidimensional (graphical) models.
    *
-   * Using the decorator pattern, this representation is independant from the
+   * Using the decorator pattern, this representation is independent from the
    * implementation of the multidimensional matrix.
    *
    * @tparam GUM_SCALAR The type of the scalar stored in this multidimensional
    * matrix.
    */
-  template <typename GUM_SCALAR>
-  class Potential : public MultiDimDecorator<GUM_SCALAR> {
-
+  template < typename GUM_SCALAR >
+  class Potential : public MultiDimDecorator< GUM_SCALAR > {
     public:
     // =========================================================================
     /// @name Constructors, Destructors and Copy
@@ -71,7 +73,7 @@ namespace gum {
      * @brief Creates an potential around aContent.
      * @param aContent The implementation of this Potential.
      */
-    Potential( MultiDimImplementation<GUM_SCALAR>* aContent );
+    Potential(MultiDimImplementation< GUM_SCALAR >* aContent);
 
     /**
      * @brief Copy constructor.
@@ -83,19 +85,19 @@ namespace gum {
      * @param aContent The implementation to use in this Potential.
      * @param src The MultiDimContainer to copy.
      */
-    Potential( MultiDimImplementation<GUM_SCALAR>*  aContent,
-               const MultiDimContainer<GUM_SCALAR>& src );
+    Potential(MultiDimImplementation< GUM_SCALAR >*  aContent,
+              const MultiDimContainer< GUM_SCALAR >& src);
     /**
      * @brief Copy constructor & assignment
      */
-    Potential( const Potential<GUM_SCALAR>& src );
-    Potential<GUM_SCALAR>& operator=( const Potential<GUM_SCALAR>& src );
+    Potential(const Potential< GUM_SCALAR >& src);
+    Potential< GUM_SCALAR >& operator=(const Potential< GUM_SCALAR >& src);
 
     /**
      * move constructor & assignement
      **/
-    Potential( Potential<GUM_SCALAR>&& from );
-    Potential<GUM_SCALAR>& operator=( Potential<GUM_SCALAR>&& src );
+    Potential(Potential< GUM_SCALAR >&& from);
+    Potential< GUM_SCALAR >& operator=(Potential< GUM_SCALAR >&& src);
 
 
     /**
@@ -109,7 +111,7 @@ namespace gum {
     // ========================================================================
     /// @{
 
-    virtual Potential<GUM_SCALAR>* newFactory() const;
+    virtual Potential< GUM_SCALAR >* newFactory() const;
 
     /// @}
     // ========================================================================
@@ -122,69 +124,69 @@ namespace gum {
      * operations)
      * @param del_vars is the set of vars to eliminate
      */
-    Potential<GUM_SCALAR>
-    margSumOut( const Set<const DiscreteVariable*>& del_vars ) const;
+    Potential< GUM_SCALAR >
+      margSumOut(const Set< const DiscreteVariable* >& del_vars) const;
 
     /**
      * Projection using sum as operation (and implementation-optimized
      * operations)
      * @param kept_vars is the set of vars to keep
      */
-    Potential<GUM_SCALAR>
-    margSumIn( const Set<const DiscreteVariable*>& kept_vars ) const;
+    Potential< GUM_SCALAR >
+      margSumIn(const Set< const DiscreteVariable* >& kept_vars) const;
 
     /**
      * Projection using multiplication as operation (and
      * implementation-optimized operations)
      * @param del_vars is the set of vars to eliminate
      */
-    Potential<GUM_SCALAR>
-    margProdOut( const Set<const DiscreteVariable*>& del_vars ) const;
+    Potential< GUM_SCALAR >
+      margProdOut(const Set< const DiscreteVariable* >& del_vars) const;
 
     /**
      * Projection using multiplication as operation (and
      * implementation-optimized operations)
      * @param kept_vars is the set of vars to keep
      */
-    Potential<GUM_SCALAR>
-    margProdIn( const Set<const DiscreteVariable*>& kept_vars ) const;
+    Potential< GUM_SCALAR >
+      margProdIn(const Set< const DiscreteVariable* >& kept_vars) const;
 
     /**
      * Projection using min as operation (and implementation-optimized
      * operations)
      * @param del_vars is the set of vars to eliminate
      */
-    Potential<GUM_SCALAR>
-    margMinOut( const Set<const DiscreteVariable*>& del_vars ) const;
+    Potential< GUM_SCALAR >
+      margMinOut(const Set< const DiscreteVariable* >& del_vars) const;
 
     /**
      * Projection using min as operation (and implementation-optimized
      * operations)
      * @param kept_vars is the set of vars to keep
      */
-    Potential<GUM_SCALAR>
-    margMinIn( const Set<const DiscreteVariable*>& kept_vars ) const;
+    Potential< GUM_SCALAR >
+      margMinIn(const Set< const DiscreteVariable* >& kept_vars) const;
 
     /**
      * Projection using max as operation (and implementation-optimized
      * operations)
      * @param del_vars is the set of vars to eliminate
      */
-    Potential<GUM_SCALAR>
-    margMaxOut( const Set<const DiscreteVariable*>& del_vars ) const;
+    Potential< GUM_SCALAR >
+      margMaxOut(const Set< const DiscreteVariable* >& del_vars) const;
 
     /**
      * Projection using max as operation (and implementation-optimized
      * operations)
      * @param kept_vars is the set of vars to keep
      */
-    Potential<GUM_SCALAR>
-    margMaxIn( const Set<const DiscreteVariable*>& kept_vars ) const;
+    Potential< GUM_SCALAR >
+      margMaxIn(const Set< const DiscreteVariable* >& kept_vars) const;
 
     /**
      * create a boolean-like potential using the predicate isNonZero
      */
-    Potential<GUM_SCALAR> isNonZeroMap() const;
+    Potential< GUM_SCALAR > isNonZeroMap() const;
 
     /// sum of all elements in the Potential
     GUM_SCALAR sum() const;
@@ -201,6 +203,13 @@ namespace gum {
     /// @throw NotFound if all value == 0.0
     GUM_SCALAR minNonZero() const;
 
+    /// set of instantiation corresponding to the parameter v in the Potential
+    Set< Instantiation > findAll(GUM_SCALAR v) const;
+    /// set of instantiation corresponding to the max in the Potential
+    Set< Instantiation > argmax() const;
+    /// set of instantiation corresponding to the min in the Potential
+    Set< Instantiation > argmin() const;
+
     /// entropy of the Potential
     GUM_SCALAR entropy() const;
 
@@ -208,18 +217,49 @@ namespace gum {
      * @throw InvalidArgument if not all and only the vars of the potential are
      * in vars
      */
-    Potential<GUM_SCALAR>
-    reorganize( const std::vector<const DiscreteVariable*>& vars ) const;
+    Potential< GUM_SCALAR >
+      reorganize(const std::vector< const DiscreteVariable* >& vars) const;
 
     /** create a new Potential extracted from *this given a partial
      * instantiation
      */
-    Potential<GUM_SCALAR> extract( const Instantiation& inst ) const;
+    Potential< GUM_SCALAR > extract(const Instantiation& inst) const;
 
     /** create a new Potential with a certain variable in first
      * @throw InvalidArgument if the var is not in the potential
      */
-    Potential<GUM_SCALAR> putFirst( const DiscreteVariable* var ) const;
+    Potential< GUM_SCALAR > putFirst(const DiscreteVariable* var) const;
+
+    /**
+     * @brief copy a Potential data using name of variables and labels (not
+     * necessarily the same variables in the same orders)
+     *
+     * @warning a strict control on names of variables and labels are made
+     *
+     * @throw InvalidArgument if the Potential is not compatible with this
+     */
+    const Potential< GUM_SCALAR >&
+      fillWith(const Potential< GUM_SCALAR >& src) const;
+
+    /**
+     * @brief copy a Potential data using the sequence of names in mapSrc to find
+     * the corresponding variables.
+     *
+     * For instance, to copy the potential P(A,B,C) in Q(D,E,A) with the mapping
+     * P.A<->Q.E, P.B<->Q.A, P.C<->Q.D (assuming that the corresponding variables
+     * have the same domain size and the order of labels):
+     *
+     * @code
+     *   Q.fillWith(P,{"C","A","B"});
+     * @endcode
+     *
+     * @warning a strict control on names of variables and labels are made
+     *
+     * @throw InvalidArgument if the Potential is not compatible with this
+     * */
+    const Potential< GUM_SCALAR >&
+      fillWith(const Potential< GUM_SCALAR >&    src,
+               const std::vector< std::string >& mapSrc) const;
 
     /**
      * @brief Automatically fills the potential with the values in
@@ -229,41 +269,31 @@ namespace gum {
      * @throw SizeError Raised if v size's does not matches this
      * MultiDimContainer domain size.
      */
-    const Potential<GUM_SCALAR>&
-    fillWith( const std::vector<GUM_SCALAR>& v ) const;
-
-    /**
-     * @brief Automatically fills this MultiDimContainer with the values in
-     * l.
-     *
-     * @param l contains the data.
-     * @throw SizeError Raised if l size's does not matches this
-     * MultiDimContainer domain size.
-     */
-    const Potential<GUM_SCALAR>&
-    fillWith( std::initializer_list<GUM_SCALAR> l ) const;
+    const Potential< GUM_SCALAR >&
+      fillWith(const std::vector< GUM_SCALAR >& v) const;
 
     /**
      * @brief Automatically fills this MultiDimContainer with the value v
      *
      * @param v contains the data.
      */
-    const Potential<GUM_SCALAR>& fillWith( const GUM_SCALAR& v ) const;
+    const Potential< GUM_SCALAR >& fillWith(const GUM_SCALAR& v) const;
+
 
     /**
      * @brief Apply abs on every element of the container
      */
-    const Potential<GUM_SCALAR>& abs() const;
+    const Potential< GUM_SCALAR >& abs() const;
 
     /**
      * @brief normalisation of this do nothing if sum is 0
      */
-    const Potential<GUM_SCALAR>& normalize() const;
+    const Potential< GUM_SCALAR >& normalize() const;
 
     /**
      * @brief apply $x^2$ on every element of the container
      */
-    const Potential<GUM_SCALAR>& sq() const;
+    const Potential< GUM_SCALAR >& sq() const;
 
     /**
      * @brief compute KL divergence between this and p
@@ -273,7 +303,7 @@ namespace gum {
      * @throws gum::FatalError if a zero is found in p or this and not in the
      * other.
      */
-    GUM_SCALAR KL( const Potential<GUM_SCALAR>& p ) const;
+    GUM_SCALAR KL(const Potential< GUM_SCALAR >& p) const;
 
     /**
      * @brief compute KL divergence between this and p without testing compatibilty
@@ -281,7 +311,7 @@ namespace gum {
      * @throws gum::FatalError if a zero is found in p or this and not in the
      * other.
      */
-    GUM_SCALAR fastKL( const Potential<GUM_SCALAR>& p ) const;
+    GUM_SCALAR fastKL(const Potential< GUM_SCALAR >& p) const;
 
     /**
      * @brief normalisation of this as a CPT
@@ -292,12 +322,17 @@ namespace gum {
     /**
      * @brief create a new potential multiplied by v from *this
      */
-    const Potential<GUM_SCALAR>& scale( GUM_SCALAR v ) const;
+    const Potential< GUM_SCALAR >& scale(GUM_SCALAR v) const;
 
     /**
-    * @brief create a new potential added with v from *this
-    */
-    const Potential<GUM_SCALAR>& translate( GUM_SCALAR v ) const;
+     * @brief create a new potential added with v from *this
+     */
+    const Potential< GUM_SCALAR >& translate(GUM_SCALAR v) const;
+
+    /**
+     * @brief get a value at random from a 1-D distribution
+     */
+    Idx draw() const;
 
     ///@}
 
@@ -308,104 +343,100 @@ namespace gum {
 
 
     /// the function to be used to add two Potentials
-    Potential<GUM_SCALAR> operator+( const Potential<GUM_SCALAR>& p2 ) const {
-      if ( p2.empty() )
-        return Potential<GUM_SCALAR>( *this ).translate( p2._empty_value );
-      if ( this->empty() )
-        return Potential<GUM_SCALAR>( p2 ).translate( this->_empty_value );
+    Potential< GUM_SCALAR > operator+(const Potential< GUM_SCALAR >& p2) const {
+      if (p2.empty())
+        return Potential< GUM_SCALAR >(*this).translate(p2._empty_value);
+      if (this->empty())
+        return Potential< GUM_SCALAR >(p2).translate(this->_empty_value);
 
-      return Potential<GUM_SCALAR>( *this->content() + *p2.content() );
+      return Potential< GUM_SCALAR >(*this->content() + *p2.content());
     }
 
     /// the function to be used to subtract two Potentials
-    Potential<GUM_SCALAR> operator-( const Potential<GUM_SCALAR>& p2 ) const {
-      if ( p2.empty() )
-        return Potential<GUM_SCALAR>( *this ).translate( -p2._empty_value );
-      if ( this->empty() ) {
-        auto p = Potential<GUM_SCALAR>( p2 );
-        p.apply( [this]( GUM_SCALAR x ) { return this->_empty_value - x; } );
+    Potential< GUM_SCALAR > operator-(const Potential< GUM_SCALAR >& p2) const {
+      if (p2.empty())
+        return Potential< GUM_SCALAR >(*this).translate(-p2._empty_value);
+      if (this->empty()) {
+        auto p = Potential< GUM_SCALAR >(p2);
+        p.apply([this](GUM_SCALAR x) { return this->_empty_value - x; });
         return p;
       }
-      return Potential<GUM_SCALAR>( *this->content() - *p2.content() );
+      return Potential< GUM_SCALAR >(*this->content() - *p2.content());
     }
 
     /// the function to be used to multiply two Potentials
-    Potential<GUM_SCALAR> operator*( const Potential<GUM_SCALAR>& p2 ) const {
-      if ( p2.empty() )
-        return Potential<GUM_SCALAR>( *this ).scale( p2._empty_value );
-      if ( this->empty() )
-        return Potential<GUM_SCALAR>( p2 ).scale( this->_empty_value );
+    Potential< GUM_SCALAR > operator*(const Potential< GUM_SCALAR >& p2) const {
+      if (p2.empty()) return Potential< GUM_SCALAR >(*this).scale(p2._empty_value);
+      if (this->empty())
+        return Potential< GUM_SCALAR >(p2).scale(this->_empty_value);
 
-      return Potential<GUM_SCALAR>( *this->content() * *p2.content() );
+      return Potential< GUM_SCALAR >(*this->content() * *p2.content());
     }
 
     /// the function to be used to divide two Potentials
-    Potential<GUM_SCALAR> operator/( const Potential<GUM_SCALAR>& p2 ) const {
-      if ( p2.empty() )
-        return Potential<GUM_SCALAR>( *this ).scale( 1 / p2._empty_value );
-      if ( this->empty() ) {
-        auto p = Potential<GUM_SCALAR>( p2 );
-        p.apply( [this]( GUM_SCALAR x ) { return this->_empty_value / x; } );
+    Potential< GUM_SCALAR > operator/(const Potential< GUM_SCALAR >& p2) const {
+      if (p2.empty())
+        return Potential< GUM_SCALAR >(*this).scale(1 / p2._empty_value);
+      if (this->empty()) {
+        auto p = Potential< GUM_SCALAR >(p2);
+        p.apply([this](GUM_SCALAR x) { return this->_empty_value / x; });
         return p;
       }
-      return Potential<GUM_SCALAR>( *this->content() / *p2.content() );
+      return Potential< GUM_SCALAR >(*this->content() / *p2.content());
     }
 
-    Potential<GUM_SCALAR>& operator+=( const Potential<GUM_SCALAR>& r ) {
+    Potential< GUM_SCALAR >& operator+=(const Potential< GUM_SCALAR >& r) {
       *this = *this + r;
       return *this;
     }
 
-    Potential<GUM_SCALAR>& operator*=( const Potential<GUM_SCALAR>& r ) {
+    Potential< GUM_SCALAR >& operator*=(const Potential< GUM_SCALAR >& r) {
       *this = *this * r;
       return *this;
     }
 
-    Potential<GUM_SCALAR>& operator-=( const Potential<GUM_SCALAR>& r ) {
+    Potential< GUM_SCALAR >& operator-=(const Potential< GUM_SCALAR >& r) {
       *this = *this - r;
       return *this;
     }
 
-    Potential<GUM_SCALAR>& operator/=( const Potential<GUM_SCALAR>& r ) {
+    Potential< GUM_SCALAR >& operator/=(const Potential< GUM_SCALAR >& r) {
       *this = *this / r;
       return *this;
     }
 
-    bool operator==( const Potential<GUM_SCALAR>& r ) const {
-      if ( this->empty() ) {
-        if ( r.empty() )
+    bool operator==(const Potential< GUM_SCALAR >& r) const {
+      if (this->empty()) {
+        if (r.empty())
           return this->_empty_value == r._empty_value;
         else
           return false;
       } else {
-        if ( r.empty() )
+        if (r.empty())
           return false;
         else
-          return ( *this->_content ) == ( *r._content );
+          return (*this->_content) == (*r._content);
       }
     }
 
-    bool operator!=( const Potential<GUM_SCALAR>& r ) const {
-      return !operator==( r );
+    bool operator!=(const Potential< GUM_SCALAR >& r) const {
+      return !operator==(r);
     }
 
     virtual const std::string toString() const {
-      return MultiDimDecorator<GUM_SCALAR>::toString();
+      return MultiDimDecorator< GUM_SCALAR >::toString();
     }
 
     ///@}
 
     protected:
-    virtual void _swap( const DiscreteVariable* x, const DiscreteVariable* y );
-
-
-    Set<const DiscreteVariable*>
-    _complementVars( const Set<const DiscreteVariable*>& del_vars ) const;
+    Set< const DiscreteVariable* >
+      _complementVars(const Set< const DiscreteVariable* >& del_vars) const;
   };
 
 
-  extern template class Potential<float>;
-  extern template class Potential<double>;
+  extern template class Potential< float >;
+  extern template class Potential< double >;
 
 
 } /* namespace gum */
