@@ -7,4 +7,4 @@ cmake \
   -DFOR_PYTHON3=${PY3K} \
   ..
 make install -j${CPU_COUNT}
-${PYTHON} ../wrappers/pyAgrum/testunits/TestSuite.py || echo "nook"
+${PYTHON} ../wrappers/pyAgrum/testunits/gumTest.py
